(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    424293,      11588]
NotebookOptionsPosition[    390110,      11056]
NotebookOutlinePosition[    390580,      11073]
CellTagsIndexPosition[    390537,      11070]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Sections 5.2 and 5.3 - Euler method and Taylor methods", "Subsection",
 CellChangeTimes->{{3.43533539844361*^9, 3.435335404336271*^9}, {
  3.435508058549799*^9, 3.435508065775423*^9}, {3.5135258222418003`*^9, 
  3.5135258394018*^9}},ExpressionUUID->"d0f57ee0-199e-49ee-b7ac-1b7c83e66d16"],

Cell[CellGroupData[{

Cell["Solving Initial Value Problems with DSolve", "Subsubsection",
 CellChangeTimes->{{3.434722839506675*^9, 
  3.4347228533956995`*^9}},ExpressionUUID->"9643bf2c-1052-49c7-8521-\
1b3148e2ca61"],

Cell[TextData[{
 "All of the methods we will see in chapter 5 are numerical methods for \
finding approximate solutions to differential equations. To help us judge how \
good those methods are we will find it useful to be able to find the exact \
solutions to those equations. Fortunately, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a very powerful function called DSolve that can solve many \
differential equations exactly. Here I apply DSolve to solve the initial \
value problem I will be using for all of the examples below."
}], "Text",
 CellChangeTimes->{{3.435335418731869*^9, 
  3.435335549339492*^9}},ExpressionUUID->"0b18ff41-04e8-4e7c-81cd-\
92350811d71e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", " ", "=", " ", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "[", "t", "]"}], ")"}], "^", "2"}], " ", "+", " ", 
        RowBox[{"t", "^", "2"}]}]}], " ", ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], " ", "\[Equal]", " ", "0.5"}]}], "}"}], 
    ",", "y", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4347199081537085`*^9, 3.434719990660884*^9}, {
  3.4347200789951324`*^9, 3.4347201049454336`*^9}, {3.43472028947223*^9, 
  3.434720290050292*^9}, {3.43507350946875*^9, 3.435073517734375*^9}, {
  3.4353221657499065`*^9, 3.4353221659999094`*^9}, {3.4353223442678165`*^9, 
  3.4353223448615737`*^9}, {3.5129170914323997`*^9, 
  3.5129171092476*^9}},ExpressionUUID->"95ce3852-4b3d-4b01-a1a5-a04ac17ec65a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.5`", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.3519564801345691`", " ", 
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"BesselJ", "[", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["5", "4"]}], ",", 
              FractionBox[
               SuperscriptBox["t", "2"], "2"]}], "]"}]}], "-", 
           RowBox[{"2.`", " ", 
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"BesselJ", "[", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["3", "4"]}], ",", 
              FractionBox[
               SuperscriptBox["t", "2"], "2"]}], "]"}]}], "+", 
           RowBox[{"1.3519564801345691`", " ", 
            RowBox[{"BesselJ", "[", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "4"]}], ",", 
              FractionBox[
               SuperscriptBox["t", "2"], "2"]}], "]"}]}], "-", 
           RowBox[{"1.3519564801345691`", " ", 
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"BesselJ", "[", 
             RowBox[{
              FractionBox["3", "4"], ",", 
              FractionBox[
               SuperscriptBox["t", "2"], "2"]}], "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1.3519564801345691`"}], " ", 
            RowBox[{"BesselJ", "[", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "4"]}], ",", 
              FractionBox[
               SuperscriptBox["t", "2"], "2"]}], "]"}]}], "+", 
           RowBox[{"BesselJ", "[", 
            RowBox[{
             FractionBox["1", "4"], ",", 
             FractionBox[
              SuperscriptBox["t", "2"], "2"]}], "]"}]}], ")"}]}], ")"}]}]}], 
     "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4347199623825297`*^9, 3.434719991504547*^9}, {
   3.434720080682449*^9, 3.4347201062421675`*^9}, 3.434720291003313*^9, 
   3.434720398850371*^9, 3.4347229182163563`*^9, 3.4347232943448963`*^9, 
   3.435073359484375*^9, {3.435073512453125*^9, 3.43507351865625*^9}, 
   3.43532216996871*^9, 3.4353223456115837`*^9, 3.4353293518650303`*^9, 
   3.43550287434375*^9, 3.5129171158152*^9, 3.513338203915733*^9, 
   3.5135254944077997`*^9, 
   3.570364970868143*^9},ExpressionUUID->"bd579ae3-35b2-44eb-8c73-\
76973f83e1a5"]
}, Open  ]],

Cell["\<\
DSolve returns a result in the form of one or more replacement rules. To do \
something useful with this result it is best to apply the replacement rule to \
define a function Y[t] that is the exact solution we seek.\
\>", "Text",
 CellChangeTimes->{{3.435335558467645*^9, 
  3.435335613799261*^9}},ExpressionUUID->"83eca7f2-73a3-4224-beec-\
34c81e99a7be"],

Cell[BoxData[
 RowBox[{"Y", ":=", " ", 
  RowBox[{"y", "/.", 
   RowBox[{"soln", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.434719976021758*^9, 3.434720017783043*^9}, {
   3.434720067371397*^9, 3.434720127880438*^9}, {3.4347201945763054`*^9, 
   3.434720198747727*^9}, {3.4347202485235605`*^9, 3.434720249929658*^9}, {
   3.4347203057985783`*^9, 3.434720327874173*^9}, {3.434720366619709*^9, 
   3.434720391507467*^9}, 3.43472043414318*^9, 3.434721265016202*^9, {
   3.435073612*^9, 3.435073621765625*^9}, {3.435322173437505*^9, 
   3.4353221831251287`*^9}, {3.4353223365489674`*^9, 
   3.4353223413771544`*^9}},ExpressionUUID->"1cb924f2-f133-40b2-b6e3-\
8fd9c5c26a8c"],

Cell["\<\
Here is a plot of that exact solution. This will allow us to make simple \
visual comparisons between the exact solution and the approximate solutions \
we generate below.\
\>", "Text",
 CellChangeTimes->{{3.4353356193324227`*^9, 
  3.435335665921994*^9}},ExpressionUUID->"7d4b5d83-dfb4-469a-a6d2-\
06f1d97d6d12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot1", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Y", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4347204392050962`*^9, 3.4347204533284693`*^9}, {
   3.434720689816848*^9, 3.434720693566416*^9}, {3.434721275593108*^9, 
   3.4347212762180367`*^9}, {3.435074826725423*^9, 3.435074870482544*^9}, {
   3.435322205406664*^9, 3.4353222107036066`*^9}, 
   3.5129171361888*^9},ExpressionUUID->"c60dfde3-2603-4062-a037-9c5ddf947b1a"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjns0VAkAh8cjRIRqnSFKO5QijiaS8isqlWQTayvFmp6yW0mnWpERQw+l
jm1JHnmVxCBqd5FWti1byXsqxp0xxhgzLtVwbzLW/vGd73z/fdZhx/wPaDIY
DN9p/vfWA7KWp4OBHrxsajoJaHuZH+9lsmGwxbcjd7pX5KTffsjcANsGXtV6
DQI+r7sqs5gBKC6wyLigSSBo/3jdDeZ+8BZ2TOjOINDjmOSVwozCPIMmxzn6
BHLn+fEuMRPwQU8jbcVcAly9h4svMtPgWVQWlr2EwA+77vBHRguwMVJBPw4k
YDDFDfa24iOaM8t9Ko6AzY5h2bPLVbBP6vAse0Dg9Bs3pH/+A4PK3QV3ewiY
VZkINTTqcWtC7ahrKMIjsder5jUN4NYd5XM8RWgIz7LYpWhEFNeYPfOsCCrb
tbNLf/oHF3XC2laViaBJlxhb2DQhNpozyJOL4DIV+mhn2SvwzyyP4NqI8SqB
/eb50mYwHmU+mxkmxoLUIbp4+C28S9k+k0ViDI33CjucWqFcbWKXKxejQF7T
ZHS1DaXqN8deu/bByPIuKZG0Iy/ke/2/kvpw5Uj1wVxWJ2LctdZ819mHsXUl
ksPnu1D7PtjV3kmCKOfGqm+eCcAS/3uhMlmC3rLGyy3W75G3NsZZZ1iCifD2
TLtfPuDKofuaAUH9WLZeV32wphvh98wjmPX98M6zPlRhJgTjx+W2Oi5SnLYM
WSQK7kXIuv6KqBIp7BWBBl2+BCZfygWjrAHMmT2i1/iFQOyKhbt9ywegXZ/J
//a2COmu7YEiNxmOsmvezfQR44Zt5+TjLhlKtoTlPhkTw1Kc6GR6bhCqIXNj
6c0+PC9+aehjJUf1Tm+ttA0S6BRGOv8qkOP85sScKqkEJzPKN3WlDsG6Z6sg
P7EfnAdfNzb7KbDaNSGN6SyF34fRhJBlSgRbNdMabVKkcII7b2oPQ9WUIj7O
HUANo1QvVj2MdO19Uf4sGfZI4yZ2j5GYI6zO02yUIeIrW0VFj2BGDDfA7cQg
JmR1R04Yj4JRvI8vNpWjiRsX3ZM/ishb/BTTBjnuViUFztr+EXXLkvVMfh4C
Q3XqVgrjE0y2RtrHGylQX9Sqz6r8hG6Ht21naxV4Yerg03n+M8qzwZLsU2L2
4QLCz1eFvXwXE0u1EpO095M41hjiEu9wu+8Pg3CM5wusxlEqs8w02kYibO51
0/dMCslZiaHC7SSITtssjhWF/f5Km7IdJC5pnMsYXkRhfm1tuW8QiVre0KCe
PYVL1/Y8vxJGIr24cGK7B4XDLhmj+mdJxOgwIq05FBYlzN2sW0TiWIBytaSU
gnrVOcOueyTwcY1HViWFd8q+1qISEhU2G18EPaaQGvRw76YKEvF9bidbnlKY
Wup/MrGWxEiu1LWrjUJ3y7VsrTYS1wUbzBy+UPidN85p6yChFSAUqNUU0txD
7PIF0z852+xbtWj4FC6v8hSScNGKvRxjSOPPM69fcgdJNMXbYWAhjZsOK6/t
UJBQKfbk/21D44T4doA1Of3Ls8gpXEpjybaI3qefSZgZLg4NZ9PQ1mgvSB0n
UcSV2vq50SCq3cNDv5BQs82TV3rQqA3Pd3SaJCE0jkmw9KLx2wID1dQUiYhT
TfN1N9P4DxP/c5U=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.5},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.434720455031398*^9, 3.434720695222475*^9, 3.434721277530385*^9, 
   3.434722923278273*^9, 3.434723298735016*^9, 3.435073442578125*^9, 
   3.4350748715467367`*^9, {3.435322197297185*^9, 3.4353222122036257`*^9}, 
   3.4353293578327475`*^9, 3.435502880109375*^9, {3.5129171274996*^9, 
   3.5129171375928*^9}, 3.5133382066925325`*^9, 3.5135254973873997`*^9, 
   3.5703649763125525`*^9},ExpressionUUID->"b73d4193-0a5f-41f5-9a09-\
47d960f9f7ee"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Direction Fields", "Subsubsection",
 CellChangeTimes->{{3.4347228668160286`*^9, 
  3.434722871549858*^9}},ExpressionUUID->"fd645d20-d23c-411c-ad8f-\
a7dba4bd0074"],

Cell[TextData[{
 "Before we look at our first approximation method, lets take a look at a \
simple graphical technique that can help us to understand why solutions to \
differential equations behave the way they do. The differential equation \
y'[t] = f[t,y] allows us to compute the slope of the solution at any point \
(t,y). By making a special plot called a direction field plot we can visual \
these slopes.\nTo make a plot of a direction field we use the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " VectorPlot function."
}], "Text",
 CellChangeTimes->{{3.4353356817375298`*^9, 3.43533584762875*^9}, {
  3.5703649360176816`*^9, 
  3.570364947780102*^9}},ExpressionUUID->"e53cd3f7-d057-4496-b67d-\
308577dbef39"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"y", "^", "2"}], "+", 
   RowBox[{"t", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.434722893406715*^9, 3.434722900312169*^9}, {
  3.512917145814*^9, 
  3.5129171523504*^9}},ExpressionUUID->"a6b4960f-d125-4a67-b099-4dd0b46524a3"],

Cell["Here is the direction field for this particular f.", "Text",
 CellChangeTimes->{{3.435335858974678*^9, 
  3.435335867210634*^9}},ExpressionUUID->"1ee6c9a2-d6b3-4a50-8fba-\
68e70f639a35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", " ", "=", " ", 
   RowBox[{"VectorPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"f", "[", 
        RowBox[{"t", ",", "y"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.434720572221021*^9, 3.4347205781734605`*^9}, {
   3.43472063090176*^9, 3.4347207042370615`*^9}, 3.434720747669557*^9, {
   3.4347228868137245`*^9, 3.434722890688278*^9}, {3.5129171667648*^9, 
   3.5129171847672*^9}, 
   3.5703649594801226`*^9},ExpressionUUID->"8c2ea1e1-7544-4864-a61f-\
db08e3de6c8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot2"}], "]"}]], "Input",
 CellChangeTimes->{{3.4347207087834125`*^9, 
  3.4347207158450985`*^9}},ExpressionUUID->"be8fe1d0-53d6-4506-a81e-\
06e984187434"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjns0VAkAh8cjRIRqnSFKO5QijiaS8isqlWQTayvFmp6yW0mnWpERQw+l
jm1JHnmVxCBqd5FWti1byXsqxp0xxhgzLtVwbzLW/vGd73z/fdZhx/wPaDIY
DN9p/vfWA7KWp4OBHrxsajoJaHuZH+9lsmGwxbcjd7pX5KTffsjcANsGXtV6
DQI+r7sqs5gBKC6wyLigSSBo/3jdDeZ+8BZ2TOjOINDjmOSVwozCPIMmxzn6
BHLn+fEuMRPwQU8jbcVcAly9h4svMtPgWVQWlr2EwA+77vBHRguwMVJBPw4k
YDDFDfa24iOaM8t9Ko6AzY5h2bPLVbBP6vAse0Dg9Bs3pH/+A4PK3QV3ewiY
VZkINTTqcWtC7ahrKMIjsder5jUN4NYd5XM8RWgIz7LYpWhEFNeYPfOsCCrb
tbNLf/oHF3XC2laViaBJlxhb2DQhNpozyJOL4DIV+mhn2SvwzyyP4NqI8SqB
/eb50mYwHmU+mxkmxoLUIbp4+C28S9k+k0ViDI33CjucWqFcbWKXKxejQF7T
ZHS1DaXqN8deu/bByPIuKZG0Iy/ke/2/kvpw5Uj1wVxWJ2LctdZ819mHsXUl
ksPnu1D7PtjV3kmCKOfGqm+eCcAS/3uhMlmC3rLGyy3W75G3NsZZZ1iCifD2
TLtfPuDKofuaAUH9WLZeV32wphvh98wjmPX98M6zPlRhJgTjx+W2Oi5SnLYM
WSQK7kXIuv6KqBIp7BWBBl2+BCZfygWjrAHMmT2i1/iFQOyKhbt9ywegXZ/J
//a2COmu7YEiNxmOsmvezfQR44Zt5+TjLhlKtoTlPhkTw1Kc6GR6bhCqIXNj
6c0+PC9+aehjJUf1Tm+ttA0S6BRGOv8qkOP85sScKqkEJzPKN3WlDsG6Z6sg
P7EfnAdfNzb7KbDaNSGN6SyF34fRhJBlSgRbNdMabVKkcII7b2oPQ9WUIj7O
HUANo1QvVj2MdO19Uf4sGfZI4yZ2j5GYI6zO02yUIeIrW0VFj2BGDDfA7cQg
JmR1R04Yj4JRvI8vNpWjiRsX3ZM/ishb/BTTBjnuViUFztr+EXXLkvVMfh4C
Q3XqVgrjE0y2RtrHGylQX9Sqz6r8hG6Ht21naxV4Yerg03n+M8qzwZLsU2L2
4QLCz1eFvXwXE0u1EpO095M41hjiEu9wu+8Pg3CM5wusxlEqs8w02kYibO51
0/dMCslZiaHC7SSITtssjhWF/f5Km7IdJC5pnMsYXkRhfm1tuW8QiVre0KCe
PYVL1/Y8vxJGIr24cGK7B4XDLhmj+mdJxOgwIq05FBYlzN2sW0TiWIBytaSU
gnrVOcOueyTwcY1HViWFd8q+1qISEhU2G18EPaaQGvRw76YKEvF9bidbnlKY
Wup/MrGWxEiu1LWrjUJ3y7VsrTYS1wUbzBy+UPidN85p6yChFSAUqNUU0txD
7PIF0z852+xbtWj4FC6v8hSScNGKvRxjSOPPM69fcgdJNMXbYWAhjZsOK6/t
UJBQKfbk/21D44T4doA1Of3Ls8gpXEpjybaI3qefSZgZLg4NZ9PQ1mgvSB0n
UcSV2vq50SCq3cNDv5BQs82TV3rQqA3Pd3SaJCE0jkmw9KLx2wID1dQUiYhT
TfN1N9P4DxP/c5U=
      "]]}}, {{}, 
    {Hue[0.67, 0.6, 0.6], 
     {Arrowheads[{{0.013504778689681385`, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 0.}, {0.015661750344768393`, 0.}}]}, 
     {Arrowheads[{{0.013507590720672756`, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 0.14253751529908634`}, {
       0.015661750344768393`, 0.14317677041519933`}}]}, 
     {Arrowheads[{{0.013549701154497395`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 0.2844357754820597}, {
       0.01566175034476839, 0.2869927959465117}}]}, 
     {Arrowheads[{{0.013730687407110491`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 0.42569478054892007`}, {
       0.01566175034476839, 0.431448076593937}}]}, 
     {Arrowheads[{{0.01420650239010017, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 0.5663145304996674}, {
       0.01566175034476839, 0.5765426123574753}}]}, 
     {Arrowheads[{{0.015160930377615778`, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 0.7062950253343018}, {
       0.015661750344768393`, 0.7222764032371266}}]}, 
     {Arrowheads[{{0.016757765808407633`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 0.8456362650528231}, {
       0.01566175034476839, 0.8686494492328909}}]}, 
     {Arrowheads[{{0.01909864117979451, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 0.9843382496552314}, {
       0.01566175034476839, 1.015661750344768}}]}, 
     {Arrowheads[{{0.02221507710316727, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 1.1224009791415268`}, {
       0.015661750344768393`, 1.1633133065727586`}}]}, 
     {Arrowheads[{{0.026091188432737254`, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 1.2598244535117091`}, {
       0.015661750344768393`, 1.3116041179168618`}}]}, 
     {Arrowheads[{{0.030691615252044377`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 1.3966086727657785`}, {
       0.01566175034476839, 1.460534184377078}}]}, 
     {Arrowheads[{{0.035979214039289074`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 1.5327536369037347`}, {
       0.01566175034476839, 1.610103505953407}}]}, 
     {Arrowheads[{{0.0419222819795379, 1.}}], 
      ArrowBox[{{-0.015661750344768393`, 1.6682593459255781`}, {
       0.015661750344768393`, 1.7603120826458494`}}]}, 
     {Arrowheads[{{0.04849599728164734, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 1.8031257998313084`}, {
       0.01566175034476839, 1.9111599144544045`}}]}, 
     {Arrowheads[{{0.055681628988146784`, 1.}}], 
      ArrowBox[{{-0.01566175034476839, 1.937352998620926}, {
       0.01566175034476839, 2.062647001379073}}]}, 
     {Arrowheads[{{0.013504954458772457`, 1.}}], 
      ArrowBox[{{0.055766821083803035`, -0.00007990688951412443}, {
       0.08709032177333981, 0.00007990688951412443}}]}, 
     {Arrowheads[{{0.01350917223087398, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.14245760840957222`}, {
       0.08709032177333982, 0.14325667730471348`}}]}, 
     {Arrowheads[{{0.013555481108846648`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.2843558685925456}, {
       0.08709032177333982, 0.2870727028360258}}]}, 
     {Arrowheads[{{0.013743301729850929`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.4256148736594059}, {
       0.08709032177333982, 0.4315279834834511}}]}, 
     {Arrowheads[{{0.01422804043414362, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.5662346236101533}, {
       0.08709032177333982, 0.5766225192469895}}]}, 
     {Arrowheads[{{0.015192368236727007`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.7062151184447876}, {
       0.08709032177333982, 0.7223563101266407}}]}, 
     {Arrowheads[{{0.016798652788972752`, 1.}}], 
      ArrowBox[{{0.055766821083803035`, 0.845556358163309}, {
       0.08709032177333981, 0.8687293561224051}}]}, 
     {Arrowheads[{{0.01914742418914699, 1.}}], 
      ArrowBox[{{0.05576682108380303, 0.9842583427657172}, {
       0.08709032177333982, 1.0157416572342823`}}]}, 
     {Arrowheads[{{0.022269825010846917`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.1223210722520125`}, {
       0.08709032177333982, 1.1633932134622724`}}]}, 
     {Arrowheads[{{0.02615016684298786, 1.}}], 
      ArrowBox[{{0.055766821083803035`, 1.259744546622195}, {
       0.08709032177333981, 1.311684024806376}}]}, 
     {Arrowheads[{{0.030753503463058947`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.3965287658762642`}, {
       0.08709032177333982, 1.460614091266592}}]}, 
     {Arrowheads[{{0.036043087372853146`, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.5326737300142206`}, {
       0.08709032177333982, 1.6101834128429213`}}]}, 
     {Arrowheads[{{0.04198751679348589, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.668179439036064}, {
       0.08709032177333982, 1.7603919895353637`}}]}, 
     {Arrowheads[{{0.04856217754283751, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.8030458929417943`}, {
       0.08709032177333982, 1.9112398213439188`}}]}, 
     {Arrowheads[{{0.05574847618548188, 1.}}], 
      ArrowBox[{{0.05576682108380303, 1.9372730917314116`}, {
       0.08709032177333982, 2.062726908268587}}]}, 
     {Arrowheads[{{0.01350759072067276, 1.}}], 
      ArrowBox[{{0.12719539251237447`, -0.0003196275580564978}, {
       0.15851889320191126`, 0.0003196275580564978}}]}, 
     {Arrowheads[{{0.013516023303361132`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.14221788774102986`}, {
       0.15851889320191123`, 0.14349639797325586`}}]}, 
     {Arrowheads[{{0.013574904712578202`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.2841161479240032}, {
       0.15851889320191123`, 0.28731242350456815`}}]}, 
     {Arrowheads[{{0.013783142219773233`, 1.}}], 
      ArrowBox[{{0.12719539251237444`, 0.4253751529908636}, {
       0.15851889320191126`, 0.43176770415199356`}}]}, 
     {Arrowheads[{{0.014294452686888203`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.5659949029416109}, {
       0.15851889320191123`, 0.5768622399155319}}]}, 
     {Arrowheads[{{0.015288157198676907`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.7059753977762453}, {
       0.15851889320191123`, 0.7225960307951832}}]}, 
     {Arrowheads[{{0.016922404295622064`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.8453166374947666}, {
       0.15851889320191126`, 0.8689690767909474}}]}, 
     {Arrowheads[{{0.01929450951146035, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 0.9840186220971749}, {
       0.15851889320191126`, 1.0159813779028246`}}]}, 
     {Arrowheads[{{0.022434536805357123`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.1220813515834702`}, {
       0.15851889320191126`, 1.163632934130815}}]}, 
     {Arrowheads[{{0.026327391285153077`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.2595048259536525`}, {
       0.15851889320191126`, 1.3119237454749182`}}]}, 
     {Arrowheads[{{0.030939345991567113`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.396289045207722}, {
       0.15851889320191126`, 1.4608538119351344`}}]}, 
     {Arrowheads[{{0.036234817931493905`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.5324340093456783`}, {
       0.15851889320191126`, 1.6104231335114638`}}]}, 
     {Arrowheads[{{0.04218329120080959, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.6679397183675215`}, {
       0.15851889320191126`, 1.7606317102039057`}}]}, 
     {Arrowheads[{{0.048760763565581886`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.802806172273252}, {
       0.15851889320191123`, 1.9114795420124613`}}]}, 
     {Arrowheads[{{0.055949047689902554`, 1.}}], 
      ArrowBox[{{0.12719539251237447`, 1.9370333710628693`}, {
       0.15851889320191123`, 2.0629666289371293`}}]}, 
     {Arrowheads[{{0.013519008581740728`, 1.}}], 
      ArrowBox[{{0.1986239639409459, -0.00071916200562712}, {
       0.22994746463048268`, 0.00071916200562712}}]}, 
     {Arrowheads[{{0.013534451261237255`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.14181835329345924`}, {
       0.22994746463048268`, 0.14389593242082646`}}]}, 
     {Arrowheads[{{0.013614191864039343`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.28371661347643257`}, {
       0.22994746463048268`, 0.2877119579521388}}]}, 
     {Arrowheads[{{0.01385614256764648, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.42497561854329297`}, {
       0.22994746463048268`, 0.4321672385995642}}]}, 
     {Arrowheads[{{0.014411049523575633`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.5655953684940404}, {
       0.22994746463048268`, 0.5772617743631026}}]}, 
     {Arrowheads[{{0.015452631255976944`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.7055758633286746}, {
       0.22994746463048268`, 0.7229955652427538}}]}, 
     {Arrowheads[{{0.01713221290126769, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.8449171030471959}, {
       0.22994746463048268`, 0.8693686112385179}}]}, 
     {Arrowheads[{{0.019542050472903492`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 0.9836190876496043}, {
       0.22994746463048268`, 1.0163809123503953`}}]}, 
     {Arrowheads[{{0.02271058270533921, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.1216818171358995`}, {
       0.22994746463048268`, 1.1640324685783854`}}]}, 
     {Arrowheads[{{0.026623710126009906`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.2591052915060819`}, {
       0.22994746463048268`, 1.3123232799224887`}}]}, 
     {Arrowheads[{{0.031249665939413303`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.3958895107601512`}, {
       0.22994746463048268`, 1.4612533463827049`}}]}, 
     {Arrowheads[{{0.036554731588591675`, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.5320344748981076`}, {
       0.22994746463048268`, 1.6108226679590343`}}]}, 
     {Arrowheads[{{0.04250981187518806, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.667540183919951}, {
       0.22994746463048268`, 1.7610312446514766`}}]}, 
     {Arrowheads[{{0.04909188923718371, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.8024066378256813`}, {
       0.22994746463048268`, 1.9118790764600317`}}]}, 
     {Arrowheads[{{0.05628343217261853, 1.}}], 
      ArrowBox[{{0.1986239639409459, 1.9366338366152986`}, {
       0.22994746463048268`, 2.0633661633847}}]}, 
     {Arrowheads[{{0.013549701154497388`, 1.}}], 
      ArrowBox[{{0.2700525353695173, -0.0012785102322259907`}, {
       0.30137603605905405`, 0.0012785102322259907`}}]}, 
     {Arrowheads[{{0.013574904712578202`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.14125900506686037`}, {
       0.30137603605905405`, 0.14445528064742535`}}]}, 
     {Arrowheads[{{0.01368358370942841, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.2831572652498337}, {
       0.30137603605905405`, 0.28827130617873764`}}]}, 
     {Arrowheads[{{0.013971979932200672`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.4244162703166941}, {
       0.30137603605905405`, 0.43272658682616305`}}]}, 
     {Arrowheads[{{0.014586394188769284`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.5650360202674415}, {
       0.30137603605905405`, 0.5778211225897014}}]}, 
     {Arrowheads[{{0.01569270810982839, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.7050165151020757}, {
       0.30137603605905405`, 0.7235549134693526}}]}, 
     {Arrowheads[{{0.017433141981548616`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.844357754820597}, {
       0.30137603605905405`, 0.8699279594651169}}]}, 
     {Arrowheads[{{0.019893456709352764`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 0.9830597394230054}, {
       0.30137603605905405`, 1.0169402605769942`}}]}, 
     {Arrowheads[{{0.02310013701309754, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.1211224689093007`}, {
       0.30137603605905405`, 1.1645918168049842`}}]}, 
     {Arrowheads[{{0.027040475244854638`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.258545943279483}, {
       0.30137603605905405`, 1.3128826281490875`}}]}, 
     {Arrowheads[{{0.0316853009555569, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.3953301625335524`}, {
       0.30137603605905405`, 1.4618126946093037`}}]}, 
     {Arrowheads[{{0.037003352671052495`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.5314751266715088`}, {
       0.30137603605905405`, 1.6113820161856331`}}]}, 
     {Arrowheads[{{0.04296741279682464, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.6669808356933522`}, {
       0.30137603605905405`, 1.7615905928780755`}}]}, 
     {Arrowheads[{{0.04955577173658819, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.8018472895990825`}, {
       0.30137603605905405`, 1.9124384246866306`}}]}, 
     {Arrowheads[{{0.056751773934796745`, 1.}}], 
      ArrowBox[{{0.2700525353695173, 1.9360744883886998`}, {
       0.30137603605905405`, 2.063925511611299}}]}, 
     {Arrowheads[{{0.013614191864039334`, 1.}}], 
      ArrowBox[{{0.3414811067980887, -0.0019976722378531103`}, {
       0.37280460748762545`, 0.0019976722378531103`}}]}, 
     {Arrowheads[{{0.013651801162482548`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.14053984306123324`}, {
       0.37280460748762545`, 0.14517444265305246`}}]}, 
     {Arrowheads[{{0.013797085019177119`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.2824381032442066}, {
       0.37280460748762545`, 0.2889904681843648}}]}, 
     {Arrowheads[{{0.014143705545851844`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.42369710831106694`}, {
       0.37280460748762545`, 0.4334457488317901}}]}, 
     {Arrowheads[{{0.014831851091484482`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.5643168582618143}, {
       0.37280460748762545`, 0.5785402845953285}}]}, 
     {Arrowheads[{{0.016017439364559356`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.7042973530964486}, {
       0.37280460748762545`, 0.7242740754749797}}]}, 
     {Arrowheads[{{0.017831761452883448`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.84363859281497}, {0.37280460748762545`,
        0.8706471214707441}}]}, 
     {Arrowheads[{{0.02035314557449628, 1.}}], 
      ArrowBox[{{0.3414811067980887, 0.9823405774173782}, {
       0.37280460748762545`, 1.0176594225826214`}}]}, 
     {Arrowheads[{{0.023606027181612924`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.1204033069036736`}, {
       0.37280460748762545`, 1.1653109788106115`}}]}, 
     {Arrowheads[{{0.027579456152498384`, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.257826781273856}, {
       0.37280460748762545`, 1.3136017901547148`}}]}, 
     {Arrowheads[{{0.03224735561791703, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.3946110005279253`}, {
       0.37280460748762545`, 1.462531856614931}}]}, 
     {Arrowheads[{{0.03758137757834421, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.5307559646658817`}, {
       0.37280460748762545`, 1.6121011781912604`}}]}, 
     {Arrowheads[{{0.04355654043772868, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.666261673687725}, {
       0.37280460748762545`, 1.7623097548837023`}}]}, 
     {Arrowheads[{{0.0501527030388391, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.8011281275934554`}, {
       0.37280460748762545`, 1.9131575866922579`}}]}, 
     {Arrowheads[{{0.05735426791670511, 1.}}], 
      ArrowBox[{{0.3414811067980887, 1.9353553263830727`}, {
       0.37280460748762545`, 2.064644673616926}}]}, 
     {Arrowheads[{{0.013730687407110486`, 1.}}], 
      ArrowBox[{{0.4129096782266601, -0.002876648022508479}, {
       0.44423317891619685`, 0.002876648022508479}}]}, 
     {Arrowheads[{{0.013783142219773233`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.13966086727657787`}, {
       0.4442331789161969, 0.14605341843770783`}}]}, 
     {Arrowheads[{{0.013971979932200672`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.28155912745955125`}, {
       0.44423317891619685`, 0.2898694439690202}}]}, 
     {Arrowheads[{{0.014387145801558872`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.4228181325264116}, {
       0.44423317891619685`, 0.4343247246164455}}]}, 
     {Arrowheads[{{0.015160930377615768`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.563437882477159}, {
       0.44423317891619685`, 0.5794192603799838}}]}, 
     {Arrowheads[{{0.016437407584498378`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.7034183773117932}, {
       0.44423317891619685`, 0.7251530512596351}}]}, 
     {Arrowheads[{{0.018335683183891123`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.8427596170303145}, {
       0.44423317891619685`, 0.8715260972553993}}]}, 
     {Arrowheads[{{0.02092623255412397, 1.}}], 
      ArrowBox[{{0.4129096782266601, 0.9814616016327229}, {
       0.44423317891619685`, 1.0185383983672767`}}]}, 
     {Arrowheads[{{0.024231546836223604`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.1195243311190182`}, {
       0.44423317891619685`, 1.1661899545952668`}}]}, 
     {Arrowheads[{{0.028242733028308254`, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.2569478054892005`}, {
       0.44423317891619685`, 1.31448076593937}}]}, 
     {Arrowheads[{{0.0329371415255185, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.3937320247432698`}, {
       0.44423317891619685`, 1.4634108323995862`}}]}, 
     {Arrowheads[{{0.03828964121419624, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.5298769888812263`}, {
       0.44423317891619685`, 1.6129801539759157`}}]}, 
     {Arrowheads[{{0.04427773470324255, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.6653826979030697`}, {
       0.44423317891619685`, 1.763188730668358}}]}, 
     {Arrowheads[{{0.05088303887731047, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.8002491518088}, {0.44423317891619685`, 
       1.9140365624769131`}}]}, 
     {Arrowheads[{{0.05809115315699131, 1.}}], 
      ArrowBox[{{0.4129096782266601, 1.9344763505984173`}, {
       0.44423317891619685`, 2.065523649401581}}]}, 
     {Arrowheads[{{0.013920407247036741`, 1.}}], 
      ArrowBox[{{0.4843382496552315, -0.003915437586192096}, {
       0.5156617503447684, 0.003915437586192096}}]}, 
     {Arrowheads[{{0.013989807297873148`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.13862207771289425`}, {
       0.5156617503447684, 0.14709220800139144`}}]}, 
     {Arrowheads[{{0.014228040434143652`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.2805203378958676}, {0.5156617503447684,
        0.2909082335327038}}]}, 
     {Arrowheads[{{0.014720039515331431`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.42177934296272795`}, {
       0.5156617503447684, 0.4353635141801291}}]}, 
     {Arrowheads[{{0.015588443528442306`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.5623990929134753}, {0.5156617503447684,
        0.5804580499436675}}]}, 
     {Arrowheads[{{0.016964013899707857`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.7023795877481096}, {0.5156617503447684,
        0.7261918408233187}}]}, 
     {Arrowheads[{{0.018953041711971708`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.841720827466631}, {0.5156617503447684, 
       0.8725648868190831}}]}, 
     {Arrowheads[{{0.02161819393726642, 1.}}], 
      ArrowBox[{{0.4843382496552315, 0.9804228120690393}, {0.5156617503447684,
        1.0195771879309603`}}]}, 
     {Arrowheads[{{0.024980252705276526`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.1184855415553345`}, {
       0.5156617503447684, 1.1672287441589504`}}]}, 
     {Arrowheads[{{0.029032579459190102`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.2559090159255168`}, {
       0.5156617503447684, 1.3155195555030539`}}]}, 
     {Arrowheads[{{0.0337561106479931, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.3926932351795862`}, {
       0.5156617503447684, 1.4644496219632699`}}]}, 
     {Arrowheads[{{0.039129079041553515`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.5288381993175426`}, {
       0.5156617503447684, 1.6140189435395993`}}]}, 
     {Arrowheads[{{0.045131607061557916`, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.664343908339386}, {0.5156617503447684, 
       1.7642275202320417`}}]}, 
     {Arrowheads[{{0.05174718590548679, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.7992103622451163`}, {
       0.5156617503447684, 1.9150753520405968`}}]}, 
     {Arrowheads[{{0.05896270509529095, 1.}}], 
      ArrowBox[{{0.4843382496552315, 1.9334375610347336`}, {
       0.5156617503447684, 2.066562438965265}}]}, 
     {Arrowheads[{{0.014206502390100193`, 1.}}], 
      ArrowBox[{{0.5557668210838029, -0.005114040928903963}, {
       0.5870903217733398, 0.005114040928903963}}]}, 
     {Arrowheads[{{0.014294452686888228`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.13742347437018237`}, {
       0.5870903217733398, 0.14829081134410332`}}]}, 
     {Arrowheads[{{0.014586394188769308`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.27932173455315573`}, {
       0.5870903217733398, 0.29210683687541567`}}]}, 
     {Arrowheads[{{0.015160930377615801`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.42058073962001613`}, {
       0.5870903217733398, 0.436562117522841}}]}, 
     {Arrowheads[{{0.016129528767694096`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.5612004895707635}, {0.5870903217733398,
        0.5816566532863794}}]}, 
     {Arrowheads[{{0.017608724217368595`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.7011809844053978}, {0.5870903217733398,
        0.7273904441660306}}]}, 
     {Arrowheads[{{0.01969197450115173, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.8405222241239191}, {0.5870903217733398,
        0.8737634901617949}}]}, 
     {Arrowheads[{{0.02243453680535713, 1.}}], 
      ArrowBox[{{0.5557668210838029, 0.9792242087263274}, {0.5870903217733398,
        1.0207757912736721`}}]}, 
     {Arrowheads[{{0.02585576560505434, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.1172869382126227`}, {
       0.5870903217733398, 1.1684273475016622`}}]}, 
     {Arrowheads[{{0.029951345736036243`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.254710412582805}, {0.5870903217733398, 
       1.3167181588457655`}}]}, 
     {Arrowheads[{{0.03470578760473949, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.3914946318368744`}, {
       0.5870903217733398, 1.4656482253059817`}}]}, 
     {Arrowheads[{{0.0401006876994049, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.5276395959748308`}, {
       0.5870903217733398, 1.6152175468823111`}}]}, 
     {Arrowheads[{{0.04611881739292795, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.6631453049966742`}, {
       0.5870903217733398, 1.7654261235747535`}}]}, 
     {Arrowheads[{{0.05274558786891727, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.7980117589024045`}, {
       0.5870903217733398, 1.9162739553833086`}}]}, 
     {Arrowheads[{{0.059969227156027156`, 1.}}], 
      ArrowBox[{{0.5557668210838029, 1.9322389576920218`}, {
       0.5870903217733398, 2.0677610423079766`}}]}, 
     {Arrowheads[{{0.014612571269483373`, 1.}}], 
      ArrowBox[{{0.6271953925123743, -0.006472458050644077}, {
       0.6585188932019111, 0.006472458050644077}}]}, 
     {Arrowheads[{{0.014720039515331414`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.13606505724844228`}, {
       0.6585188932019111, 0.14964922846584344`}}]}, 
     {Arrowheads[{{0.015068113732437343`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.2779633174314156}, {0.6585188932019111,
        0.29346525399715573`}}]}, 
     {Arrowheads[{{0.015727913077885992`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.419222322498276}, {0.6585188932019111, 
       0.43792053464458114`}}]}, 
     {Arrowheads[{{0.016798652788972766`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.5598420724490234}, {0.6585188932019111,
        0.5830150704081195}}]}, 
     {Arrowheads[{{0.01838235884604448, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.6998225672836577}, {0.6585188932019111,
        0.7287488612877707}}]}, 
     {Arrowheads[{{0.02056015642934361, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.839163807002179}, {0.6585188932019111, 
       0.875121907283535}}]}, 
     {Arrowheads[{{0.02338050795681107, 1.}}], 
      ArrowBox[{{0.6271953925123743, 0.9778657916045873}, {0.6585188932019111,
        1.0221342083954124`}}]}, 
     {Arrowheads[{{0.026861592976077382`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.1159285210908827`}, {
       0.6585188932019111, 1.1697857646234024`}}]}, 
     {Arrowheads[{{0.031001352207100926`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.253351995461065}, {0.6585188932019111, 
       1.3180765759675057`}}]}, 
     {Arrowheads[{{0.03578770597780046, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.3901362147151344`}, {
       0.6585188932019111, 1.4670066424277222`}}]}, 
     {Arrowheads[{{0.041205486916323565`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.5262811788530906`}, {
       0.6585188932019111, 1.6165759640040513`}}]}, 
     {Arrowheads[{{0.04724005103156733, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.661786887874934}, {0.6585188932019111, 
       1.7667845406964935`}}]}, 
     {Arrowheads[{{0.053878711590164455`, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.7966533417806643`}, {
       0.6585188932019111, 1.9176323725050486`}}]}, 
     {Arrowheads[{{0.06111104205824093, 1.}}], 
      ArrowBox[{{0.6271953925123743, 1.9308805405702818`}, {
       0.6585188932019111, 2.069119459429717}}]}, 
     {Arrowheads[{{0.0151609303776158, 1.}}], 
      ArrowBox[{{0.6986239639409457, -0.00799068895141244}, {
       0.7299474646304825, 0.00799068895141244}}]}, 
     {Arrowheads[{{0.015288157198676927`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.1345468263476739}, {0.7299474646304825,
        0.1511674593666118}}]}, 
     {Arrowheads[{{0.015692708109828406`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.27644508653064725`}, {
       0.7299474646304825, 0.29498348489792414`}}]}, 
     {Arrowheads[{{0.016437407584498385`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.41770409159750765`}, {
       0.7299474646304825, 0.4394387655453495}}]}, 
     {Arrowheads[{{0.017608724217368595`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.558323841548255}, {0.7299474646304825, 
       0.5845333013088878}}]}, 
     {Arrowheads[{{0.019294509511460393`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.6983043363828894}, {0.7299474646304825,
        0.7302670921885391}}]}, 
     {Arrowheads[{{0.02156443352432618, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.8376455761014107}, {0.7299474646304825,
        0.8766401381843034}}]}, 
     {Arrowheads[{{0.024460865197415627`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 0.976347560703819}, {0.7299474646304825, 
       1.0236524392961808`}}]}, 
     {Arrowheads[{{0.02800098564230244, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.1144102901901143`}, {
       0.7299474646304825, 1.1713039955241709`}}]}, 
     {Arrowheads[{{0.032184799782129354`, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.2518337645602966`}, {
       0.7299474646304825, 1.3195948068682741`}}]}, 
     {Arrowheads[{{0.0370033526710525, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.388617983814366}, {0.7299474646304825, 
       1.4685248733284904`}}]}, 
     {Arrowheads[{{0.0424444849884244, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.5247629479523224`}, {
       0.7299474646304825, 1.6180941949048198`}}]}, 
     {Arrowheads[{{0.04849599728164735, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.6602686569741656`}, {
       0.7299474646304825, 1.7683027715972617`}}]}, 
     {Arrowheads[{{0.05514703349434578, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.795135110879896}, {0.7299474646304825, 
       1.9191506034058172`}}]}, 
     {Arrowheads[{{0.06238848326868566, 1.}}], 
      ArrowBox[{{0.6986239639409457, 1.9293623096695134`}, {
       0.7299474646304825, 2.0706376903304853`}}]}, 
     {Arrowheads[{{0.015870943487124655`, 1.}}], 
      ArrowBox[{{0.7700525353695171, -0.009668733631209053}, {
       0.8013760360590539, 0.009668733631209053}}]}, 
     {Arrowheads[{{0.016017439364559377`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.1328687816678773}, {0.8013760360590539,
        0.1528455040464084}}]}, 
     {Arrowheads[{{0.01647678455020938, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.27476704185085066`}, {
       0.8013760360590539, 0.29666152957772074`}}]}, 
     {Arrowheads[{{0.017303167034942217`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.416026046917711}, {0.8013760360590539, 
       0.44111681022514604`}}]}, 
     {Arrowheads[{{0.018570444851121574`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.5566457968684584}, {0.8013760360590539,
        0.5862113459886844}}]}, 
     {Arrowheads[{{0.020353145574496228`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.6966262917030926}, {0.8013760360590539,
        0.7319451368683356}}]}, 
     {Arrowheads[{{0.022710582705339256`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.8359675314216141}, {0.8013760360590539,
        0.8783181828641}}]}, 
     {Arrowheads[{{0.025679723283514203`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 0.9746695160240223}, {0.8013760360590539,
        1.0253304839759774`}}]}, 
     {Arrowheads[{{0.029276835532404673`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.1127322455103177`}, {
       0.8013760360590539, 1.1729820402039675`}}]}, 
     {Arrowheads[{{0.03350370175107075, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.2501557198805}, {0.8013760360590539, 
       1.3212728515480707`}}]}, 
     {Arrowheads[{{0.03835412294765342, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.3869399391345694`}, {
       0.8013760360590539, 1.470202918008287}}]}, 
     {Arrowheads[{{0.043818649457885696`, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.5230849032725258`}, {
       0.8013760360590539, 1.6197722395846164`}}]}, 
     {Arrowheads[{{0.04988733040498028, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.658590612294369}, {0.8013760360590539, 
       1.7699808162770585`}}]}, 
     {Arrowheads[{{0.05655102727672433, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.7934570662000995`}, {
       0.8013760360590539, 1.9208286480856138`}}]}, 
     {Arrowheads[{{0.06380188695990262, 1.}}], 
      ArrowBox[{{0.7700525353695171, 1.9276842649897168`}, {
       0.8013760360590539, 2.072315735010282}}]}, 
     {Arrowheads[{{0.016757765808407647`, 1.}}], 
      ArrowBox[{{0.8414811067980885, -0.011506592090033914`}, {
       0.8728046074876253, 0.011506592090033914`}}]}, 
     {Arrowheads[{{0.016922404295622088`, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.13103092320905244`}, {
       0.8728046074876253, 0.15468336250523326`}}]}, 
     {Arrowheads[{{0.01743314198154862, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.2729291833920258}, {0.8728046074876253,
        0.29849938803654563`}}]}, 
     {Arrowheads[{{0.01833568318389114, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.41418818845888616`}, {
       0.8728046074876253, 0.44295466868397093`}}]}, 
     {Arrowheads[{{0.01969197450115173, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.5548079384096335}, {0.8728046074876253,
        0.5880492044475093}}]}, 
     {Arrowheads[{{0.02156443352432618, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.6947884332442679}, {0.8728046074876253,
        0.7337829953271606}}]}, 
     {Arrowheads[{{0.024003202227743006`, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.8341296729627892}, {0.8728046074876253,
        0.8801560413229248}}]}, 
     {Arrowheads[{{0.027040475244854607`, 1.}}], 
      ArrowBox[{{0.8414811067980885, 0.9728316575651975}, {0.8728046074876253,
        1.027168342434802}}]}, 
     {Arrowheads[{{0.030691615252044384`, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.110894387051493}, {0.8728046074876253, 
       1.1748198986627925`}}]}, 
     {Arrowheads[{{0.03495983816766752, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.2483178614216752`}, {
       0.8728046074876253, 1.3231107100068957`}}]}, 
     {Arrowheads[{{0.03984128735023138, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.3851020806757446`}, {
       0.8728046074876253, 1.472040776467112}}]}, 
     {Arrowheads[{{0.04532888393912521, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.5212470448137008`}, {
       0.8728046074876253, 1.621610098043441}}]}, 
     {Arrowheads[{{0.05141469374859059, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.6567527538355442`}, {
       0.8728046074876253, 1.7718186747358833`}}]}, 
     {Arrowheads[{{0.05809115315699132, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.7916192077412745`}, {
       0.8728046074876253, 1.9226665065444384`}}]}, 
     {Arrowheads[{{0.06535158476035097, 1.}}], 
      ArrowBox[{{0.8414811067980885, 1.925846406530892}, {0.8728046074876253, 
       2.0741535934691067`}}]}, 
     {Arrowheads[{{0.01783176145288345, 1.}}], 
      ArrowBox[{{0.9129096782266599, -0.013504264327887022`}, {
       0.9442331789161967, 0.013504264327887022`}}]}, 
     {Arrowheads[{{0.018012947121910546`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.12903325097119933`}, {
       0.9442331789161967, 0.15668103474308637`}}]}, 
     {Arrowheads[{{0.018570444851121574`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.2709315111541727}, {0.9442331789161967,
        0.3004970602743987}}]}, 
     {Arrowheads[{{0.019542050472903482`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.41219051622103303`}, {
       0.9442331789161967, 0.444952340921824}}]}, 
     {Arrowheads[{{0.020978912873730087`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.5528102661717804}, {0.9442331789161967,
        0.5900468766853624}}]}, 
     {Arrowheads[{{0.02293275334705813, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.6927907610064147}, {0.9442331789161967,
        0.7357806675650136}}]}, 
     {Arrowheads[{{0.025445717670730623`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.8321320007249361}, {0.9442331789161967,
        0.882153713560778}}]}, 
     {Arrowheads[{{0.028545780253816752`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 0.9708339853273443}, {0.9442331789161967,
        1.0291660146726553`}}]}, 
     {Arrowheads[{{0.03224735561791704, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.1088967148136397`}, {
       0.9442331789161967, 1.1768175709006454`}}]}, 
     {Arrowheads[{{0.03655473158859168, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.246320189183822}, {0.9442331789161967, 
       1.3251083822447487`}}]}, 
     {Arrowheads[{{0.04146597043675802, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.3831044084378914`}, {
       0.9442331789161967, 1.474038448704965}}]}, 
     {Arrowheads[{{0.046976011388125356`, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.5192493725758478`}, {
       0.9442331789161967, 1.6236077702812943`}}]}, 
     {Arrowheads[{{0.05307868734965547, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.654755081597691}, {0.9442331789161967, 
       1.7738163469737365`}}]}, 
     {Arrowheads[{{0.05976784899792662, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.7896215355034215`}, {
       0.9442331789161967, 1.9246641787822918`}}]}, 
     {Arrowheads[{{0.06703789749944729, 1.}}], 
      ArrowBox[{{0.9129096782266599, 1.9238487342930388`}, {
       0.9442331789161967, 2.07615126570696}}]}, 
     {Arrowheads[{{0.019098641179794536`, 1.}}], 
      ArrowBox[{{0.9843382496552313, -0.015661750344768383`}, {
       1.015661750344768, 0.015661750344768383`}}]}, 
     {Arrowheads[{{0.01929450951146035, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.12687576495431796`}, {
       1.015661750344768, 0.1588385207599677}}]}, 
     {Arrowheads[{{0.019893456709352747`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.2687740251372913}, {1.015661750344768, 
       0.3026545462912801}}]}, 
     {Arrowheads[{{0.020926232554123916`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.4100330302041517}, {1.015661750344768, 
       0.4471098269387054}}]}, 
     {Arrowheads[{{0.022434536805357102`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.550652780154899}, {1.015661750344768, 
       0.5922043627022437}}]}, 
     {Arrowheads[{{0.02446086519741552, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.6906332749895334}, {1.015661750344768, 
       0.737938153581895}}]}, 
     {Arrowheads[{{0.027040475244854666`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.8299745147080547}, {1.015661750344768, 
       0.8843111995776594}}]}, 
     {Arrowheads[{{0.030197603171218123`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 0.9686764993104631}, {1.015661750344768, 
       1.0313235006895367`}}]}, 
     {Arrowheads[{{0.03394565413085823, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.1067392287967583`}, {1.015661750344768,
        1.1789750569175268`}}]}, 
     {Arrowheads[{{0.038289641214196236`, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.2441627031669407`}, {1.015661750344768,
        1.32726586826163}}]}, 
     {Arrowheads[{{0.0432291402825987, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.38094692242101}, {1.015661750344768, 
       1.4761959347218463`}}]}, 
     {Arrowheads[{{0.04876076356558188, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.5170918865589664`}, {1.015661750344768,
        1.6257652562981757`}}]}, 
     {Arrowheads[{{0.05487985905879056, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.6525975955808097`}, {1.015661750344768,
        1.7759738329906176`}}]}, 
     {Arrowheads[{{0.06158152340691432, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.7874640494865401`}, {1.015661750344768,
        1.9268216647991732`}}]}, 
     {Arrowheads[{{0.06886113006543731, 1.}}], 
      ArrowBox[{{0.9843382496552313, 1.9216912482761574`}, {1.015661750344768,
        2.078308751723841}}]}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.5},
  ImageSize->{651., Automatic},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.4347207169543457`*^9, 3.434722926902856*^9, 3.4347229733193827`*^9, 
   3.4353222497197313`*^9, {3.5129171723184*^9, 3.5129171887764*^9}, 
   3.570364981382561*^9},ExpressionUUID->"31e5a355-dfb4-4c95-9141-\
e671ce18fb8a"]
}, Open  ]],

Cell["\<\
The direction field is useful for two things. It is useful for explaining why \
the graph of the exact solution behaves the way it does, because the solution \
function has to follow the direction field. Later the direction field will \
also be useful for helping us to understand just why and how approximate \
solutions will diverge from the exact solution. Approximate solutions tend to \
diverge from the exact solution because once you make a mistake in estimate \
y[t] for a particular t the direction field will tend to push that \
approximate solution even further away from the exact solution.\
\>", "Text",
 CellChangeTimes->{{3.435335881557138*^9, 
  3.435336055396882*^9}},ExpressionUUID->"2d36c615-ab55-449d-a0c9-\
c44d40f3a68d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Euler's Method", "Subsubsection",
 CellChangeTimes->{{3.4347229800998516`*^9, 
  3.4347229838650427`*^9}},ExpressionUUID->"c52591d6-c93c-42f6-b92c-\
ac9e31fb23af"],

Cell["\<\
The following function implements a single step in the Euler method iteration \
derived in section 5.2.\
\>", "Text",
 CellChangeTimes->{{3.435336068570612*^9, 
  3.4353360950743427`*^9}},ExpressionUUID->"7385051f-3349-4203-a772-\
242417515084"],

Cell[BoxData[
 RowBox[{
  RowBox[{"euler", "[", 
   RowBox[{"{", 
    RowBox[{"t_", ",", "y_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t", " ", "+", " ", "h"}], ",", 
    RowBox[{"y", " ", "+", " ", 
     RowBox[{"h", "*", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "y"}], "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4347208100373716`*^9, 3.4347208612658443`*^9}, {
  3.4347209152596235`*^9, 3.434720917868698*^9}, {3.434722792059016*^9, 
  3.434722794683714*^9}, {3.434723338777277*^9, 3.4347233432923822`*^9}, {
  3.4353293174057703`*^9, 
  3.4353293207890434`*^9}},ExpressionUUID->"84e4f48d-b641-43f9-bfba-\
1e07b54ad4f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"y", "^", "2"}], " ", "+", " ", 
   RowBox[{"t", "^", "2", " "}]}]}]], "Input",
 CellChangeTimes->{{3.4347233298095603`*^9, 3.4347233353245497`*^9}, {
  3.5129172107724*^9, 
  3.5129172166692*^9}},ExpressionUUID->"c135e3ef-5b35-4552-8b41-76f5b8f22522"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.1"}]], "Input",
 CellChangeTimes->{{3.4347208716084027`*^9, 3.4347208738425207`*^9}, {
   3.435074700484375*^9, 3.435074702921875*^9}, 3.435074746421875*^9, {
   3.4350749853371596`*^9, 3.4350749863074536`*^9}, 3.435075089080347*^9, {
   3.4350754738124943`*^9, 3.435075478323208*^9}, 3.435075607898155*^9, {
   3.435322289938996*^9, 
   3.43532229692346*^9}},ExpressionUUID->"dae8a8bd-bc16-411f-9374-\
556e707c0227"],

Cell[BoxData["0.1`"], "Output",
 CellChangeTimes->{
  3.434720874498695*^9, 3.434722820133907*^9, 3.43507460015625*^9, 
   3.43507470421875*^9, 3.4350747840625*^9, 3.435074997293683*^9, 
   3.4350750901914897`*^9, 3.4350754800147257`*^9, 3.435075608978874*^9, {
   3.4353222660168147`*^9, 3.4353222973765907`*^9}, 3.4353293697211924`*^9, 
   3.5129172214896*^9},ExpressionUUID->"7e5b38c3-7c16-4938-9803-97c4e59048e8"]
}, Open  ]],

Cell["\<\
Using the single step Euler function with NestList generates a sequence of \
approximate solution points.\
\>", "Text",
 CellChangeTimes->{{3.4353361101389637`*^9, 
  3.435336136189506*^9}},ExpressionUUID->"b22880d6-dc9f-4043-b167-\
09b9d5964598"],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", " ", "=", " ", 
   RowBox[{"NestList", "[", 
    RowBox[{"euler", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5"}], "}"}], ",", "10"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4347208754204636`*^9, 3.4347208997301626`*^9}, {
   3.434720932460767*^9, 3.4347209336793766`*^9}, {3.43507470884375*^9, 
   3.43507471021875*^9}, {3.435074750234375*^9, 3.43507475290625*^9}, {
   3.4350750021295023`*^9, 3.4350750060889273`*^9}, {3.435075093462319*^9, 
   3.4350750954811563`*^9}, {3.4350754856374555`*^9, 3.435075485935037*^9}, 
   3.4350756122993455`*^9, {3.435322281829517*^9, 3.4353223042985544`*^9}, {
   3.512917228416*^9, 
   3.5129172291336*^9}},ExpressionUUID->"e0be180f-1f51-4b58-8767-\
3dcf8fc12dcc"],

Cell["\<\
To get a measure of the quality of the solution produced, we can examine the \
y value of the last point generated. That point corresponds to t = 1, so we \
can compare that approximate y with the exact y at 1.0.\
\>", "Text",
 CellChangeTimes->{{3.4353361429404564`*^9, 3.4353361913222675`*^9}, {
  3.5129172358884*^9, 
  3.5129172393672*^9}},ExpressionUUID->"16ef7ba7-ddd7-413b-8e4e-4bccd01542cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yEst", " ", "=", " ", 
  RowBox[{"points", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435075024790558*^9, 
  3.4350750396266627`*^9}},ExpressionUUID->"2cb93842-635f-4e64-a300-\
89ac173ca198"],

Cell[BoxData["1.344661874444219`"], "Output",
 CellChangeTimes->{3.4350750406595564`*^9, 3.4350750999570274`*^9, 
  3.4353223078298497`*^9, 3.43532937550095*^9, 
  3.5129172442344*^9},ExpressionUUID->"48ba0c2f-f3bd-40eb-9920-54ff83220cdf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yActual", " ", "=", " ", 
  RowBox[{"Y", "[", "1.0", "]"}]}]], "Input",
 CellChangeTimes->{{3.4350750464030695`*^9, 3.435075059173388*^9}, {
  3.435322310720512*^9, 3.4353223108142633`*^9}, {3.5129172764016*^9, 
  3.5129172770724*^9}},ExpressionUUID->"65f75f9b-a223-4156-9a5f-688ce3dbc2ce"],

Cell[BoxData["1.5800849793350842`"], "Output",
 CellChangeTimes->{
  3.4350750599871826`*^9, {3.4353223120174036`*^9, 3.435322319423748*^9}, 
   3.4353223616117883`*^9, 3.4353293781480474`*^9, 3.435502889890625*^9, 
   3.5129172462156*^9, 3.5129172781800003`*^9, 
   3.5135255042826*^9},ExpressionUUID->"43f2c41d-8c76-469b-877f-7c6344b00be0"]
}, Open  ]],

Cell["\<\
The difference between these two is quite substantial. This is not \
surprising, since the Euler method is a relatively crude method.\
\>", "Text",
 CellChangeTimes->{{3.4353361981826086`*^9, 
  3.4353362257021074`*^9}},ExpressionUUID->"71ce6a3b-befc-4425-8c5b-\
befe1bdccd7b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yActual", " ", "-", " ", "yEst"}]], "Input",
 CellChangeTimes->{{3.4350750694710217`*^9, 
  3.4350750742598915`*^9}},ExpressionUUID->"b98d4af8-4d9a-4360-a5ee-\
f9064bc4ccbc"],

Cell[BoxData["0.23542310489086526`"], "Output",
 CellChangeTimes->{{3.4350750750110865`*^9, 3.4350751044172487`*^9}, 
   3.435322364283697*^9, 3.4353293808421354`*^9, 
   3.512917282782*^9},ExpressionUUID->"83e9d7bd-9531-4440-92c9-282e4a13f080"]
}, Open  ]],

Cell["\<\
We can see the crudeness of the Euler estimate by plotting those estimated \
points against the exact solution.\
\>", "Text",
 CellChangeTimes->{{3.4353362381881933`*^9, 
  3.435336263113099*^9}},ExpressionUUID->"3a66c874-7487-4bd3-a65f-\
f38571d875c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot3", " ", "=", " ", 
  RowBox[{"ListPlot", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.434720923555543*^9, 3.4347209436626015`*^9}, {
   3.435074891782058*^9, 3.435074908449201*^9}, {3.4353223720962973`*^9, 
   3.4353223745338287`*^9}, 
   3.435329345959966*^9},ExpressionUUID->"e09033ca-382d-4d3f-b42d-\
5dea90d7df2d"],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{0., 0.5}, {0.1, 0.525}, {0.2, 0.5535625000000001}, {
    0.30000000000000004`, 0.588205644140625}, {0.4, 0.6318042321205138}, {0.5,
     0.687721890893053}, {0.6, 0.7600180308144047}, {0.7, 
    0.8537807715307052}, {0.7999999999999999, 0.9756749321142618}, {
    0.8999999999999999, 1.1348690894298787`}, {0.9999999999999999, 
    1.344661874444219}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.4347209368196397`*^9, 3.4347209445375004`*^9}, 
   3.435074635609375*^9, 3.43507471490625*^9, 3.435074756109375*^9, 
   3.43507478975*^9, 3.4350749096072936`*^9, 3.43507549478418*^9, 
   3.4350756187366743`*^9, 3.4353223765807295`*^9, 3.4353293837398458`*^9, 
   3.5129172857771997`*^9},ExpressionUUID->"72b80e71-6f7e-4fe4-9fcc-\
a1542529dcaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot3"}], "]"}]], "Input",
 CellChangeTimes->{{3.43472094692785*^9, 3.4347209522084913`*^9}, {
   3.435075502771902*^9, 3.4350755054188137`*^9}, 
   3.4353224283157673`*^9},ExpressionUUID->"864be9ff-a461-41eb-b117-\
5957fb647fed"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3s0VAkAx/HxyDPPajtDRItSxNFEUn6VSoVsYm0S1vSUtpJOWZGRwVaW
7agleeRVEiOP2jbSyrZlK3lPxbgzxhhjzE153JuMbf/4nu/5WIYf9zugymAw
fL72/3cckLY9GQ5wT86jvpKAuofJiX4mC7rbfboKvnpVftaNGuZm2DQl125U
IeD1qqc6l+mPsmLT7AuqBAL3TzVcYe5HgGXXtOYcAn0OKR5pzGgs0G1xmKdD
oGCBb/JFZhIMtFUyV80nwNGqWfoLMxPmpZXhecsI/LDnJu/DWDG2RMnpBwEE
dGc5wZ7mPMSy57rNJhCw3qWQPr1UC+eUrk2Vdwmcee2KrPGH+DgaVHyrj8DC
WiOBikojCqeVDpp6QtwXebxsXdcETsNRHnuTEE0RuaZ75M2I5hiytGOEmLBZ
b1Bx7B9wNcI71lQKoUqXG5patyA+lj2cLBPCeTbs/u7Kl+CdXRnJsRbhZRLr
9bPlrVC7n/NUO1yExRkjdJniDbwrWF4zpSKMTPULuhzbIVtrZFsgE6FY9qhF
/9cOVChfH3/lMgB9s1ukWNyJwtDvdf5KGcDlI3UHC6y6wXFTW/dd9wAmN5SL
D5/vQeO7YBc7RzGinZprv3nKh4Xo3wvVqWL0VzZfarN8h5L1cU4aCjGmIzpz
bH9+j8uH7qj6Bw5ixUZN5cFHvYi4bRLJbByEZ6HloXsLBWD8uNJGw1mCM2ah
S4TB/QjaMHgvulwCO3mAbo8PgZkXMv6Y1RDmGXzQav5MIH6VRZBP1RDUG3N4
394QIsulM0DoKsVR1qO32l4iXLHpnnnQI0X59vCCx5MimIm4jsbnhjExYmIo
uTaA5rIXel7mMtTt9lTL3CyGakmU01W+DOe3cfNrJWKcyq7a2pMxAsu+Hfwi
7iDYd79safWVY61LUibTSQLf92NJoStGEWzeSqt0SJDGDu6+pq7AREua6ARn
CA2MCq14pQJZ6iHRflZShEgSpoMmScwT1BWqNksR+YU1QcV+wJw4jr/ryWFM
SxuOnDQcA6MshCcylqGFkxDbVzSGqOu8NOMmGUprUwLm7vyIhhWpWkY/jYAx
cfp6GuMTjHZE2SXqy9FY2q5jVf0JvfZvOmLq5XhubO/VfX4cVXmwEoeMwuBw
MeHrM4F9PGcjM+UoaNrzcYLVJBK4Nzm9dxQgHBJ5fPMpVEjNcvS9SYTO/834
HZNCai43TLCTBNFtk8s2p7Dfb9S6cheJiyrnshVLKCyqr6/yCSTxMHlkWMuO
wsX0vc8uh5O4WlYyvdOdwmHn7DGdGBIxGowoSzaFJUnzt2mWkjjuP7pWXEFB
ueacXs9tEvi4zj23msLb0YH20nISNdZbngc+oJARWLNv6z0SiQOup9qeUJhd
7neKW09CUSBx6emg0NuWnqfWQSKdv3mh/WcKfyRPsTu6SKj7C/hKJYVMt1Db
Ij6JrHxvu3Y1Gl4lK2s3CUi4qMVfitOj8efZVy84wySeJ9piyILGNfvV6bvk
JMble4v+tqZxUnTD35IkcSzZNL9kOY1l3pH9T8ZJmOgtDYtg0VBX6SzOmCJR
xpHY+LrSIOrcIsI+k/jCMkld7U6jPqLIwXGGhMAwLsnMg8bvi3UnZmdJRJ5u
WaS5jcZ/eWJyfw==
      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0., 0.5}, {0.1, 0.525}, {0.2, 0.5535625000000001}, {
     0.30000000000000004`, 0.588205644140625}, {0.4, 0.6318042321205138}, {
     0.5, 0.687721890893053}, {0.6, 0.7600180308144047}, {0.7, 
     0.8537807715307052}, {0.7999999999999999, 0.9756749321142618}, {
     0.8999999999999999, 1.1348690894298787`}, {0.9999999999999999, 
     1.344661874444219}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.6000000000000001},
  ImageSize->{642., Automatic},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.4347209531302605`*^9, 3.43507465625*^9, 3.435074722234375*^9, {
   3.435074764265625*^9, 3.435074793359375*^9}, 3.435074914443113*^9, 
   3.435075506922385*^9, 3.4350756240149703`*^9, 3.4353223821120505`*^9, 
   3.4353224294564066`*^9, 3.4353293865435762`*^9, 
   3.5129172882108*^9},ExpressionUUID->"5c1b687f-6839-4c1f-9bf2-4664d28d51ea"]
}, Open  ]],

Cell["\<\
The only effective way to improve the quality of the Euler estimate is to use \
a smaller step size and compute more points. This second iteration through \
the method uses a step size 1/4 as small as above and computes 4 times as \
many points.\
\>", "Text",
 CellChangeTimes->{{3.4353362760521717`*^9, 
  3.4353363268552237`*^9}},ExpressionUUID->"aca838ba-2cf5-43d7-9000-\
a93a1aca28c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.025"}]], "Input",
 CellChangeTimes->{{3.4353223994560223`*^9, 3.4353224034248233`*^9}, {
  3.435322495050414*^9, 
  3.435322496269164*^9}},ExpressionUUID->"8035f4de-cf50-47b0-b3bc-\
8983063957f1"],

Cell[BoxData["0.025`"], "Output",
 CellChangeTimes->{3.4353224055186005`*^9, 3.435322497550414*^9, 
  3.5129172975708*^9},ExpressionUUID->"b55ff21d-4d84-4a6f-ae57-9b267c722605"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", " ", "=", " ", 
   RowBox[{"NestList", "[", 
    RowBox[{"euler", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5"}], "}"}], ",", "40"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4347208754204636`*^9, 3.4347208997301626`*^9}, {
   3.434720932460767*^9, 3.4347209336793766`*^9}, {3.43507470884375*^9, 
   3.43507471021875*^9}, {3.435074750234375*^9, 3.43507475290625*^9}, {
   3.4350750021295023`*^9, 3.4350750060889273`*^9}, {3.435075093462319*^9, 
   3.4350750954811563`*^9}, {3.4350754856374555`*^9, 3.435075485935037*^9}, 
   3.4350756122993455`*^9, {3.435322281829517*^9, 3.4353223042985544`*^9}, 
   3.435322455956664*^9, {3.435322502081664*^9, 3.435322502237914*^9}, {
   3.512917300488*^9, 
   3.5129173021884003`*^9}},ExpressionUUID->"db2fb540-240c-4056-bfff-\
590467f444f1"],

Cell["\<\
This is the new error estimate for t = 2.0. Note that the size of the error \
has decreased by roughly a factor of 4, just as the step size has decreased. \
This is what we expect, becuase the Euler method has an O[h] error estimate.\
\>", "Text",
 CellChangeTimes->{{3.435336340013074*^9, 
  3.4353364054269834`*^9}},ExpressionUUID->"3bd533a2-9b5c-4709-9739-\
5b4556ffe70a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yEst", " ", "=", " ", 
  RowBox[{"points", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435075024790558*^9, 
  3.4350750396266627`*^9}},ExpressionUUID->"57aa2c32-3b05-40ff-811e-\
75d7d788e878"],

Cell[BoxData["1.508058569378449`"], "Output",
 CellChangeTimes->{3.4350750406595564`*^9, 3.4350750999570274`*^9, 
  3.4353223078298497`*^9, 3.435322459378539*^9, 3.435322508378539*^9, 
  3.5129173062911997`*^9},ExpressionUUID->"9ac15f8e-a2b2-4e8b-9dab-\
866bbf823e02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yActual", " ", "-", " ", "yEst"}]], "Input",
 CellChangeTimes->{{3.4350750694710217`*^9, 
  3.4350750742598915`*^9}},ExpressionUUID->"a351fc21-fe01-4769-af7b-\
a5a5199bcaed"],

Cell[BoxData["0.07202640995663523`"], "Output",
 CellChangeTimes->{{3.4350750750110865`*^9, 3.4350751044172487`*^9}, 
   3.435322364283697*^9, 3.435322463675414*^9, 3.435322510909789*^9, 
   3.5129173076484003`*^9},ExpressionUUID->"f826f2f6-a357-47f6-9dae-\
19bf08d3802c"]
}, Open  ]],

Cell["Here is a plot of the Euler estimate with smaller step size.", "Text",
 CellChangeTimes->{{3.4353364384151583`*^9, 
  3.4353364492445307`*^9}},ExpressionUUID->"5bc2b747-eafb-404c-84c0-\
44c30862595a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot3", " ", "=", " ", 
  RowBox[{"ListPlot", "[", "points", "]"}]}]], "Input",
 CellChangeTimes->{{3.434720923555543*^9, 3.4347209436626015`*^9}, {
   3.435074891782058*^9, 3.435074908449201*^9}, {3.4353223720962973`*^9, 
   3.4353223745338287`*^9}, 
   3.4353364272263694`*^9},ExpressionUUID->"f710992d-e06c-4b8d-9a4a-\
49ba01a28ef8"],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxV0V9IU1EcB/C7VShU9m9SGxkYFdmTYa6ghy9F9KA2+k8lRAbbUh8aET0E
Uu3BGlIrCSqzlVChIYmulGWu1SAWaM4Wy2iue/fv3v25bc6aPbnqt+NDXzgc
zr/P7xxO+emzB/VKjuMq/rZ//f/h0XGPgirK/LgHll2nol4jj200b0droF+5
2Ta/7oCu5MCUxc+j4Lhgt1+rr1khMMeNsr4bW1w6AQbKe9SZXub2WAUUyn3A
kad8T7VPwGghUGSr+rOaEPKUcVyXVtbyhhDbP4H8lb6gYSjEfB+ubr15cmZJ
GGN0/DNedD0bmjWGYaR6fjySUrqkJwwF3W8S2u9HrbWVEdwn7yvcek1bpy2C
avK+4e1d20CjKopx8gKo97x6vLc9ikbygnCNlKz1rokxj0fZ1OK53u4YPtJ+
HpoR1S3rbpH5AuT9q3mtKOIMnQ9BbN55yHRHYvXCML92tKoPx1H4kwi6u940
rV+XYPUjGGy77LDmEugkLwr/+RO+lmCS3SeGwWN61YYvKWjJE9HwvHR4UpCx
gDwJ79RFLaVcGl7yJFzcN33Bqc7gAXlxDCgs5zLODJrIS2C2fdXSJ6ZpbCcv
CU9NxUOuMouF5KXQUVycq5vLYoK8FJYX6dP5wAxs5MkQlh03u8d+opm8HxiN
b7p96dMv7CAvjY0NvSqDnGPvzcAsOxcpy3/jD2KHOzc=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.4347209368196397`*^9, 3.4347209445375004`*^9}, 
   3.435074635609375*^9, 3.43507471490625*^9, 3.435074756109375*^9, 
   3.43507478975*^9, 3.4350749096072936`*^9, 3.43507549478418*^9, 
   3.4350756187366743`*^9, 3.4353223765807295`*^9, 3.435322473878539*^9, 
   3.435322514097289*^9, 
   3.51291731016*^9},ExpressionUUID->"54a5f9c3-181d-4147-b847-d7bcf9335b57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot3"}], "]"}]], "Input",
 CellChangeTimes->{{3.43472094692785*^9, 3.4347209522084913`*^9}, {
   3.435075502771902*^9, 3.4350755054188137`*^9}, 
   3.4353224283157673`*^9},ExpressionUUID->"ecfaa946-e0a2-4214-a9bf-\
caf40aa76bbd"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3s0VAkAx/HxyDPPajtDRItSxNFEUn6VSoVsYm0S1vSUtpJOWZGRwVaW
7agleeRVEiOP2jbSyrZlK3lPxbgzxhhjzE153JuMbf/4nu/5WIYf9zugymAw
fL72/3cckLY9GQ5wT86jvpKAuofJiX4mC7rbfboKvnpVftaNGuZm2DQl125U
IeD1qqc6l+mPsmLT7AuqBAL3TzVcYe5HgGXXtOYcAn0OKR5pzGgs0G1xmKdD
oGCBb/JFZhIMtFUyV80nwNGqWfoLMxPmpZXhecsI/LDnJu/DWDG2RMnpBwEE
dGc5wZ7mPMSy57rNJhCw3qWQPr1UC+eUrk2Vdwmcee2KrPGH+DgaVHyrj8DC
WiOBikojCqeVDpp6QtwXebxsXdcETsNRHnuTEE0RuaZ75M2I5hiytGOEmLBZ
b1Bx7B9wNcI71lQKoUqXG5patyA+lj2cLBPCeTbs/u7Kl+CdXRnJsRbhZRLr
9bPlrVC7n/NUO1yExRkjdJniDbwrWF4zpSKMTPULuhzbIVtrZFsgE6FY9qhF
/9cOVChfH3/lMgB9s1ukWNyJwtDvdf5KGcDlI3UHC6y6wXFTW/dd9wAmN5SL
D5/vQeO7YBc7RzGinZprv3nKh4Xo3wvVqWL0VzZfarN8h5L1cU4aCjGmIzpz
bH9+j8uH7qj6Bw5ixUZN5cFHvYi4bRLJbByEZ6HloXsLBWD8uNJGw1mCM2ah
S4TB/QjaMHgvulwCO3mAbo8PgZkXMv6Y1RDmGXzQav5MIH6VRZBP1RDUG3N4
394QIsulM0DoKsVR1qO32l4iXLHpnnnQI0X59vCCx5MimIm4jsbnhjExYmIo
uTaA5rIXel7mMtTt9lTL3CyGakmU01W+DOe3cfNrJWKcyq7a2pMxAsu+Hfwi
7iDYd79safWVY61LUibTSQLf92NJoStGEWzeSqt0SJDGDu6+pq7AREua6ARn
CA2MCq14pQJZ6iHRflZShEgSpoMmScwT1BWqNksR+YU1QcV+wJw4jr/ryWFM
SxuOnDQcA6MshCcylqGFkxDbVzSGqOu8NOMmGUprUwLm7vyIhhWpWkY/jYAx
cfp6GuMTjHZE2SXqy9FY2q5jVf0JvfZvOmLq5XhubO/VfX4cVXmwEoeMwuBw
MeHrM4F9PGcjM+UoaNrzcYLVJBK4Nzm9dxQgHBJ5fPMpVEjNcvS9SYTO/834
HZNCai43TLCTBNFtk8s2p7Dfb9S6cheJiyrnshVLKCyqr6/yCSTxMHlkWMuO
wsX0vc8uh5O4WlYyvdOdwmHn7DGdGBIxGowoSzaFJUnzt2mWkjjuP7pWXEFB
ueacXs9tEvi4zj23msLb0YH20nISNdZbngc+oJARWLNv6z0SiQOup9qeUJhd
7neKW09CUSBx6emg0NuWnqfWQSKdv3mh/WcKfyRPsTu6SKj7C/hKJYVMt1Db
Ij6JrHxvu3Y1Gl4lK2s3CUi4qMVfitOj8efZVy84wySeJ9piyILGNfvV6bvk
JMble4v+tqZxUnTD35IkcSzZNL9kOY1l3pH9T8ZJmOgtDYtg0VBX6SzOmCJR
xpHY+LrSIOrcIsI+k/jCMkld7U6jPqLIwXGGhMAwLsnMg8bvi3UnZmdJRJ5u
WaS5jcZ/eWJyfw==
      "]]}}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxV0V9IU1EcB/C7VShU9m9SGxkYFdmTYa6ghy9F9KA2+k8lRAbbUh8aET0E
Uu3BGlIrCSqzlVChIYmulGWu1SAWaM4Wy2iue/fv3v25bc6aPbnqt+NDXzgc
zr/P7xxO+emzB/VKjuMq/rZ//f/h0XGPgirK/LgHll2nol4jj200b0droF+5
2Ta/7oCu5MCUxc+j4Lhgt1+rr1khMMeNsr4bW1w6AQbKe9SZXub2WAUUyn3A
kad8T7VPwGghUGSr+rOaEPKUcVyXVtbyhhDbP4H8lb6gYSjEfB+ubr15cmZJ
GGN0/DNedD0bmjWGYaR6fjySUrqkJwwF3W8S2u9HrbWVEdwn7yvcek1bpy2C
avK+4e1d20CjKopx8gKo97x6vLc9ikbygnCNlKz1rokxj0fZ1OK53u4YPtJ+
HpoR1S3rbpH5AuT9q3mtKOIMnQ9BbN55yHRHYvXCML92tKoPx1H4kwi6u940
rV+XYPUjGGy77LDmEugkLwr/+RO+lmCS3SeGwWN61YYvKWjJE9HwvHR4UpCx
gDwJ79RFLaVcGl7yJFzcN33Bqc7gAXlxDCgs5zLODJrIS2C2fdXSJ6ZpbCcv
CU9NxUOuMouF5KXQUVycq5vLYoK8FJYX6dP5wAxs5MkQlh03u8d+opm8HxiN
b7p96dMv7CAvjY0NvSqDnGPvzcAsOxcpy3/jD2KHOzc=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.6000000000000001},
  ImageSize->{678., Automatic},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.4347209531302605`*^9, 3.43507465625*^9, 3.435074722234375*^9, {
   3.435074764265625*^9, 3.435074793359375*^9}, 3.435074914443113*^9, 
   3.435075506922385*^9, 3.4350756240149703`*^9, 3.4353223821120505`*^9, 
   3.4353224294564066`*^9, 3.435322479144164*^9, 3.435322518081664*^9, 
   3.5129173121568003`*^9},ExpressionUUID->"7bc66938-0c41-4539-aa1d-\
7f00d5ef36bd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Higher Order Taylor Methods", "Subsubsection",
 CellChangeTimes->{{3.434722997097893*^9, 
  3.4347230034565353`*^9}},ExpressionUUID->"0cc43104-3990-4842-97a9-\
523a39abdc59"],

Cell[TextData[{
 "The Euler method\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["y", 
     RowBox[{"i", "+", "1"}]], " ", "=", " ", 
    RowBox[{
     SubscriptBox["y", "i"], " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"f", "(", 
       RowBox[{
        SubscriptBox["t", "i"], " ", ",", " ", 
        SubscriptBox["y", "i"]}], ")"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"0799b5c2-1050-4aa1-8702-c3ffda99e06e"],
 "\ncan be written\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", 
     SubscriptBox["t", 
      RowBox[{"i", "+", "1"}]], ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"y", "(", 
      SubscriptBox["t", "i"], ")"}], "  ", "+", " ", 
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "i"], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["t", 
         RowBox[{"i", "+", "1"}]], " ", "-", " ", 
        SubscriptBox["t", "i"]}], ")"}], " "}]}]}], TraditionalForm]],
  ExpressionUUID->"2656f265-24cd-4668-9fc5-67c0e0ca09e3"],
 "\nwhich looks like a Taylor expansion for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "4d3992f9-2336-4707-8824-d68bd46e188f"],
 " out to the first derivative. If a Taylor expansion to one derivative is \
useful, perhaps it might be useful to expand this estimate out to higher \
derivatives."
}], "Text",
 CellChangeTimes->{{3.4353364783728857`*^9, 
  3.4353367704370685`*^9}},ExpressionUUID->"55605f96-be7b-47c4-91d0-\
395e44faeaff"],

Cell[TextData[{
 "For example, using a Taylor estimate out to the third derivative produces \
the estimate\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", 
     SubscriptBox["t", 
      RowBox[{"i", "+", "1"}]], ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"y", "(", 
      SubscriptBox["t", "i"], ")"}], "  ", "+", " ", 
     RowBox[{
      RowBox[{"y", "'"}], 
      RowBox[{"(", 
       SubscriptBox["t", "i"], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["t", 
         RowBox[{"i", "+", "1"}]], " ", "-", " ", 
        SubscriptBox["t", "i"]}], ")"}]}], "  ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"y", "\"\<(\!\(
\*SubscriptBox[\(t\), \(i\)]\))\>"}], 
       RowBox[{"2", "!"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["t", 
          RowBox[{"i", "+", "1"}]], " ", "-", " ", 
         SubscriptBox["t", "i"]}], ")"}], "2"]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["y", 
         RowBox[{"(", "3", ")"}]], "(", 
        SubscriptBox["t", "i"], ")"}], 
       RowBox[{"3", "!"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["t", 
          RowBox[{"i", "+", "1"}]], " ", "-", " ", 
         SubscriptBox["t", "i"]}], ")"}], "3"], " "}]}]}], TraditionalForm]],
  ExpressionUUID->"308a1b01-f408-4dc8-acf4-95aaee1fd99f"]
}], "Text",
 CellChangeTimes->{{3.435336777547217*^9, 
  3.4353369506597996`*^9}},ExpressionUUID->"676e44e0-349d-49eb-9e28-\
db25b158a49f"],

Cell[TextData[{
 "As before, we can begin to simplify this by substituting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{
     SubscriptBox["t", "i"], ",", 
     SubscriptBox["y", "i"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "8a167772-eaa9-42b5-a974-f0d13c8cfd37"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "'"}], 
    RowBox[{"(", 
     SubscriptBox["t", "i"], ")"}]}], TraditionalForm]],ExpressionUUID->
  "806b5b85-942c-4ce5-a520-af68957e03d7"],
 ", but what do we do with the higher order derivatives? The simple solution \
is to note that the second derivative is the derivative with respect to t of \
the first derivative, the third derivative is the derivative of the second \
derivative with respect to t, and so on. Further, to simplify these \
derivatives as we compute them we will want to substitute ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "642ac6de-3138-4922-8080-b9f23264ca65"],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]],ExpressionUUID->
  "a24bd76e-b21f-4943-bc09-c79a6cc672c3"],
 " whereever it occurs."
}], "Text",
 CellChangeTimes->{{3.4353369709276295`*^9, 
  3.435337155869624*^9}},ExpressionUUID->"aa48408b-adb9-4177-aa2a-\
7582bd3d8a55"],

Cell[TextData[{
 "The following two statements show how to implement this process in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". The first statement computes an nth order Taylor expansion for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "b619047a-8277-426a-8d45-6d75dde02a4e"],
 " about the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", 
    SubscriptBox["t", "k"]}], TraditionalForm]],ExpressionUUID->
  "b50bbe1e-0c38-4831-801a-ab23d4667237"],
 ". The second statement goes into that expansion and replaces all of the \
derivative terms with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"t", ",", " ", "y"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "9368ab21-7ed2-4ff1-98b9-c2df2d905d7d"],
 "."
}], "Text",
 CellChangeTimes->{{3.4353371716682177`*^9, 3.4353372371284637`*^9}, {
  3.513337192458533*^9, 3.513337322390933*^9}, {3.513507861076145*^9, 
  3.513507861247745*^9}},ExpressionUUID->"a4ae3dcb-8797-4e4f-bbc8-\
01de8337b93e"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"f", ",", "h"}], "]"}]], "Input",
 CellChangeTimes->{{3.4353294600984335`*^9, 3.4353294811968985`*^9}, 
   3.5133373296293325`*^9, {3.513338408915333*^9, 
   3.513338409367733*^9}},ExpressionUUID->"0e40de20-e7db-4850-b5f6-\
47baf0ad4e33"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp", " ", "=", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tk", ",", "4"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4353294844392014`*^9, 3.435329503955673*^9}, {
  3.5133373342937326`*^9, 
  3.513337352966933*^9}},ExpressionUUID->"1732cfb8-81a5-4ce6-9119-\
3f3488b094a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "[", "tk", "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "-", "tk"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]",
     MultilineFunction->None], "[", "tk", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "tk", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["y", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "tk", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["y", 
     TagBox[
      RowBox[{"(", "4", ")"}],
      Derivative],
     MultilineFunction->None], "[", "tk", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.513337355119733*^9},ExpressionUUID->"7bf49e7b-2dda-40c5-84ce-\
37341a77dbdc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exp", "//.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "n_", "]"}], "[", "y", "]"}], "[", "tk", 
      "]"}], "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"Dt", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", 
          RowBox[{"y", "[", "t", "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{"t", "\[Rule]", "tk"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4347216712037787`*^9, 3.4347216843116436`*^9}, {
   3.4347219188627453`*^9, 3.4347219219248924`*^9}, 3.4347219977911515`*^9, {
   3.4347223622647843`*^9, 3.434722364811366*^9}, {3.4347230274225245`*^9, 
   3.434723028031829*^9}, {3.434723154001691*^9, 3.4347231541266766`*^9}, 
   3.513337368473333*^9},ExpressionUUID->"7b2a74f8-8366-4d76-b374-\
b7a301d920d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "-", "tk"}], ")"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", 
     RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
  RowBox[{"y", "[", "tk", "]"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", 
       RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", 
       RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", 
             RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", 
             RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", 
        RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", 
             RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", 
           RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", 
              RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", 
             RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", 
          RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"3", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", 
       RowBox[{"y", "[", "tk", "]"}]}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.513337383074933*^9},ExpressionUUID->"6e7bb730-e9d8-41d0-b963-\
c7990a9abedf"]
}, Open  ]],

Cell[TextData[{
 "The second statement uses the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " replace repeatedly operator, //. This operator says to apply a replacement \
rule to an expression repeatedly until the expression no longer changes. This \
is what is required to fully replace all the derivatives of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "t", ")"}], TraditionalForm]],ExpressionUUID->
  "bf56f3c2-f201-4534-b7ad-7178de7c00a6"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "af2d858f-6aea-42bb-a52b-ecd99eb3188b"],
 "."
}], "Text",
 CellChangeTimes->{{3.513337390375733*^9, 
  3.5133374846777325`*^9}},ExpressionUUID->"25889a16-70f4-4271-924d-\
0841df901594"],

Cell["\<\
Now that we know how to do this, we can consolidate these two statements into \
a convenient function definition.\
\>", "Text",
 CellChangeTimes->{{3.513337513241333*^9, 
  3.513337532242133*^9}},ExpressionUUID->"156ccddf-7527-4ba1-ab33-\
738b40145b65"],

Cell[BoxData[
 RowBox[{
  RowBox[{"taylorFormula", "[", 
   RowBox[{"t_", ",", "w_", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s", ",", "exp", ",", "subs"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"exp", " ", "=", " ", 
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"y", "[", "s", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"subs", " ", "=", " ", 
      RowBox[{"exp", "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "k_", "]"}], "[", "y", "]"}], "[", "t",
            "]"}], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{"Dt", "[", 
            RowBox[{
             RowBox[{"f", "[", 
              RowBox[{"s", ",", 
               RowBox[{"y", "[", "s", "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s", ",", 
               RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{"s", "\[Rule]", "t"}], "}"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"subs", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "\[Rule]", "w"}], ",", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{"t", "+", "h"}]}]}], "}"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4347221412121277`*^9, 3.4347221796295767`*^9}, {
   3.4347222210154333`*^9, 3.4347222408725204`*^9}, 3.434722274134313*^9, {
   3.43472239788568*^9, 3.434722422211003*^9}, {3.4347231594698105`*^9, 
   3.4347231827015095`*^9}, {3.4347232156039686`*^9, 
   3.4347232159008093`*^9}, {3.435329514794677*^9, 3.4353295229709196`*^9}, {
   3.513337617464933*^9, 3.5133376649981327`*^9}, {3.513337709473733*^9, 
   3.513337814555333*^9}, {3.513337951102133*^9, 3.513337957295333*^9}, {
   3.513338265722933*^9, 3.513338370523733*^9}, {3.5133388378373327`*^9, 
   3.513338839225733*^9}},ExpressionUUID->"52289563-32f3-401a-8d6a-\
9dedcd6922e5"],

Cell["\<\
Here is what one of these estimates looks like. This is the Taylor estimate \
of order 2.\
\>", "Text",
 CellChangeTimes->{{3.435337300807266*^9, 
  3.435337320340641*^9}},ExpressionUUID->"622f6287-8dbe-4c41-8a52-\
16170f4f2947"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"taylorFormula", "[", 
  RowBox[{"t", ",", "y", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{
  3.513338844794933*^9},ExpressionUUID->"acdda1d1-dca5-4c17-986a-\
73ace1da7a59"],

Cell[BoxData[
 RowBox[{"y", "+", 
  RowBox[{"h", " ", 
   RowBox[{"f", "[", 
    RowBox[{"t", ",", "y"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["h", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "y"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.513337852806533*^9, 3.5133379609769325`*^9, 3.513338047151333*^9, {
   3.513338401442933*^9, 3.513338416278533*^9}, 
   3.5133548036879997`*^9},ExpressionUUID->"193ece58-eddb-4638-92d3-\
edffdb2a14fe"]
}, Open  ]],

Cell["\<\
When the Taylor estimate gets applied in practice, it is most often used out \
to order 4. The following function sets up the iteration to develop a series \
of point estimates with the Taylor method of order 4.\
\>", "Text",
 CellChangeTimes->{{3.435337338311346*^9, 
  3.435337396364537*^9}},ExpressionUUID->"d1e255bb-4993-4587-b865-\
1d913a107043"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"taylor4", "[", 
   RowBox[{"{", 
    RowBox[{"t_", ",", "y_"}], "}"}], "]"}], " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"t", "+", "h"}], ",", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"taylorFormula", "[", 
       RowBox[{"p", ",", "q", ",", "4"}], "]"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"p", "\[Rule]", "t"}], ",", 
       RowBox[{"q", "\[Rule]", "y"}]}], "}"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4347213643328843`*^9, 3.4347213757378206`*^9}, {
   3.4347215823546405`*^9, 3.4347216524871855`*^9}, {3.434721768739416*^9, 
   3.4347218489801717`*^9}, {3.4347219621390095`*^9, 3.434721964154402*^9}, {
   3.4347220282563915`*^9, 3.434722075844659*^9}, {3.4347221882223363`*^9, 
   3.434722197346285*^9}, {3.4347224361000276`*^9, 3.4347224368968105`*^9}, 
   3.434722647763141*^9, {3.513338117600933*^9, 3.513338173464533*^9}, 
   3.513338854404533*^9, 
   3.513354816792*^9},ExpressionUUID->"bac17b3d-43ff-45fb-b647-77f8dc9ff074"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"h", "+", "t"}], ",", 
   RowBox[{"y", "+", 
    RowBox[{"h", " ", 
     RowBox[{"f", "[", 
      RowBox[{"t", ",", "y"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["h", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     SuperscriptBox["h", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     SuperscriptBox["h", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"t", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"t", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"3", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "y"}], "]"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5133548181492*^9},ExpressionUUID->"f3143cfe-b4ff-4a50-b04e-529ad613671a"]
}, Open  ]],

Cell[TextData[{
 "Once we specify what ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "c874d7dc-1752-47d1-a1e8-521d051646ad"],
 " is and supply a value to use for ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "7b156b19-a75c-4d8b-a33a-36f82586ced8"],
 ", this becomes quite a bit more tractable."
}], "Text",
 CellChangeTimes->{{3.5133385134665327`*^9, 
  3.513338550547733*^9}},ExpressionUUID->"400c3e52-4aeb-4c4b-9dc7-\
c2dddb2f3d79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"y", "^", "2"}], " ", "+", " ", 
   RowBox[{"t", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4347212910757*^9, 3.4347213253530006`*^9}, {
  3.4347230753076324`*^9, 3.4347230790572004`*^9}, {3.5129173384428*^9, 
  3.5129173452756*^9}},ExpressionUUID->"8cac342c-f427-45ce-8832-529a4addde44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.1"}]], "Input",
 CellChangeTimes->{{3.4347225901760263`*^9, 3.4347225926444917`*^9}, {
  3.5129173548852*^9, 
  3.5129173556028*^9}},ExpressionUUID->"8dd7d663-129c-41c8-8670-7897af04a97a"],

Cell[BoxData["0.1`"], "Output",
 CellChangeTimes->{
  3.4347226536374645`*^9, 3.4347232817213507`*^9, 3.435329576894966*^9, {
   3.5129173491132*^9, 3.5129173563984003`*^9}, 3.513337989462533*^9, 
   3.513338188830533*^9, 3.513338557240133*^9, 
   3.51335484027*^9},ExpressionUUID->"a787268b-3c6e-4d7e-a88a-bfc57887f6ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"taylor4", "[", 
  RowBox[{"{", 
   RowBox[{"t", ",", "y"}], "}"}], "]"}]], "Input",ExpressionUUID->"beb62567-\
a813-420e-8674-58f2bc97b3d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.1`", "\[InvisibleSpace]", "+", "t"}], ",", 
   RowBox[{"y", "+", 
    RowBox[{"0.1`", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t", "2"], "+", 
       SuperscriptBox["y", "2"]}], ")"}]}], "+", 
    RowBox[{"0.005000000000000001`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "t"}], "+", 
       RowBox[{"2", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["t", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"0.0001666666666666667`", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["t", "2"], "+", 
           SuperscriptBox["y", "2"]}], ")"}], "2"]}], "+", 
       RowBox[{"2", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "t"}], "+", 
          RowBox[{"2", " ", "y", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["t", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"4.166666666666667`*^-6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["t", "2"], "+", 
          SuperscriptBox["y", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "t"}], "+", 
          RowBox[{"2", " ", "y", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["t", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "y", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["t", "2"], "+", 
              SuperscriptBox["y", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{"2", " ", "y", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "t"}], "+", 
             RowBox[{"2", " ", "y", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["t", "2"], "+", 
                SuperscriptBox["y", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.513338567411333*^9, 
  3.5133548447784*^9},ExpressionUUID->"d69f5753-be70-4643-a22a-255dffd4335e"]
}, Open  ]],

Cell["\<\
Here now is the result of iterating the fourth order Taylor formula starting \
from our usual initial conditions.\
\>", "Text",
 CellChangeTimes->{{3.5133385839005327`*^9, 
  3.513338603587733*^9}},ExpressionUUID->"25ec182a-0fc6-406c-9c76-\
e92f31175997"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"taylorPts", " ", "=", " ", 
  RowBox[{"NestList", "[", 
   RowBox[{"taylor4", ",", 
    RowBox[{"{", 
     RowBox[{"0.", ",", "0.5"}], "}"}], ",", "10"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434721854167074*^9, 3.434721865103314*^9}, {
   3.4347224470831375`*^9, 3.4347224840632515`*^9}, 
   3.4347226569339595`*^9},ExpressionUUID->"951f7e0b-8a3c-4d02-abfd-\
4be0d902a5df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1`", ",", "0.5266572916666666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2`", ",", "0.5583720720375175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30000000000000004`", ",", "0.5980579481769556`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", "0.6491605628636997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "0.7159062474128415`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6`", ",", "0.8037202983591263`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7`", ",", "0.9199555688288755`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7999999999999999`", ",", "1.07521884206048`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8999999999999999`", ",", "1.2859330200145687`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999999`", ",", "1.5796967785752898`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.513338190359333*^9, 3.513338614476533*^9, 
  3.5133548492088003`*^9},ExpressionUUID->"8c16bab9-a8bf-41a3-864d-\
6428cffdae30"]
}, Open  ]],

Cell["\<\
Plotting these estimated points against the exact solution shows that this is \
a pretty good estimate.\
\>", "Text",
 CellChangeTimes->{{3.4353374160385523`*^9, 
  3.4353374391035614`*^9}},ExpressionUUID->"61d1e865-d9c6-43aa-ab01-\
42c40b5aa3e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot4", " ", "=", " ", 
  RowBox[{"ListPlot", "[", "taylorPts", "]"}]}]], "Input",
 CellChangeTimes->{{3.434721952030799*^9, 3.4347219522651467`*^9}, {
  3.4347224711741114`*^9, 
  3.4347224899844446`*^9}},ExpressionUUID->"87962d8a-c0b4-47a7-8cf8-\
e5440a8d3a21"],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{0., 0.5}, {0.1, 0.5266572916666666}, {0.2, 
    0.5583720720375175}, {0.30000000000000004`, 0.5980579481769556}, {0.4, 
    0.6491605628636997}, {0.5, 0.7159062474128415}, {0.6, 
    0.8037202983591263}, {0.7, 0.9199555688288755}, {0.7999999999999999, 
    1.07521884206048}, {0.8999999999999999, 1.2859330200145687`}, {
    0.9999999999999999, 1.5796967785752898`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.4347224908437204`*^9, 3.4347226709792166`*^9, 
  3.434723102398261*^9, 3.434723288861153*^9, 3.435329583713134*^9, 
  3.5129173626696*^9, 
  3.513338194852133*^9},ExpressionUUID->"2e26a0bb-a22c-434e-a874-\
90d76fd93772"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot4"}], "]"}]], "Input",
 CellChangeTimes->{{3.434722492234185*^9, 
  3.434722498139755*^9}},ExpressionUUID->"cd767237-ae77-46e2-b277-\
92bc69f91e15"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3s0VAkAx/HxyDPPajtDRItSxNFEUn6VSoVsYm0S1vSUtpJOWZGRwVaW
7agleeRVEiOP2jbSyrZlK3lPxbgzxhhjzE153JuMbf/4nu/5WIYf9zugymAw
fL72/3cckLY9GQ5wT86jvpKAuofJiX4mC7rbfboKvnpVftaNGuZm2DQl125U
IeD1qqc6l+mPsmLT7AuqBAL3TzVcYe5HgGXXtOYcAn0OKR5pzGgs0G1xmKdD
oGCBb/JFZhIMtFUyV80nwNGqWfoLMxPmpZXhecsI/LDnJu/DWDG2RMnpBwEE
dGc5wZ7mPMSy57rNJhCw3qWQPr1UC+eUrk2Vdwmcee2KrPGH+DgaVHyrj8DC
WiOBikojCqeVDpp6QtwXebxsXdcETsNRHnuTEE0RuaZ75M2I5hiytGOEmLBZ
b1Bx7B9wNcI71lQKoUqXG5patyA+lj2cLBPCeTbs/u7Kl+CdXRnJsRbhZRLr
9bPlrVC7n/NUO1yExRkjdJniDbwrWF4zpSKMTPULuhzbIVtrZFsgE6FY9qhF
/9cOVChfH3/lMgB9s1ukWNyJwtDvdf5KGcDlI3UHC6y6wXFTW/dd9wAmN5SL
D5/vQeO7YBc7RzGinZprv3nKh4Xo3wvVqWL0VzZfarN8h5L1cU4aCjGmIzpz
bH9+j8uH7qj6Bw5ixUZN5cFHvYi4bRLJbByEZ6HloXsLBWD8uNJGw1mCM2ah
S4TB/QjaMHgvulwCO3mAbo8PgZkXMv6Y1RDmGXzQav5MIH6VRZBP1RDUG3N4
394QIsulM0DoKsVR1qO32l4iXLHpnnnQI0X59vCCx5MimIm4jsbnhjExYmIo
uTaA5rIXel7mMtTt9lTL3CyGakmU01W+DOe3cfNrJWKcyq7a2pMxAsu+Hfwi
7iDYd79safWVY61LUibTSQLf92NJoStGEWzeSqt0SJDGDu6+pq7AREua6ARn
CA2MCq14pQJZ6iHRflZShEgSpoMmScwT1BWqNksR+YU1QcV+wJw4jr/ryWFM
SxuOnDQcA6MshCcylqGFkxDbVzSGqOu8NOMmGUprUwLm7vyIhhWpWkY/jYAx
cfp6GuMTjHZE2SXqy9FY2q5jVf0JvfZvOmLq5XhubO/VfX4cVXmwEoeMwuBw
MeHrM4F9PGcjM+UoaNrzcYLVJBK4Nzm9dxQgHBJ5fPMpVEjNcvS9SYTO/834
HZNCai43TLCTBNFtk8s2p7Dfb9S6cheJiyrnshVLKCyqr6/yCSTxMHlkWMuO
wsX0vc8uh5O4WlYyvdOdwmHn7DGdGBIxGowoSzaFJUnzt2mWkjjuP7pWXEFB
ueacXs9tEvi4zj23msLb0YH20nISNdZbngc+oJARWLNv6z0SiQOup9qeUJhd
7neKW09CUSBx6emg0NuWnqfWQSKdv3mh/WcKfyRPsTu6SKj7C/hKJYVMt1Db
Ij6JrHxvu3Y1Gl4lK2s3CUi4qMVfitOj8efZVy84wySeJ9piyILGNfvV6bvk
JMble4v+tqZxUnTD35IkcSzZNL9kOY1l3pH9T8ZJmOgtDYtg0VBX6SzOmCJR
xpHY+LrSIOrcIsI+k/jCMkld7U6jPqLIwXGGhMAwLsnMg8bvi3UnZmdJRJ5u
WaS5jcZ/eWJyfw==
      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0., 0.5}, {0.1, 0.5266572916666666}, {0.2, 
     0.5583720720375175}, {0.30000000000000004`, 0.5980579481769556}, {0.4, 
     0.6491605628636997}, {0.5, 0.7159062474128415}, {0.6, 
     0.8037202983591263}, {0.7, 0.9199555688288755}, {0.7999999999999999, 
     1.07521884206048}, {0.8999999999999999, 1.2859330200145687`}, {
     0.9999999999999999, 1.5796967785752898`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.6000000000000001},
  ImageSize->{597., Automatic},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4347224989521613`*^9, 3.434723105366669*^9, 
  3.4347233043437443`*^9, 3.43532958601192*^9, 3.5129173641359997`*^9, 
  3.513338220685733*^9},ExpressionUUID->"a666b704-bbe9-4d96-b41a-\
35df181f2476"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 5.4 - Runge-Kutta rules", "Subsection",
 CellChangeTimes->{{3.513513886288745*^9, 
  3.513513894665945*^9}},ExpressionUUID->"c2a87ceb-72a8-42ff-aeba-\
3d4a954c8fce"],

Cell["\<\
Runge-Kutta type rules are very important solution methods for differential \
equations which are simpler and easier to apply than Taylor methods. In this \
section I will derive some of these Runge-Kutta type rules.\
\>", "Text",
 CellChangeTimes->{{3.5135139020291452`*^9, 
  3.513513963352745*^9}},ExpressionUUID->"24119a21-532b-45a3-849d-\
84cfaeb5690c"],

Cell["\<\
My approach here is somewhat different than the approach used in the text. \
This is intentional, because the text's discussion of this subject is rather \
vague and difficult to follow.\
\>", "Text",
 CellChangeTimes->{{3.513513966987545*^9, 
  3.513514006580345*^9}},ExpressionUUID->"63c4a41a-cae4-470d-8267-\
e2909afd7263"],

Cell[CellGroupData[{

Cell["Multi-stage methods", "Subsubsection",
 CellChangeTimes->{{3.513508192717745*^9, 
  3.513508198708145*^9}},ExpressionUUID->"f6903f23-b9b1-4714-808f-\
86c9c5fe38db"],

Cell[TextData[{
 "We have seen that the Euler method, which uses a single derivative \
estimate, is fairly crude and ineffective. The Taylor method is more \
effective because it uses higher order derivatives to refine the estimate. \
Another way to refine the estimate is to use multiple estimates for the first \
derivative developed at different points between ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "k"], TraditionalForm]],ExpressionUUID->
  "8d2de289-52c5-4129-9106-6e24cba4c2cf"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "k"], " ", "+", " ", "h"}], TraditionalForm]],
  ExpressionUUID->"d70bf290-42c3-4994-ad12-e35bce2f2c0e"],
 " instead of just the single first derivative that Euler's method uses."
}], "Text",
 CellChangeTimes->{{3.5135082405161448`*^9, 
  3.513508384394945*^9}},ExpressionUUID->"39968e6d-238f-4a18-bdc8-\
279419cd2d01"],

Cell[TextData[{
 "A ",
 StyleBox["multi-stage method",
  FontSlant->"Italic"],
 " computes a series of different estimates for the derivative ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "'"}], 
    RowBox[{"(", "t", ")"}]}], TraditionalForm]],ExpressionUUID->
  "1b542e0d-478c-4db6-b019-02f22eecaca9"],
 " developed at different points to improve on the crude, single derivative \
term that Euler's method uses."
}], "Text",
 CellChangeTimes->{{3.513508203762545*^9, 3.5135082290657454`*^9}, {
  3.5135083921169453`*^9, 
  3.5135084360933447`*^9}},ExpressionUUID->"fb6a70d4-ae14-4a9d-bfc4-\
35ab0caab331"],

Cell[TextData[{
 "In a multi-stage method with ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "5048ba76-eb72-4366-99cd-2a8934dd5ab8"],
 " stages we compute a series of derivative estimates ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "i"], TraditionalForm]],ExpressionUUID->
  "63f77e55-fb4c-48fe-9613-c15d6105022d"],
 ". These estimates are constructed recursively via the following scheme:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "1"], " ", "=", " ", 
    RowBox[{"f", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "f9f8c71e-8a13-4cab-b631-40deab7986db"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "i"], " ", "=", " ", 
    RowBox[{"f", "(", 
     RowBox[{
      RowBox[{
       SubscriptBox["t", "k"], " ", "+", " ", 
       RowBox[{
        SubscriptBox["\[Alpha]", "i"], " ", "h"}]}], ",", 
      RowBox[{
       SubscriptBox["y", "k"], " ", "+", " ", 
       RowBox[{"h", " ", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "1"}], 
          RowBox[{"i", "-", "1"}]], 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"i", ",", "j"}]], " ", 
          SubscriptBox["k", "j"]}]}]}]}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"4e1e31d1-9024-4d1f-aeed-c9baaf2ae0fb"],
 "\n\nWe then construct our ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", 
    RowBox[{
     SubscriptBox["t", "k"], ",", 
     SubscriptBox["y", "k"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "eefd5ba4-dbdf-4f54-b6a5-7db52dd96bf2"],
 " as a weighted average of the derivative estimates:\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "p"], 
     RowBox[{
      SubscriptBox["\[Gamma]", "i"], " ", 
      SubscriptBox["k", "i"]}]}]}], TraditionalForm]],ExpressionUUID->
  "6d8853c5-c92b-498e-8f97-3828c8b12c22"]
}], "Text",
 CellChangeTimes->{{3.513508605618545*^9, 3.5135088612401447`*^9}, {
   3.513508899038945*^9, 3.513508996772945*^9}, {3.5135109990329447`*^9, 
   3.5135110313405447`*^9}, 3.513511562972945*^9, {3.5135128326881447`*^9, 
   3.513512833234145*^9}},ExpressionUUID->"c008f9e7-b1eb-425c-822c-\
5c00476b1c37"],

Cell[TextData[{
 "As you can see, the main problem we will confront when constructing a \
multi-stage method is in picking the appropriate set of constants ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Alpha]", "i"], TraditionalForm]],ExpressionUUID->
  "8f629c7f-6a84-4d85-b8eb-b0b6f6beae84"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", 
    RowBox[{"i", ",", "j"}]], TraditionalForm]],ExpressionUUID->
  "db095bfd-1c79-4254-94e1-6d5b7bbace4b"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "i"], TraditionalForm]],ExpressionUUID->
  "86061101-f5cd-4d12-9020-fd1bcec8e2d6"],
 ". In the next section we will use a sophisticated technique designed to \
determine the correct constants to use in the multi-stage formula."
}], "Text",
 CellChangeTimes->{{3.513510835794545*^9, 3.5135109724505453`*^9}, {
  3.5135110412777452`*^9, 
  3.513511047112145*^9}},ExpressionUUID->"62945e57-c244-4dad-bdf0-\
cbbfa8c50a2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matching a multi-stage method to a Taylor method", "Subsubsection",
 CellChangeTimes->{{3.513511069357745*^9, 3.5135110794041452`*^9}, {
  3.5135259652002*^9, 
  3.5135259664482*^9}},ExpressionUUID->"7477762e-e19c-42f2-9095-12f3f9efbf16"],

Cell[TextData[{
 "The only effective methods we have seen so far are Taylor methods. Taylor \
methods have one weakness, and that is the difficulty in constructing the \
Taylor formulas. This is no big deal if we have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to do the heavy symbolic work for us, but nonetheless Taylor methods are \
not the most convenient methods around."
}], "Text",
 CellChangeTimes->{{3.513511087204145*^9, 
  3.5135111929877453`*^9}},ExpressionUUID->"73a5bdf3-aa1c-4c01-a537-\
2a0b4e79987b"],

Cell[TextData[{
 "Here once again is the function we developed above to help us construct ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["T", 
     RowBox[{"(", "n", ")"}]], "(", 
    RowBox[{
     SubscriptBox["t", "k"], ",", 
     SubscriptBox["y", "k"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "4c4299cf-8845-42c4-bc43-4bcc6c735114"]
}], "Text",
 CellChangeTimes->{{3.5135112016457453`*^9, 
  3.513511268632145*^9}},ExpressionUUID->"79cc4707-0c93-4e2e-ba1e-\
15b4c99e578a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"taylorFormula", "[", 
   RowBox[{"t_", ",", "w_", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"s", ",", "exp", ",", "subs"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"exp", " ", "=", " ", 
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"y", "[", "s", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"subs", " ", "=", " ", 
      RowBox[{"exp", "//.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Derivative", "[", "k_", "]"}], "[", "y", "]"}], "[", "t",
            "]"}], "\[Rule]", 
          RowBox[{"(", 
           RowBox[{"Dt", "[", 
            RowBox[{
             RowBox[{"f", "[", 
              RowBox[{"s", ",", 
               RowBox[{"y", "[", "s", "]"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s", ",", 
               RowBox[{"k", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{"s", "\[Rule]", "t"}], "}"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"subs", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "\[Rule]", "w"}], ",", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{"t", "+", "h"}]}]}], "}"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4347221412121277`*^9, 3.4347221796295767`*^9}, {
   3.4347222210154333`*^9, 3.4347222408725204`*^9}, 3.434722274134313*^9, {
   3.43472239788568*^9, 3.434722422211003*^9}, {3.4347231594698105`*^9, 
   3.4347231827015095`*^9}, {3.4347232156039686`*^9, 
   3.4347232159008093`*^9}, {3.435329514794677*^9, 3.4353295229709196`*^9}, {
   3.513337617464933*^9, 3.5133376649981327`*^9}, {3.513337709473733*^9, 
   3.513337814555333*^9}, {3.513337951102133*^9, 3.513337957295333*^9}, {
   3.513338265722933*^9, 3.513338370523733*^9}, {3.5133388378373327`*^9, 
   3.513338839225733*^9}},ExpressionUUID->"56f87ffb-2f14-454a-936c-\
72ada9e2b662"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bigT", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"taylorFormula", "[", 
       RowBox[{"tk", ",", "yk", ",", "n"}], "]"}], " ", "-", " ", "yk"}], 
     ")"}], "/", "h"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134475920334435`*^9, 3.5134476449019365`*^9}, {
   3.513448026385007*^9, 3.513448032484617*^9}, {3.513448199623311*^9, 
   3.5134482025717163`*^9}, 3.513449620707807*^9, {3.513508122751745*^9, 
   3.513508133032145*^9}},ExpressionUUID->"f2fb33ab-fd90-4c82-9b72-\
b5d35794e6ae"],

Cell["\<\
And here again for your edification is an example of a typical Taylor \
formula. In this case, the Taylor formula of order 4.\
\>", "Text",
 CellChangeTimes->{{3.513511284606545*^9, 
  3.5135113158377447`*^9}},ExpressionUUID->"f7f539dd-25ab-4196-8818-\
eb0a9158a91d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigT", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.513511323434945*^9, 
  3.513511328333345*^9}},ExpressionUUID->"6cdd8682-594f-4a92-aae2-\
d39035cc4d25"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "24"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["h", "3"], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["h", "2"], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"3", " ", "h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "3"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "3"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["h", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"12", "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "3"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"12", "+", 
          RowBox[{"4", " ", "h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["h", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", 
             RowBox[{"h", " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
          RowBox[{"h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"3", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.513511330111745*^9},ExpressionUUID->"bf4c5913-177c-40ca-b024-\
db29a0f6a634"]
}, Open  ]],

Cell["\<\
Our goal is to replace this nasty thing with an equivalent multi-stage \
method. As you will see below, multi-stage methods are much easier to compute \
in practice than Taylor methods. Provided we can get the constants in the \
multi-stage method right, we will have found a better approach.\
\>", "Text",
 CellChangeTimes->{{3.513511376178545*^9, 
  3.5135114753789454`*^9}},ExpressionUUID->"463c9587-af52-4bd6-8bb4-\
8c620decbcef"],

Cell[TextData[{
 "Since we have a bunch of constants to give values to, we should set \
ourselves a goal that helps us to know when we have the 'right' set of \
constants for the multi-stage method. Our goal here will simply be to make \
sure that the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " "}], TraditionalForm]],
  ExpressionUUID->"467a51b7-afed-4ee3-a90e-452165ed70f7"],
 " that the multi-stage method computes is as close as possible to the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " "}], TraditionalForm]],
  ExpressionUUID->"bbce1700-8c32-4a95-b7ec-ef319cf00ab3"],
 " that comes from the Taylor method we are trying to replace. In particular, \
for a Taylor method of order ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "154fb466-3535-4334-973f-775843a0746d"],
 ", which has truncation error ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["h", "n"], ")"}], TraditionalForm]],ExpressionUUID->
  "d8639aba-c981-4bce-9c22-ed5eedb266e2"],
 ", we will set ourselves the goal of making the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " "}], TraditionalForm]],
  ExpressionUUID->"04e57aa5-2770-482d-bd22-530c853454c3"],
 " of the multi-stage method differ from the Taylor ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " "}], TraditionalForm]],
  ExpressionUUID->"a4765ee8-80c1-45cd-b1e2-90e49b4f1584"],
 " by an error of size ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["h", "n"], ")"}], TraditionalForm]],ExpressionUUID->
  "4b796703-20f3-41b0-818d-37fe4a1346a3"],
 "."
}], "Text",
 CellChangeTimes->{{3.513511488373745*^9, 3.513511554595745*^9}, {
   3.513511585452545*^9, 3.513511728426545*^9}, 
   3.5135117875505447`*^9},ExpressionUUID->"012bfd30-7462-4c85-80e0-\
7c40507f6cdd"],

Cell[TextData[{
 "Our first challenge in this program is that the two methods do not look \
much like each other. The Taylor method, as you can see above, involves a \
tangled mass of partial derivatives of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "c4e0c147-2218-4ab2-862a-dd9e12476281"],
 " and factors of ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "5ad53c1d-b246-4e7f-bf3e-86a82cec2e07"],
 ". The multi-stage method involves nested applications of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "19e0a319-1149-46cf-92c6-b6fa44b4ee62"],
 ", but no partial derivatives. How do we reconcile these?"
}], "Text",
 CellChangeTimes->{{3.513511802495345*^9, 
  3.5135119153925447`*^9}},ExpressionUUID->"0e5ba330-3f93-4cfb-961f-\
fed071fa005c"],

Cell[TextData[{
 "The key to reconciling these is a multi-variate Taylor expansion of the \
function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "8cd96a0a-e1fd-4c19-a83b-53e2c99bcbef"],
 ". Just as we can form Taylor expansions of functions of one variable, we \
can make Taylor expansions of multivariate functions. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the same Series function we use to develop Taylor series in a single \
variable can also be used to make multivariate Taylor expansions for \
functions of two or more variables."
}], "Text",
 CellChangeTimes->{{3.513511920353345*^9, 3.513512021207345*^9}, {
  3.5135120555273447`*^9, 3.513512078381345*^9}, {3.5135260628873997`*^9, 
  3.5135260643382*^9}},ExpressionUUID->"72f592fa-8304-4b23-aef5-88466dd614e5"],

Cell[TextData[{
 "Here is an example. The next statement expands ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "cf446871-6002-4b07-88b6-1f010b399f26"],
 " as a power series in ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "80a7c1bb-22e5-4e20-bc9c-7f2f5fb384d4"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "83b8d8d0-2fe3-445e-b004-ce3ca8cc5d20"],
 " up to order 2 about ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["t", "k"], ",", 
     SubscriptBox["y", "k"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "179fac85-0ec7-4170-818d-9bd17226cea5"],
 "."
}], "Text",
 CellChangeTimes->{{3.513512083856945*^9, 3.513512158034945*^9}, {
  3.5135260841658*^9, 
  3.5135260876289997`*^9}},ExpressionUUID->"06f75dad-db17-4229-bdc1-\
edb0a3bf5461"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"t", ",", "y"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "tk", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "yk", ",", "2"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.513512140063745*^9, 
  3.513512141764145*^9}},ExpressionUUID->"caaa6588-acdc-4b99-8cc3-\
a6b969e14854"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "-", "tk"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"y", "-", "yk"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "tk"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", "yk"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "tk"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.513512160546545*^9},ExpressionUUID->"45e9041c-775f-43e0-ab46-\
78881b0039d3"]
}, Open  ]],

Cell[TextData[{
 "Lots of lovely partial derivatives here. Furthermore, if we simply replace \
the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "-", " ", 
    SubscriptBox["t", "k"]}], TraditionalForm]],ExpressionUUID->
  "f3eaf164-7625-46ba-ab4a-faed4f9ce7c0"],
 " here with ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "7aaf2ddd-2c44-4dc2-a462-6ddc36938afd"],
 " terms, we start to get something that looks a little more like the Taylor \
expression above. If we can replace all of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "5b954fd8-ab38-4076-84dc-ece1943ee000"],
 " terms in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", 
     RowBox[{
      SubscriptBox["t", "k"], ",", 
      SubscriptBox["y", "k"]}], ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "p"], 
     RowBox[{
      SubscriptBox["\[Gamma]", "i"], " ", 
      SubscriptBox["k", "i"]}]}]}], TraditionalForm]],ExpressionUUID->
  "4e8c0516-67f2-403b-add0-6d864ffcc329"],
 " with their power series expansions, we stand a pretty good chance of being \
able to construct an expression that we can match to the Taylor expression."
}], "Text",
 CellChangeTimes->{{3.513512166349745*^9, 3.513512234802545*^9}, {
  3.513512347543745*^9, 
  3.5135124533585453`*^9}},ExpressionUUID->"a63520bd-31f0-4dda-a386-\
8393eff4afce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A first example", "Subsubsection",
 CellChangeTimes->{{3.513512495306945*^9, 
  3.513512497974545*^9}},ExpressionUUID->"f7d76ac2-b078-4ead-a657-\
288120fd5f79"],

Cell["\<\
As our first example of this matching process, we will pick a fairly modest \
problem. Our goal is to construct a two-stage method that matches the Taylor \
formula of order 2.\
\>", "Text",
 CellChangeTimes->{{3.513512501390945*^9, 
  3.513512546584145*^9}},ExpressionUUID->"f27f1bfd-eea3-45bd-bf38-\
f9ff71114017"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigT", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.513512554025345*^9, 
  3.513512557379345*^9}},ExpressionUUID->"b25ca3a4-3358-40c7-a622-\
a58c39eb9a98"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.513512558767745*^9},ExpressionUUID->"5a6032b7-1046-4d4e-8074-\
206adfbaa964"]
}, Open  ]],

Cell[TextData[{
 "Here is how we would render the 2-stage method in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.513512570623745*^9, 
  3.513512586707345*^9}},ExpressionUUID->"b305519f-4f56-41e8-9309-\
1d841f29063c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "1", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513512589499745*^9, 3.5135125989065447`*^9}, 
   3.513512647391345*^9},ExpressionUUID->"c8e23b2c-1a71-4fb1-9245-\
31df57600df4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "2", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"tk", " ", "+", " ", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", "h"}]}], ",", 
    RowBox[{"yk", " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5135126078609447`*^9, 3.513512651462945*^9}, {
  3.513512816635745*^9, 
  3.513512817025745*^9}},ExpressionUUID->"04c4ad7c-bbc4-4ec4-a819-\
79408cfda594"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "  ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], " ", 
    RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], " ", 
    RowBox[{"k", "[", "2", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.513512656267745*^9, 
  3.513512681867345*^9}},ExpressionUUID->"0b64e2e8-04e2-4fab-b5f6-\
a299e50e4f3b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "1", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"tk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"a", "[", "2", "]"}]}]}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.513512683349345*^9, 
  3.513512824420145*^9},ExpressionUUID->"19e80ad3-49a3-40e5-8366-\
2f6b5047d777"]
}, Open  ]],

Cell[TextData[{
 "We will accomplish this matching process by replacing every ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "cc98c35b-9d34-4028-ae50-f1b7e4e834d4"],
 " in sight in phi with its power series expansion in ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "6383ab52-f7e5-4347-b268-c3ac0886ca5f"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "eec31674-96df-4491-9ee7-088d0caedc57"],
 " up to order 1. This will give us a set of partial derivative and ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "8e0ba782-24f1-48b3-8af8-a1ab336ae49c"],
 " terms that we can then try to match to the corresponding terms in the \
Taylor formula."
}], "Text",
 CellChangeTimes->{{3.513512710867745*^9, 3.513512786917745*^9}, {
  3.5135261359578*^9, 
  3.5135261558634*^9}},ExpressionUUID->"3b0a53ff-02ce-4618-9bbd-54b223887086"],

Cell[TextData[{
 "First we construct a generic series expansion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "f75cefc6-2a7a-4e39-9daa-b91e21a3697d"],
 "."
}], "Text",
 CellChangeTimes->{{3.5135128573517447`*^9, 
  3.5135128778501453`*^9}},ExpressionUUID->"e24f2a1e-c2bb-4862-ab2d-\
b0a3bdb59015"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fSeries", " ", "=", " ", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"t", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tk", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "yk", ",", "1"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513463208024893*^9, 3.5134632129389014`*^9}, {
  3.5134699709113717`*^9, 
  3.5134699761373806`*^9}},ExpressionUUID->"b6e93afd-c421-432b-842d-\
b3e24a23ed51"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "-", "tk"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"y", "-", "yk"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "tk"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.513467709913*^9, 3.51346922976967*^9, 
  3.5134700493327093`*^9, 
  3.513512881906145*^9},ExpressionUUID->"96981a2a-1a94-4c02-a71f-\
77e99096cd49"]
}, Open  ]],

Cell[TextData[{
 "We then construct equivalents for k[1] and k[2] where we use the series \
expansion to estimate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"t", ",", "y"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "ad28b124-4bd7-4ae0-a3b0-994dc0e60e49"],
 " for ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "ab99c498-ef02-4fad-96de-2970201373ee"],
 " near ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "k"], TraditionalForm]],ExpressionUUID->
  "67c74ff4-ea66-4ee4-990a-83cd70583eef"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "665b7e1a-f35f-4c6b-a1ee-41eb8ac8c712"],
 " near ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "k"], TraditionalForm]],ExpressionUUID->
  "4c2727b7-689e-452c-905e-d2d76fd556b2"],
 "."
}], "Text",
 CellChangeTimes->{{3.5135128883489447`*^9, 3.513512963665745*^9}, {
  3.5135261712918*^9, 
  3.5135261785146*^9}},ExpressionUUID->"1db3be61-3f06-4e6a-bd08-a3205ec842dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k1", " ", "=", " ", 
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134674903894143`*^9, 3.5134675099206486`*^9}, {
  3.513467718555415*^9, 3.513467727322631*^9}, {3.5135129670041447`*^9, 
  3.513512967284945*^9}},ExpressionUUID->"202744c2-fb0b-4687-b2d8-\
d3ab1fe56345"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"tk", ",", "yk"}], "]"}]], "Output",
 CellChangeTimes->{3.5134677286954327`*^9, 3.513469232671275*^9, 
  3.513470051859914*^9, 
  3.513512968938545*^9},ExpressionUUID->"701457ba-def1-4110-9c23-\
7d8436258f52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k2", " ", "=", " ", 
  RowBox[{"fSeries", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Rule]", 
      RowBox[{"tk", "+", 
       RowBox[{
        RowBox[{"a", "[", "2", "]"}], " ", "h"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"yk", "+", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", "h", " ", "k1"}]}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.513467730255436*^9, 3.513467785651133*^9}, {
  3.5135129715905447`*^9, 
  3.5135129928065453`*^9}},ExpressionUUID->"43005adc-296a-4fc9-9f4c-\
852b209eabe0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.513467805705569*^9, 3.5134692342936783`*^9, 
  3.513470053591517*^9, 
  3.513512999280545*^9},ExpressionUUID->"6ee5b5ab-6753-4115-9e88-\
6cdcc48796b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], "k1"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], " ", "k2"}]}]}]], "Input",
 CellChangeTimes->{{3.5135130114329453`*^9, 
  3.513513029513345*^9}},ExpressionUUID->"3b9e4bea-b0d9-4adc-ad53-\
d063e62885fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "1", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"a", "[", "2", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.513513030324545*^9},ExpressionUUID->"39817cf5-06c4-4253-8d28-\
0a5be497d8ec"]
}, Open  ]],

Cell[TextData[{
 "Our goal now is to make the difference between bigT[2] and phi as small as \
possible. In particular, we want to make this difference be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["h", "2"], ")"}], TraditionalForm]],ExpressionUUID->
  "af186f09-5328-4f5f-a98b-b55aa8b57cd7"],
 "."
}], "Text",
 CellChangeTimes->{{3.5135130348641453`*^9, 
  3.513513084768545*^9}},ExpressionUUID->"a082ee2b-68d7-4f32-a60f-\
a9494496f062"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diff", " ", "=", " ", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"bigT", "[", "2", "]"}], "-", " ", "phi"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.513467928087784*^9, 3.5134679427050095`*^9}, {
   3.5134700568987226`*^9, 3.5134700626083326`*^9}, 3.513470177596135*^9, {
   3.513513091975745*^9, 
   3.513513092802545*^9}},ExpressionUUID->"7a408aa0-f38d-40b1-b881-\
62930a6a7c3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "-", 
  RowBox[{
   RowBox[{"c", "[", "1", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{"h", " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["h", "2"], " ", 
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.513470178235736*^9, 
  3.513513094331345*^9},ExpressionUUID->"3894b622-884e-4152-97f8-\
8811fe7ee254"]
}, Open  ]],

Cell["\<\
Right away we see what we have to do to make the terms containing only \
f[tk,yk] vanish. We have to pick c[1] and c[2] to satisfy c[1] + c[2] == 1.\
\>", "Text",
 CellChangeTimes->{{3.513513133128545*^9, 
  3.513513185326145*^9}},ExpressionUUID->"e1bd810d-cd83-4562-80c8-\
7678a261be5b"],

Cell[TextData[{
 "The remaining terms involve various partial derivatives of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "3f5d8d39-e842-4831-b0b1-7f1fcd21364b"],
 ". Let us isolate those terms by using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Coefficient function to isolate the coefficients of specific terms in diff."
}], "Text",
 CellChangeTimes->{{3.513513198710945*^9, 3.5135132479133453`*^9}, 
   3.5135262247218*^9},ExpressionUUID->"eca5d6b5-cfa4-43e3-a42e-98222bce2bdc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"set1", " ", "=", " ", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"diff", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{"0", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"tk", ",", "yk"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134569865031652`*^9, 3.5134570065804005`*^9}, {
   3.5134614551154137`*^9, 3.513461458017019*^9}, 3.513464079863624*^9, 
   3.5134701208276353`*^9},ExpressionUUID->"33f945c6-9888-4e03-b8f6-\
4170b2bc496a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{"h", " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5134701216232367`*^9, 
  3.5135132549957447`*^9},ExpressionUUID->"820a7845-de2d-4a60-b26f-\
78f4fbcc718d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"set2", " ", "=", " ", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"diff", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{"1", ",", "0"}], "]"}], "[", "f", "]"}], "[", 
     RowBox[{"tk", ",", "yk"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513457124563408*^9, 3.513457127075012*^9}, {
   3.513461678411006*^9, 3.51346168053261*^9}, 3.5134640713460093`*^9, 
   3.5134701130588217`*^9},ExpressionUUID->"ec87c31d-5f27-427a-b73d-\
2458e4226e2d"],

Cell[BoxData[
 RowBox[{
  FractionBox["h", "2"], "-", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}]}]}]], "Output",
 CellChangeTimes->{3.513470114104023*^9, 
  3.513513271391345*^9},ExpressionUUID->"6da3a6ba-80e0-4a7c-99b5-\
49810417e70f"]
}, Open  ]],

Cell["\<\
We can read off from this two equations that will have to be satisfied.\
\>", "Text",
 CellChangeTimes->{{3.5135133000329447`*^9, 
  3.5135133168185453`*^9}},ExpressionUUID->"0719336d-977a-4ad4-8483-\
8f8514a8367a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns1", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"set1", ",", 
      RowBox[{"h", " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.5134614626502275`*^9, 3.513461570243616*^9}, {
   3.513461607948882*^9, 3.513461665228983*^9}, {3.5134634935677943`*^9, 
   3.5134635531286993`*^9}, {3.513463950071396*^9, 3.513463968463828*^9}, {
   3.513463998946282*^9, 3.5134640496931715`*^9}, 3.5134680731056385`*^9, 
   3.513468127144133*^9, {3.513469107309455*^9, 3.5134691437355185`*^9}, {
   3.5134698113074913`*^9, 3.513469814489897*^9}, 3.5134701072556114`*^9, 
   3.5134701465832806`*^9},ExpressionUUID->"f09f5ed3-fe44-447c-b906-\
95f3481f37fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "-", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"2", ",", "1"}], "]"}], " ", 
     RowBox[{"c", "[", "2", "]"}]}]}], "\[Equal]", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.5134701471448812`*^9, 
  3.513513320125745*^9},ExpressionUUID->"be85ad9c-fea2-4ea4-959e-\
6e36ce721890"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns2", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"set2", ",", "h"}], " ", "]"}], "\[Equal]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.5134611248784337`*^9, 3.513461194423356*^9}, {
   3.5134612287746162`*^9, 3.5134613419840155`*^9}, {3.513461372700469*^9, 
   3.5134613763040752`*^9}, {3.5134616924354305`*^9, 3.513461812259241*^9}, 
   3.5134642531643286`*^9, 3.5134643018364143`*^9, {3.5134643506956997`*^9, 
   3.513464378214148*^9}, {3.51346441354821*^9, 3.51346443061464*^9}, {
   3.513469154624338*^9, 3.513469171300767*^9}, {3.513469823225912*^9, 
   3.51346982757832*^9}, 3.5134701701705217`*^9, 
   3.513513324712145*^9},ExpressionUUID->"95610e60-0346-4fc5-8419-\
8f28a837c222"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], "-", 
    RowBox[{
     RowBox[{"a", "[", "2", "]"}], " ", 
     RowBox[{"c", "[", "2", "]"}]}]}], "\[Equal]", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5135133253517447`*^9},ExpressionUUID->"5dae322e-0458-4288-8ead-\
1617f1e5a943"]
}, Open  ]],

Cell["\<\
Finally, we assemble all of the required equations into one set and solve.\
\>", "Text",
 CellChangeTimes->{{3.513513339001745*^9, 
  3.513513358704545*^9}},ExpressionUUID->"791b8f37-6f86-4878-9200-\
bf51894ed4b6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allEqns", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "[", "1", "]"}], "+", 
       RowBox[{"c", "[", "2", "]"}]}], "\[Equal]", "1"}], "}"}], ",", "eqns1",
     ",", "eqns2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134693108742123`*^9, 3.5134693179254246`*^9}, {
   3.5134698358307343`*^9, 3.5134698406199427`*^9}, 3.5134701859109497`*^9, {
   3.513513331373345*^9, 
   3.5135133353669453`*^9}},ExpressionUUID->"9f031e80-8a75-49ec-862b-\
7295087a3558"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "+", 
     RowBox[{"c", "[", "2", "]"}]}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "2", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"c", "[", "2", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.513469319157827*^9, 3.513470189218155*^9, 
  3.513513361574945*^9},ExpressionUUID->"2a5b95a6-766b-4665-ab1e-\
04f65833e1b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", " ", "=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{"allEqns", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], ",", 
      RowBox[{"c", "[", "2", "]"}], ",", 
      RowBox[{"a", "[", "2", "]"}], ",", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513470199373773*^9, 3.5134702196382084`*^9}, {
  3.5135133658805447`*^9, 3.513513384678545*^9}, {3.513513564296945*^9, 
  3.513513566543345*^9}},ExpressionUUID->"e53f2a9f-a93a-4410-b11e-\
9717fdeb2e4a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"svars\"\>"}], ":", 
  " ", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Equations may not give solutions \
for all \\\\\\\\\\\\\\\"solve\\\\\\\\\\\\\\\" variables.\\\\\\\"\\\", \
\\\"MT\\\"]\\) \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/svars\\\", ButtonNote -> \
\\\"Solve::svars\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.5134702206678104`*^9, 3.513513388500545*^9, {3.513513706061945*^9, 
   3.513513719368745*^9}},ExpressionUUID->"4e61f886-93e4-4197-aa81-\
a52dcfa67968"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"1", "-", 
      RowBox[{"c", "[", "2", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"a", "[", "2", "]"}], "\[Rule]", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "2", "]"}]}]]}], ",", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"2", ",", "1"}], "]"}], "\[Rule]", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"c", "[", "2", "]"}]}]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5134702206678104`*^9, 3.5135133885161448`*^9, {3.513513706077545*^9, 
   3.513513719368745*^9}},ExpressionUUID->"6aa38d3f-2923-46fc-83f2-\
316f28ffe6c8"]
}, Open  ]],

Cell["\<\
Since the equations are under-determined (we have three equations in four \
unknowns), the solution comes back containing a free parameter. Basically, we \
are free to choose c[2] to be any number between 0 and 1, inclusive. Once we \
have selected c[2] the remaining constants in the multi-stage methods are set.\
\>", "Text",
 CellChangeTimes->{{3.5135133979697447`*^9, 
  3.5135135000249453`*^9}},ExpressionUUID->"1e6523f5-6592-43d7-88c4-\
3f26b7b5332e"],

Cell[TextData[{
 "Two special cases of the two stage method are commonly used. The ",
 StyleBox["midpoint rule",
  FontSlant->"Italic"],
 " uses c[2] = 1, and the ",
 StyleBox["modified Euler rule",
  FontSlant->"Italic"],
 " uses c[2] = 1/2."
}], "Text",
 CellChangeTimes->{{3.5134704764624596`*^9, 3.5134705116717215`*^9}, {
  3.513513771176345*^9, 3.5135137789919453`*^9}, {3.5135262656717997`*^9, 
  3.5135262918642*^9}},ExpressionUUID->"d8c42544-236d-46b8-834d-c8ee4611cfd4"],

Cell["Here is the phi for the midpoint rule.", "Text",
 CellChangeTimes->{{3.513513519322145*^9, 
  3.513513529555745*^9}},ExpressionUUID->"c96070b9-7fc8-4d00-8fea-\
a5d6d08472b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", "2", "]"}], " ", "=", " ", "1"}]], "Input",
 CellChangeTimes->{{3.513513576683345*^9, 3.513513578617745*^9}, {
  3.513513676780745*^9, 
  3.513513677888345*^9}},ExpressionUUID->"3a4b384a-a0eb-4f19-bc7e-\
f0cece658112"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.513513678808745*^9, 
  3.513513728026745*^9},ExpressionUUID->"31244792-dfb2-49fc-b6db-\
f7ab3b651d28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "  ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], " ", 
      RowBox[{"k", "[", "2", "]"}]}]}], ")"}], "/.", 
   RowBox[{"soln", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5135136856727448`*^9, 
  3.5135136998531446`*^9}},ExpressionUUID->"2df13a48-c288-4048-80f3-\
a15c51473311"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{
    FractionBox["h", "2"], "+", "tk"}], ",", 
   RowBox[{"yk", "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "h", " ", 
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]], "Output",
 CellChangeTimes->{{3.513513692443145*^9, 
  3.513513729461945*^9}},ExpressionUUID->"93cac504-22c2-4534-9104-\
fe4ae6e7c74f"]
}, Open  ]],

Cell["and the phi for the modified Euler rule.", "Text",
 CellChangeTimes->{{3.5135137365755453`*^9, 
  3.513513745576745*^9}},ExpressionUUID->"5ce556b3-47c2-49d9-aa6d-\
9822f3ebbb70"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", "2", "]"}], " ", "=", " ", 
  RowBox[{"1", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.513513748634345*^9, 
  3.513513753735545*^9}},ExpressionUUID->"d8d60e39-5bfb-4a6a-a661-\
6cfe35afef48"],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{
  3.5135137544999447`*^9},ExpressionUUID->"31464a62-cdd0-479c-baa8-\
6aa939326b66"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "  ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], " ", 
      RowBox[{"k", "[", "2", "]"}]}]}], ")"}], "/.", 
   RowBox[{"soln", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",ExpressionUUID->"c03962be-\
f818-47b8-87bd-dbc0d3c3d12c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"h", "+", "tk"}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5135137620659447`*^9},ExpressionUUID->"8ff4637f-3279-4cff-b5bb-\
f3ab3369db7b"]
}, Open  ]],

Cell["\<\
Both of these methods have the great advantage of being much easier to work \
with in practice than the Taylor method of order 2 they replace.\
\>", "Text",
 CellChangeTimes->{{3.513513802251545*^9, 
  3.513513834356345*^9}},ExpressionUUID->"8904d6b2-8d4f-41a0-91e7-\
957e73be2abd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigT", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.513513836524745*^9, 
  3.513513839738345*^9}},ExpressionUUID->"17011391-248f-4129-96f8-\
e99bd888e47b"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5135138407211447`*^9},ExpressionUUID->"375eeac9-09cf-4b93-8b93-\
e43476cc33db"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4 Multi-step methods", "Subsubsection",
 CellChangeTimes->{{3.5134703378718166`*^9, 
  3.513470353549844*^9}},ExpressionUUID->"e2d17fcd-9694-45bc-91de-\
7b2bbf451815"],

Cell["\<\
The order 2 multi-stage methods we developed above are an improvement on \
Euler's method, but they are not strong enough for industrial use. To get \
acceptable results, we have to go to at least order 4 in the Taylor method. \
The details are largely similar to what we saw in the section above, but the \
algebra does scale up quite a bit.\
\>", "Text",
 CellChangeTimes->{{3.5135238306026*^9, 3.5135238881042*^9}, {
   3.5135240552298*^9, 3.5135241190182*^9}, 
   3.5135263292106*^9},ExpressionUUID->"b2b9e951-57ba-46b8-a6b0-a2db4da3c9ab"],

Cell["We start by defining k terms for a four-stage process.", "Text",
 CellChangeTimes->{{3.5135242001382*^9, 
  3.5135242181406*^9}},ExpressionUUID->"2eb4f897-526c-4d94-9fc8-c720ffcb20ee"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "1", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513512589499745*^9, 3.5135125989065447`*^9}, 
   3.513512647391345*^9},ExpressionUUID->"168935a4-95a3-4636-b846-\
1d9565a90874"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "2", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"tk", " ", "+", " ", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", "h"}]}], ",", 
    RowBox[{"yk", " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5135126078609447`*^9, 3.513512651462945*^9}, {
  3.513512816635745*^9, 
  3.513512817025745*^9}},ExpressionUUID->"4bda2408-61a1-43b2-a578-\
31186b0e405c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "3", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"tk", " ", "+", " ", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", "h"}]}], ",", 
    RowBox[{"yk", " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"k", "[", "2", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513524233959*^9, 
  3.5135242633806*^9}},ExpressionUUID->"c88ea32c-c98d-4262-8b6a-cee9dc8692d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", "4", "]"}], " ", ":=", " ", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"tk", " ", "+", " ", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", "h"}]}], ",", 
    RowBox[{"yk", " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"k", "[", "2", "]"}]}], " ", "+", " ", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"k", "[", "3", "]"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5135242666098003`*^9, 
  3.5135242968269997`*^9}},ExpressionUUID->"710e8917-25b2-4a18-a2d8-\
a0353db9e9e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "  ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], " ", 
    RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"c", "[", "2", "]"}], " ", 
    RowBox[{"k", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], " ", 
    RowBox[{"k", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{
    RowBox[{"c", "[", "4", "]"}], " ", 
    RowBox[{"k", "[", "4", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.513512656267745*^9, 3.513512681867345*^9}, {
  3.5135243026458*^9, 
  3.5135243124737997`*^9}},ExpressionUUID->"b325b529-5931-4cdb-89d5-\
29b29feadf85"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "1", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"tk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"a", "[", "2", "]"}]}]}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"tk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"a", "[", "3", "]"}]}]}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{"tk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"a", "[", "2", "]"}]}]}], ",", 
         RowBox[{"yk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"b", "[", 
            RowBox[{"2", ",", "1"}], "]"}], " ", 
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"tk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"a", "[", "4", "]"}]}]}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{"tk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"a", "[", "2", "]"}]}]}], ",", 
         RowBox[{"yk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"b", "[", 
            RowBox[{"2", ",", "1"}], "]"}], " ", 
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{"tk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"a", "[", "3", "]"}]}]}], ",", 
         RowBox[{"yk", "+", 
          RowBox[{"h", " ", 
           RowBox[{"b", "[", 
            RowBox[{"3", ",", "1"}], "]"}], " ", 
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
          RowBox[{"h", " ", 
           RowBox[{"b", "[", 
            RowBox[{"3", ",", "2"}], "]"}], " ", 
           RowBox[{"f", "[", 
            RowBox[{
             RowBox[{"tk", "+", 
              RowBox[{"h", " ", 
               RowBox[{"a", "[", "2", "]"}]}]}], ",", 
             RowBox[{"yk", "+", 
              RowBox[{"h", " ", 
               RowBox[{"b", "[", 
                RowBox[{"2", ",", "1"}], "]"}], " ", 
               RowBox[{"f", "[", 
                RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]}], 
        "]"}]}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.513512683349345*^9, 3.513512824420145*^9, 
  3.5135243143926*^9},ExpressionUUID->"baf83207-40e8-4657-ab53-6773f552671c"]
}, Open  ]],

Cell["Our goal is to match the Taylor method of order 4.", "Text",
 CellChangeTimes->{{3.5135243331126003`*^9, 
  3.5135243476205997`*^9}},ExpressionUUID->"0ae40e10-0100-442e-ad9a-\
8d90fdab9f8e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigT", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.5135243497578*^9, 
  3.5135243534082003`*^9}},ExpressionUUID->"de3ccf7a-9c7f-4332-9ea4-\
4410f348e74f"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "24"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["h", "3"], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["h", "2"], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"3", " ", "h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"24", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["h", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "3"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "3"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["h", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
       RowBox[{"h", " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"12", "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["h", "3"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"12", "+", 
          RowBox[{"4", " ", "h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["h", "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["h", "2"], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"h", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", 
             RowBox[{"h", " ", 
              RowBox[{
               SuperscriptBox["f", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
          RowBox[{"h", " ", 
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"3", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.513524354391*^9},ExpressionUUID->"431da15b-2bb9-47ed-babf-801708124070"]
}, Open  ]],

Cell[TextData[{
 "Note that this taylor function includes derivatives of up to order 2. To \
generate those derivatives from our multi-step formula we will have to expand \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"t", ",", "y"}], ")"}], TraditionalForm]],ExpressionUUID->
  "cd204a7c-c4ae-4edc-9fe1-aa8c0267a089"],
 " to order 2 in both variables."
}], "Text",
 CellChangeTimes->{{3.5135243666994*^9, 
  3.5135244357762003`*^9}},ExpressionUUID->"ffd7f579-7c8e-4027-afa9-\
775762bd7253"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fSeries", " ", "=", " ", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"t", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "tk", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "yk", ",", "2"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.513463208024893*^9, 
  3.5134632129389014`*^9}},ExpressionUUID->"23edb18f-d946-482c-9bcb-\
ca14b42f5967"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "-", "tk"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"y", "-", "yk"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "tk"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", "yk"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "tk"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", "-", "tk"}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.513467709913*^9, 3.51346922976967*^9, 
  3.5135244394266*^9},ExpressionUUID->"c9b8959d-bb55-4540-baed-0597d6ac0917"]
}, Open  ]],

Cell["Next we construct expansions for k[1] through k[4].", "Text",
 CellChangeTimes->{{3.5135244797214003`*^9, 
  3.513524493543*^9}},ExpressionUUID->"28c7c7cc-b85b-4128-a10c-761c6f631315"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k1", " ", "=", " ", 
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134674903894143`*^9, 3.5134675099206486`*^9}, {
  3.513467718555415*^9, 3.513467727322631*^9}, {3.5135129670041447`*^9, 
  3.513512967284945*^9}},ExpressionUUID->"9ffbf96e-e3ff-46da-8488-\
6fdae6105c4a"],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"tk", ",", "yk"}], "]"}]], "Output",
 CellChangeTimes->{3.5134677286954327`*^9, 3.513469232671275*^9, 
  3.513470051859914*^9, 3.513512968938545*^9, 
  3.5135245002978*^9},ExpressionUUID->"3ed504aa-78d6-4054-8df7-eaeec9207090"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k2", " ", "=", " ", 
  RowBox[{"fSeries", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Rule]", 
      RowBox[{"tk", "+", 
       RowBox[{
        RowBox[{"a", "[", "2", "]"}], " ", "h"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"yk", "+", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"2", ",", "1"}], "]"}], " ", "h", " ", "k1"}]}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.513467730255436*^9, 3.513467785651133*^9}, {
  3.5135129715905447`*^9, 
  3.5135129928065453`*^9}},ExpressionUUID->"9b305fe9-b98a-4da1-b2b4-\
a5a6cb186217"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "h", " ", 
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.513467805705569*^9, 3.5134692342936783`*^9, 
  3.513470053591517*^9, 3.513512999280545*^9, 
  3.5135245079574003`*^9},ExpressionUUID->"b8f6a0cf-0b10-4f42-bb5a-\
36e656454130"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", " ", "=", " ", 
  RowBox[{"fSeries", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Rule]", 
      RowBox[{"tk", "+", 
       RowBox[{
        RowBox[{"a", "[", "3", "]"}], " ", "h"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"yk", "+", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"3", ",", "1"}], "]"}], " ", "h", " ", "k1"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"3", ",", "2"}], "]"}], " ", "h", " ", "k2"}]}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5135245099698*^9, 
  3.5135245416689997`*^9}},ExpressionUUID->"bd4aa363-1f16-4644-8cc7-\
f74f054f3b5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "3", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "3", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"a", "[", "2", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "2", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"b", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}], "+", 
           RowBox[{"h", " ", 
            RowBox[{"a", "[", "2", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "2", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"b", "[", 
           RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"f", "[", 
           RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", "h", " ", 
            RowBox[{"a", "[", "2", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "2", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "h", " ", 
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "3", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"a", "[", "2", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox["h", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "2", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"b", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          RowBox[{"f", "[", 
           RowBox[{"tk", ",", "yk"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}], "+", 
            RowBox[{"h", " ", 
             RowBox[{"a", "[", "2", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "2", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["h", "2"], " ", 
          SuperscriptBox[
           RowBox[{"b", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", "h", " ", 
             RowBox[{"a", "[", "2", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "2", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.513524544399*^9},ExpressionUUID->"7c0a9b0e-6739-47b5-9b72-2f519cfe9fe6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", " ", "=", "  ", 
  RowBox[{"fSeries", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", "\[Rule]", 
      RowBox[{"tk", "+", 
       RowBox[{
        RowBox[{"a", "[", "4", "]"}], " ", "h"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"yk", "+", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"4", ",", "1"}], "]"}], " ", "h", " ", "k1"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"4", ",", "2"}], "]"}], " ", "h", " ", "k2"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"b", "[", 
         RowBox[{"4", ",", "3"}], "]"}], " ", "h", " ", "k3"}]}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5135245466142*^9, 
  3.5135245739142*^9}},ExpressionUUID->"f1ce153b-3b31-4b49-99f0-7403e8e69b3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "4", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "4", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"f", "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"a", "[", "2", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "2", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"b", "[", 
          RowBox[{"2", ",", "1"}], "]"}], " ", 
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}], "+", 
           RowBox[{"h", " ", 
            RowBox[{"a", "[", "2", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "2", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"b", "[", 
           RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"f", "[", 
           RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", "h", " ", 
            RowBox[{"a", "[", "2", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "2", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"h", " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], "+", 
        RowBox[{"h", " ", 
         RowBox[{"a", "[", "3", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SuperscriptBox["h", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "3", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["f", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"tk", ",", "yk"}], "]"}], "+", 
           RowBox[{"h", " ", 
            RowBox[{"a", "[", "3", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "3", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h", " ", 
            RowBox[{"b", "[", 
             RowBox[{"3", ",", "1"}], "]"}], " ", 
            RowBox[{"f", "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{"h", " ", 
            RowBox[{"b", "[", 
             RowBox[{"3", ",", "2"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"f", "[", 
               RowBox[{"tk", ",", "yk"}], "]"}], "+", 
              RowBox[{"h", " ", 
               RowBox[{"a", "[", "2", "]"}], " ", 
               RowBox[{
                SuperscriptBox["f", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SuperscriptBox["h", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "2", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["f", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"2", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
              RowBox[{"h", " ", 
               RowBox[{"b", "[", 
                RowBox[{"2", ",", "1"}], "]"}], " ", 
               RowBox[{"f", "[", 
                RowBox[{"tk", ",", "yk"}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["f", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}], "+", 
                 RowBox[{"h", " ", 
                  RowBox[{"a", "[", "2", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "2"], " ", 
                  SuperscriptBox["h", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["h", "2"], " ", 
               SuperscriptBox[
                RowBox[{"b", "[", 
                 RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"f", "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FractionBox["1", "2"], " ", 
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "2"], " ", "h", " ", 
                  RowBox[{"a", "[", "2", "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "4"], " ", 
                  SuperscriptBox["h", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
           ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", "h", " ", 
            RowBox[{"a", "[", "3", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "4"], " ", 
            SuperscriptBox["h", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "3", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", " ", 
             RowBox[{"b", "[", 
              RowBox[{"3", ",", "1"}], "]"}], " ", 
             RowBox[{"f", "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{"h", " ", 
             RowBox[{"b", "[", 
              RowBox[{"3", ",", "2"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"f", "[", 
                RowBox[{"tk", ",", "yk"}], "]"}], "+", 
               RowBox[{"h", " ", 
                RowBox[{"a", "[", "2", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["f", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SuperscriptBox["h", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["f", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
               RowBox[{"h", " ", 
                RowBox[{"b", "[", 
                 RowBox[{"2", ",", "1"}], "]"}], " ", 
                RowBox[{"f", "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
                  RowBox[{"h", " ", 
                   RowBox[{"a", "[", "2", "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SuperscriptBox["h", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["h", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"b", "[", 
                  RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"f", "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", "h", " ", 
                   RowBox[{"a", "[", "2", "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "4"], " ", 
                   SuperscriptBox["h", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "h", " ", 
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox["h", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "4", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "1"}], "]"}], " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "2"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"a", "[", "2", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox["h", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "2", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"b", "[", 
           RowBox[{"2", ",", "1"}], "]"}], " ", 
          RowBox[{"f", "[", 
           RowBox[{"tk", ",", "yk"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}], "+", 
            RowBox[{"h", " ", 
             RowBox[{"a", "[", "2", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "2", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["h", "2"], " ", 
          SuperscriptBox[
           RowBox[{"b", "[", 
            RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", "h", " ", 
             RowBox[{"a", "[", "2", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "2", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "+", 
         RowBox[{"h", " ", 
          RowBox[{"a", "[", "3", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox["h", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "3", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["f", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"tk", ",", "yk"}], "]"}], "+", 
            RowBox[{"h", " ", 
             RowBox[{"a", "[", "3", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "3", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"h", " ", 
             RowBox[{"b", "[", 
              RowBox[{"3", ",", "1"}], "]"}], " ", 
             RowBox[{"f", "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{"h", " ", 
             RowBox[{"b", "[", 
              RowBox[{"3", ",", "2"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"f", "[", 
                RowBox[{"tk", ",", "yk"}], "]"}], "+", 
               RowBox[{"h", " ", 
                RowBox[{"a", "[", "2", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["f", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SuperscriptBox["h", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["f", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
               RowBox[{"h", " ", 
                RowBox[{"b", "[", 
                 RowBox[{"2", ",", "1"}], "]"}], " ", 
                RowBox[{"f", "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}], "+", 
                  RowBox[{"h", " ", 
                   RowBox[{"a", "[", "2", "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SuperscriptBox["h", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["h", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"b", "[", 
                  RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"f", "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", "h", " ", 
                   RowBox[{"a", "[", "2", "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "4"], " ", 
                   SuperscriptBox["h", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", "h", " ", 
             RowBox[{"a", "[", "3", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
            RowBox[{
             FractionBox["1", "4"], " ", 
             SuperscriptBox["h", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "3", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["f", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"h", " ", 
              RowBox[{"b", "[", 
               RowBox[{"3", ",", "1"}], "]"}], " ", 
              RowBox[{"f", "[", 
               RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
             RowBox[{"h", " ", 
              RowBox[{"b", "[", 
               RowBox[{"3", ",", "2"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"f", "[", 
                 RowBox[{"tk", ",", "yk"}], "]"}], "+", 
                RowBox[{"h", " ", 
                 RowBox[{"a", "[", "2", "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["f", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                 RowBox[{
                  SuperscriptBox["f", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                RowBox[{"h", " ", 
                 RowBox[{"b", "[", 
                  RowBox[{"2", ",", "1"}], "]"}], " ", 
                 RowBox[{"f", "[", 
                  RowBox[{"tk", ",", "yk"}], "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}], "+", 
                   RowBox[{"h", " ", 
                    RowBox[{"a", "[", "2", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SuperscriptBox["h", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "1"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["h", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"b", "[", 
                   RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"f", "[", 
                   RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", "h", " ", 
                    RowBox[{"a", "[", "2", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "4"], " ", 
                    SuperscriptBox["h", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["f", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"2", ",", "2"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"tk", ",", "yk"}], "]"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}], "2"]}]}], ")"}]}]}], ")"}], 
    "2"]}]}]], "Output",
 CellChangeTimes->{
  3.5135245750842*^9},ExpressionUUID->"483342f2-6970-431a-8f0d-2c2a31d63e60"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"phi", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "k1"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], " ", "k2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], " ", "k3"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"c", "[", "4", "]"}], " ", "k4"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5135130114329453`*^9, 3.513513029513345*^9}, {
  3.5135245825722*^9, 
  3.5135245978602*^9}},ExpressionUUID->"1e5965d1-7654-4d19-8830-c6efef27b250"],

Cell[TextData[{
 "Our goal now is the minimize the difference between phi and bigT[4]. \
Specifically, we want all terms containing powers of ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "af69a886-df49-44a6-9b6c-464c54cf1337"],
 " lower than 4 to vanish."
}], "Text",
 CellChangeTimes->{{3.5135246125086*^9, 3.5135246586222*^9}, 
   3.5135263844502*^9},ExpressionUUID->"f11db8a3-dc3c-428d-abfa-efc072d67545"],

Cell["\<\
Here is the difference to minimize. This is a very large expression, so I \
have suppressed printing of it.\
\>", "Text",
 CellChangeTimes->{{3.5135246648778*^9, 
  3.5135246900874*^9}},ExpressionUUID->"167484d6-2a9f-4f26-9df1-b1599c5919a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"diff", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"bigT", "[", "4", "]"}], "-", " ", "phi"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.513467928087784*^9, 3.5134679427050095`*^9}, {
  3.5135247085578003`*^9, 
  3.5135247089634*^9}},ExpressionUUID->"5c38a07f-7ac9-4f7d-a0e0-a26e70364cbe"],

Cell[TextData[{
 "Just as in the last example, diff contains terms depending on f[tk,yk] and \
terms containing the two first derivatives of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "f7579986-52ef-4f5e-ab59-6a636a868283"],
 ". The first set of terms tell us that"
}], "Text",
 CellChangeTimes->{{3.5135247415674*^9, 3.513524796183*^9}, 
   3.5135264062746*^9},ExpressionUUID->"2d520e2b-fe52-4da0-902a-485fd9ae8b10"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cEqn", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "+", 
     RowBox[{"c", "[", "2", "]"}], "+", 
     RowBox[{"c", "[", "3", "]"}], "+", 
     RowBox[{"c", "[", "4", "]"}]}], "\[Equal]", "1"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5135248176486*^9, 
  3.5135248372265997`*^9}},ExpressionUUID->"54e3bad3-aa6d-4869-9811-\
3152ce93d601"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "1", "]"}], "+", 
    RowBox[{"c", "[", "2", "]"}], "+", 
    RowBox[{"c", "[", "3", "]"}], "+", 
    RowBox[{"c", "[", "4", "]"}]}], "\[Equal]", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5135248399877996`*^9},ExpressionUUID->"c67851b9-0fc9-4ded-83bd-\
90e8ae959a75"]
}, Open  ]],

Cell[TextData[{
 "The other terms of interest are the terms containing first derivatives of ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "252400e5-9aad-49de-86ae-02dc7853264e"],
 ". We can isolate those by using Coefficient again. Once again, this is a \
very large set of terms, so I have suppressed printing of the terms."
}], "Text",
 CellChangeTimes->{{3.5135248522026*^9, 3.513524910297*^9}, 
   3.5135264159778*^9},ExpressionUUID->"4b2bb1a3-2898-4a34-bdd1-6c51e8119198"],

Cell[BoxData[
 RowBox[{
  RowBox[{"set1", " ", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"diff", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"0", ",", "1"}], "]"}], "[", "f", "]"}], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5134569865031652`*^9, 3.5134570065804005`*^9}, {
   3.5134614551154137`*^9, 3.513461458017019*^9}, 
   3.513464079863624*^9},ExpressionUUID->"b82f5df5-ef49-4881-abab-\
5dcdab1e4be8"],

Cell[TextData[{
 "The parts of set1 that interest us are the terms involving powers of ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "22115aea-3d19-4c8d-b3ac-0baa5fcd7184"],
 " less than 4. There is a relatively modest number of those terms, so we can \
use Coefficient to peel them off one by one for study."
}], "Text",
 CellChangeTimes->{{3.5135249190642*^9, 3.5135249633682003`*^9}, 
   3.5135264274126*^9},ExpressionUUID->"ac7f8396-9957-4c72-ba83-e7b7c954574e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set1", ",", "h"}], "]"}]], "Input",
 CellChangeTimes->{{3.5134633897340117`*^9, 
  3.513463407330843*^9}},ExpressionUUID->"fe6d09ac-0469-4bb9-8cf5-\
ebf5ebbaa09c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.513463408532045*^9, 3.513464628110987*^9, 
  3.513466239921418*^9, 3.513467978210672*^9, 3.5134692511885076`*^9, 
  3.5135249666286*^9},ExpressionUUID->"2f978818-5322-4dc6-bb46-a30804a30b03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set1", ",", 
   RowBox[{"h", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.513463414834456*^9, 
  3.513463424241273*^9}},ExpressionUUID->"59af3154-49f8-4ec7-a5a2-\
405099b6dc02"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5134634251460743`*^9, 3.5134646307161913`*^9, 
  3.513466241528221*^9, 3.5134679881010895`*^9, 3.5134692529825106`*^9, 
  3.5135249702790003`*^9},ExpressionUUID->"33621fd2-d802-4e00-bcb7-\
3bccdff1cb7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set1", ",", 
   RowBox[{"h", "^", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5134634306528835`*^9, 
  3.5134634464089117`*^9}},ExpressionUUID->"f6788b03-6a1e-49fc-b287-\
6cc409dc691c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["5", "24"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "24"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "2", "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "3", "]"}], "2"], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5134634472825127`*^9, 3.5134646340389977`*^9, 
  3.513466243743425*^9, 3.5134679934050984`*^9, 3.513469255306915*^9, 
  3.5135249729154*^9},ExpressionUUID->"03557b15-98bf-4ea4-b2cd-f6f979f57c35"]
}, Open  ]],

Cell["\<\
Examining these sets of terms gives us some equations that need to be solved.\
\>", "Text",
 CellChangeTimes->{{3.5135250029765997`*^9, 3.5135250155034*^9}, 
   3.5135264412342*^9},ExpressionUUID->"1d00c98c-7b7f-4cbd-b510-68b14d16ec6c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqns1", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"set1", ",", 
       RowBox[{"h", " ", 
        RowBox[{"f", "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"set1", ",", " ", 
       RowBox[{
        SuperscriptBox["h", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"set1", ",", "  ", 
       RowBox[{
        SuperscriptBox["h", "3"], " ", 
        SuperscriptBox[
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"set1", ",", "  ", 
       RowBox[{
        SuperscriptBox["h", "3"], " ", 
        RowBox[{"f", "[", 
         RowBox[{"tk", ",", "yk"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"set1", ",", "  ", 
       RowBox[{
        SuperscriptBox["h", "3"], "  ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.5134614626502275`*^9, 3.513461570243616*^9}, {
   3.513461607948882*^9, 3.513461665228983*^9}, {3.5134634935677943`*^9, 
   3.5134635531286993`*^9}, {3.513463950071396*^9, 3.513463968463828*^9}, {
   3.513463998946282*^9, 3.5134640496931715`*^9}, 3.5134680731056385`*^9, 
   3.513468127144133*^9, {3.513469107309455*^9, 3.5134691437355185`*^9}, {
   3.5134698113074913`*^9, 3.513469814489897*^9}, 
   3.5135250189354*^9},ExpressionUUID->"2c834e11-1a0f-4b68-82e6-e3297cf53178"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["5", "24"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "24"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "3", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5135250205266*^9},ExpressionUUID->"276aaeb6-d319-4a62-9a3e-3d1eff5476db"]
}, Open  ]],

Cell["\<\
Next, we do the similar process with the other first derivative terms.\
\>", "Text",
 CellChangeTimes->{{3.513525043521*^9, 
  3.5135250578106003`*^9}},ExpressionUUID->"396b8b78-01d7-4da6-b490-\
3fee459aba7b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"set2", " ", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"diff", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", 
        RowBox[{"1", ",", "0"}], "]"}], "[", "f", "]"}], "[", 
      RowBox[{"tk", ",", "yk"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.513457124563408*^9, 3.513457127075012*^9}, {
   3.513461678411006*^9, 3.51346168053261*^9}, 
   3.5134640713460093`*^9},ExpressionUUID->"f9867f0c-b5be-4867-9d3c-\
ebefaa9753a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set2", ",", "h"}], "]"}]], "Input",
 CellChangeTimes->{{3.5134633897340117`*^9, 3.513463407330843*^9}, {
  3.513464132139316*^9, 
  3.513464132310916*^9}},ExpressionUUID->"8bd097ea-320e-4144-a2e4-\
cea5c5f47547"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"c", "[", "2", "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}]}]}]], "Output",
 CellChangeTimes->{3.513463408532045*^9, 3.513464133106518*^9, 
  3.5134646496858253`*^9, 3.513466254101843*^9, 3.513468190449044*^9, 
  3.5134692682549376`*^9, 
  3.513525062163*^9},ExpressionUUID->"c6d2760d-65bf-45cc-8196-20861bbe3704"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set2", ",", 
   RowBox[{"h", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.513463414834456*^9, 3.513463424241273*^9}, {
  3.513464140812931*^9, 
  3.5134641409845314`*^9}},ExpressionUUID->"ea21a423-f552-49c1-8831-\
f53753f9df76"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5134634251460743`*^9, 3.513464141608533*^9, 
  3.5134646511678276`*^9, 3.5134681925394483`*^9, 3.5134692706417418`*^9, 
  3.5135250638166*^9},ExpressionUUID->"7150f213-ee1c-479c-b060-1c24bf0b9758"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{"set2", ",", 
   RowBox[{"h", "^", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5134634306528835`*^9, 3.5134634464089117`*^9}, {
  3.513464150843749*^9, 
  3.5134641510933495`*^9}},ExpressionUUID->"5eae4f9d-fbc1-4d40-9170-\
6f63cf495f98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "24"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"tk", ",", "yk"}], "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"4", ",", "2"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "1"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"b", "[", 
     RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"3", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "3", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", 
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "2"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], " ", 
   RowBox[{"a", "[", "4", "]"}], " ", 
   RowBox[{"b", "[", 
    RowBox[{"4", ",", "3"}], "]"}], " ", 
   RowBox[{"c", "[", "4", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5134634472825127`*^9, 3.5134641517017508`*^9, 
  3.513464653601432*^9, 3.513468195300653*^9, 3.513469271764944*^9, 
  3.5135250651113997`*^9},ExpressionUUID->"e5396ad5-9c1b-4868-8ccc-\
d10ca6c43f94"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqns2", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"set2", ",", "h"}], " ", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"set2", ",", 
        RowBox[{
         SuperscriptBox["h", "2"], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"set2", ",", "  ", 
        RowBox[{
         SuperscriptBox["h", "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"tk", ",", "yk"}], "]"}], "2"]}]}], "]"}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"set2", ",", " ", 
        RowBox[{
         SuperscriptBox["h", "3"], " ", 
         RowBox[{"f", "[", 
          RowBox[{"tk", ",", "yk"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"set2", ",", " ", 
        RowBox[{
         SuperscriptBox["h", "3"], " ", 
         RowBox[{
          SuperscriptBox["f", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"tk", ",", "yk"}], "]"}]}]}], "]"}], "\[Equal]", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5134611248784337`*^9, 3.513461194423356*^9}, {
   3.5134612287746162`*^9, 3.5134613419840155`*^9}, {3.513461372700469*^9, 
   3.5134613763040752`*^9}, {3.5134616924354305`*^9, 3.513461812259241*^9}, 
   3.5134642531643286`*^9, 3.5134643018364143`*^9, {3.5134643506956997`*^9, 
   3.513464378214148*^9}, {3.51346441354821*^9, 3.51346443061464*^9}, {
   3.513469154624338*^9, 3.513469171300767*^9}, {3.513469823225912*^9, 
   3.51346982757832*^9}},ExpressionUUID->"223c7637-2275-4e6d-8b3a-\
8b72a4d30893"],

Cell["Here now are all of the equations we need to solve.", "Text",
 CellChangeTimes->{{3.51347074414333*^9, 
  3.513470752380144*^9}},ExpressionUUID->"549313f7-1a11-41f4-bf94-\
c729b35c7399"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allEqns", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{"cEqn", ",", "eqns1", ",", "eqns2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134693108742123`*^9, 3.5134693179254246`*^9}, {
  3.5134698358307343`*^9, 3.5134698406199427`*^9}, {3.5135250753294*^9, 
  3.513525079167*^9}},ExpressionUUID->"0c336771-f5ce-4c86-919f-73bc695cedb6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "+", 
     RowBox[{"c", "[", "2", "]"}], "+", 
     RowBox[{"c", "[", "3", "]"}], "+", 
     RowBox[{"c", "[", "4", "]"}]}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"2", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "1"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["5", "24"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"2", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "24"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "2", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "3", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"c", "[", "2", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "24"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "1"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], " ", 
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.513469319157827*^9, 
  3.5135250805242*^9},ExpressionUUID->"489f9293-57ae-4d24-9a24-f4b0f8be24e4"]
}, Open  ]],

Cell[TextData[{
 "Unfortunately, this is a difficult system of nonlinear equations. Even ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will have a lot of trouble solving these equations. Consequently, we will \
have to give it some help."
}], "Text",
 CellChangeTimes->{{3.5134707576685534`*^9, 
  3.5134708157942557`*^9}},ExpressionUUID->"e0a6d936-39a1-42b9-8157-\
5d8e760bef00"],

Cell["\<\
One reasonable way to generate a solution to this system is to make two \
simple assumptions. The first assumption is that each step depends only on \
the step immediately before it. The second assumption is that step 2 looks \
like the midpoint rule.\
\>", "Text",
 CellChangeTimes->{{3.5134706255207214`*^9, 3.5134706932560406`*^9}, {
  3.5134708285550785`*^9, 3.5134708295066795`*^9}, {3.513514060181945*^9, 
  3.513514062740345*^9}, {3.5135264760534*^9, 
  3.5135264786118*^9}},ExpressionUUID->"f5b0128a-df5b-49d5-b4ba-636bacc0b743"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"n_", ",", "k_"}], "]"}], " ", ":=", 
   RowBox[{"0", "/;", 
    RowBox[{"k", " ", "<", " ", 
     RowBox[{"n", "-", "1"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "2", "]"}], " ", "=", " ", 
   RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"2", ",", "1"}], "]"}], " ", "=", " ", 
   RowBox[{"1", "/", "2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5134694576860704`*^9, 3.513469480727311*^9}, {
  3.5134698762036057`*^9, 3.5134698772800074`*^9}, {3.5135251005078*^9, 
  3.5135251365438004`*^9}},ExpressionUUID->"ecebc330-5e25-4bf7-ab33-\
362a0e5dd1c1"],

Cell["\<\
If we code these assumptions and then try again to solve the equations, we \
meet with success.\
\>", "Text",
 CellChangeTimes->{{3.5134707082632666`*^9, 
  3.51347073281771*^9}},ExpressionUUID->"aaac2c09-cfc8-41bc-b51a-\
7abe88c11528"],

Cell[CellGroupData[{

Cell[BoxData["allEqns"], "Input",
 CellChangeTimes->{{3.513469574920276*^9, 3.51346957713548*^9}, {
  3.5134698641915846`*^9, 
  3.5134698646439853`*^9}},ExpressionUUID->"916244fc-53c6-4747-abe9-\
51e1ee589b3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "+", 
     RowBox[{"c", "[", "2", "]"}], "+", 
     RowBox[{"c", "[", "3", "]"}], "+", 
     RowBox[{"c", "[", "4", "]"}]}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox[
      RowBox[{"c", "[", "2", "]"}], "2"], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["5", "24"], "-", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "24"], "-", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "3", "]"}], "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox[
      RowBox[{"c", "[", "2", "]"}], "2"], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "6"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "24"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"3", ",", "2"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"b", "[", 
        RowBox[{"4", ",", "3"}], "]"}], "2"], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], " ", 
      RowBox[{"c", "[", "3", "]"}]}], "-", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], " ", 
      RowBox[{"a", "[", "4", "]"}], " ", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], " ", 
      RowBox[{"c", "[", "4", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.513469578087082*^9, 
  3.5135251465434*^9},ExpressionUUID->"7d2e07a3-cd36-48fd-a7eb-96aff4b8a922"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", " ", "=", " ", 
  RowBox[{"Solve", "[", 
   RowBox[{"allEqns", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], ",", 
      RowBox[{"a", "[", "4", "]"}], ",", 
      RowBox[{"b", "[", 
       RowBox[{"3", ",", "2"}], "]"}], ",", 
      RowBox[{"b", "[", 
       RowBox[{"4", ",", "3"}], "]"}], ",", 
      RowBox[{"c", "[", "1", "]"}], ",", 
      RowBox[{"c", "[", "2", "]"}], ",", 
      RowBox[{"c", "[", "3", "]"}], ",", 
      RowBox[{"c", "[", "4", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5134693376750593`*^9, 3.51346933801826*^9}, {
  3.5134694903525276`*^9, 3.5134694947517357`*^9}, {3.5134696816712637`*^9, 
  3.5134696844324684`*^9}, {3.5134697286429462`*^9, 3.513469729766148*^9}, {
  3.5134698884340267`*^9, 3.5134698888396273`*^9}, {3.513525157947*^9, 
  3.5135251954806004`*^9}},ExpressionUUID->"e2b214f7-eaee-465a-9d52-\
f0a5417ceb0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", "1", "]"}], "\[Rule]", 
     FractionBox["1", "6"]}], ",", 
    RowBox[{
     RowBox[{"c", "[", "2", "]"}], "\[Rule]", 
     FractionBox["1", "3"]}], ",", 
    RowBox[{
     RowBox[{"a", "[", "4", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"c", "[", "3", "]"}], "\[Rule]", 
     FractionBox["1", "3"]}], ",", 
    RowBox[{
     RowBox[{"a", "[", "3", "]"}], "\[Rule]", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{
     RowBox[{"c", "[", "4", "]"}], "\[Rule]", 
     FractionBox["1", "6"]}], ",", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"4", ",", "3"}], "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"b", "[", 
      RowBox[{"3", ",", "2"}], "]"}], "\[Rule]", 
     FractionBox["1", "2"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.513469450104457*^9, 3.513469571784671*^9, 
  3.513469686382472*^9, 3.5134697327769537`*^9, 
  3.5135251970874*^9},ExpressionUUID->"5fabc254-f581-40cf-bb79-e475430c2fe2"]
}, Open  ]],

Cell["\<\
This produces the most commonly used Runge-Kutta formula of order 4. Slightly \
different assumptions will produce other possible order 4 formulas.\
\>", "Text",
 CellChangeTimes->{{3.5135252508294*^9, 
  3.5135253001878*^9}},ExpressionUUID->"f08fd850-f6c0-48b2-96c8-3c4086caaefe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phi", "  ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], " ", 
      RowBox[{"k", "[", "1", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], " ", 
      RowBox[{"k", "[", "2", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"c", "[", "3", "]"}], " ", 
      RowBox[{"k", "[", "3", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"c", "[", "4", "]"}], " ", 
      RowBox[{"k", "[", "4", "]"}]}]}], ")"}], "/.", 
   RowBox[{"soln", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.513525235791*^9, 
  3.5135252463054*^9}},ExpressionUUID->"72c8b287-8d24-4ba5-bf76-142055354854"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"f", "[", 
    RowBox[{"tk", ",", "yk"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      FractionBox["h", "2"], "+", "tk"}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "h", " ", 
       RowBox[{"f", "[", 
        RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      FractionBox["h", "2"], "+", "tk"}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "h", " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{
          FractionBox["h", "2"], "+", "tk"}], ",", 
         RowBox[{"yk", "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "h", " ", 
           RowBox[{"f", "[", 
            RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{"h", "+", "tk"}], ",", 
     RowBox[{"yk", "+", 
      RowBox[{"h", " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{
          FractionBox["h", "2"], "+", "tk"}], ",", 
         RowBox[{"yk", "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "h", " ", 
           RowBox[{"f", "[", 
            RowBox[{
             RowBox[{
              FractionBox["h", "2"], "+", "tk"}], ",", 
             RowBox[{"yk", "+", 
              RowBox[{
               FractionBox["1", "2"], " ", "h", " ", 
               RowBox[{"f", "[", 
                RowBox[{"tk", ",", "yk"}], "]"}]}]}]}], "]"}]}]}]}], 
        "]"}]}]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.5135137620659447`*^9, 
  3.5135253029958*^9},ExpressionUUID->"ce071025-a8f4-490a-a1c4-93157278e617"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Runge-Kutta method example", "Subsubsection",
 CellChangeTimes->{{3.435324003862914*^9, 3.435324009331664*^9}, {
  3.5135253965178003`*^9, 
  3.5135253982962*^9}},ExpressionUUID->"ffc1ec06-a984-45c0-bfdc-9b3baa63d696"],

Cell["\<\
Here is the code to implement a single step in the Runge-Kutta method we \
derived above. For clarity, this version is written out in multi-stage form.\
\>", "Text",
 CellChangeTimes->{{3.43533779156378*^9, 3.4353378871835575`*^9}, {
  3.5135254171098003`*^9, 
  3.5135254347222*^9}},ExpressionUUID->"d2be71d0-86bc-4816-8742-e039ea9f5d32"],

Cell[BoxData[
 RowBox[{
  RowBox[{"runge", "[", 
   RowBox[{"{", 
    RowBox[{"t_", ",", "y_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k1", ",", "k2", ",", "k3", ",", "k4"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"k1", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k2", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", 
         RowBox[{"h", "/", "2"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k1", "*", 
          RowBox[{"h", "/", "2"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k3", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", 
         RowBox[{"h", "/", "2"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k2", "*", 
          RowBox[{"h", "/", "2"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k4", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", "h"}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k3", "*", "h"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "+", "h"}], ",", 
       RowBox[{"y", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k1", "+", 
           RowBox[{"2", "*", "k2"}], "+", 
           RowBox[{"2", "*", "k3"}], "+", "k4"}], ")"}], "*", 
         RowBox[{"h", "/", "6"}]}]}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435324150284789*^9, 3.435324295800414*^9}, {
  3.435324415706664*^9, 3.435324419441039*^9}, {3.4353380673437815`*^9, 
  3.4353381418362603`*^9}},ExpressionUUID->"1caadc7d-31e3-40f4-b069-\
4be320b391ba"],

Cell["\<\
Let's test this on the differential equation we've been using for examples.\
\>", "Text",
 CellChangeTimes->{{3.513525453801*^9, 
  3.5135254688394003`*^9}},ExpressionUUID->"cfe37764-825d-4e00-bdd5-\
309016c36999"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"y", "^", "2"}], " ", "+", " ", 
   RowBox[{"t", "^", "2", " "}]}]}]], "Input",
 CellChangeTimes->{{3.5129174115755997`*^9, 
  3.5129174179091997`*^9}},ExpressionUUID->"32bc80d8-f215-491d-9c3f-\
af0d858e4cd7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.1"}]], "Input",
 CellChangeTimes->{{3.4347225901760263`*^9, 3.4347225926444917`*^9}, {
  3.435323743222289*^9, 
  3.435323743331664*^9}},ExpressionUUID->"c55b5fe8-410d-4766-a99c-\
79d0dcf84817"],

Cell[BoxData["0.1`"], "Output",
 CellChangeTimes->{3.4347226536374645`*^9, 3.4347232817213507`*^9, 
  3.435323744612914*^9, 3.435324324066039*^9, 3.4353381561346908`*^9, 
  3.4355054153883667`*^9, 
  3.513525477981*^9},ExpressionUUID->"c89bc6d9-b307-4646-9f14-e09d32a1047e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rungePts", " ", "=", " ", 
  RowBox[{"NestList", "[", 
   RowBox[{"runge", ",", 
    RowBox[{"{", 
     RowBox[{"0.", ",", "0.5"}], "}"}], ",", "10"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434721854167074*^9, 3.434721865103314*^9}, {
   3.4347224470831375`*^9, 3.4347224840632515`*^9}, 3.4347226569339595`*^9, {
   3.435323748425414*^9, 3.435323760316039*^9}, {3.435324328612914*^9, 
   3.435324334769164*^9}, {3.512917422012*^9, 
   3.5129174221056004`*^9}},ExpressionUUID->"8dacf5e1-d55f-437c-81b1-\
603ec829bc59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1`", ",", "0.526658003818244`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2`", ",", "0.5583739310754928`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.30000000000000004`", ",", "0.5980617416954938`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4`", ",", "0.6491676977837305`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "0.7159192784283326`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6`", ",", "0.8037440440952285`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7`", ",", "0.9199996377502666`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7999999999999999`", ",", "1.0753038289112133`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8999999999999999`", ",", "1.2861072888217873`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9999999999999999`", ",", "1.5800880093111669`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.43472186596259*^9, {3.434721947234476*^9, 3.4347219689351015`*^9}, 
   3.434722033708888*^9, 3.4347222023769555`*^9, {3.434722466252804*^9, 
   3.4347224847662954`*^9}, 3.4347226581525693`*^9, 3.4347230994142303`*^9, 
   3.434723284314802*^9, {3.435323763362914*^9, 3.435323780519164*^9}, 
   3.435324365941039*^9, {3.435324398487914*^9, 3.435324423472289*^9}, 
   3.435338158478696*^9, 
   3.5135254792446003`*^9},ExpressionUUID->"b6fcbe73-a8f2-47e4-8f7e-\
502c5e1e7db9"]
}, Open  ]],

Cell[TextData[{
 "The Runge-Kutta method is a fourth order method with error proportional to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["h", "4"], TraditionalForm]],ExpressionUUID->
  "04a573a9-bde3-416b-ad5f-4236078e76e0"],
 ". For a wide range of applications Runge-Kutta produces acceptable results \
with only a modest amount of calculation effort."
}], "Text",
 CellChangeTimes->{{3.435337896778351*^9, 
  3.4353379694112525`*^9}},ExpressionUUID->"db0a3611-af5a-46e6-a077-\
c088cbd8c91f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yEst", "=", 
  RowBox[{"rungePts", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435324342894164*^9, 
  3.435324344722289*^9}},ExpressionUUID->"412d6077-8e06-4228-8caf-\
3a82453457c0"],

Cell[BoxData["1.5800880093111669`"], "Output",
 CellChangeTimes->{
  3.435323835987914*^9, {3.435324403472289*^9, 3.435324426284789*^9}, 
   3.4353381659795117`*^9, 
   3.5135254859681997`*^9},ExpressionUUID->"55fec059-55be-4f84-8770-\
b41cd75a64be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yActual", "-", "yEst"}]], "Input",ExpressionUUID->"e6255f9f-17fd-49cb-aafe-d6c3c75e8f2f"],

Cell[BoxData[
 RowBox[{"-", "3.0299760827023903`*^-6"}]], "Output",
 CellChangeTimes->{
  3.435323852331664*^9, {3.435324405753539*^9, 3.435324428550414*^9}, 
   3.5135254878402*^9, 
   3.5135255318634*^9},ExpressionUUID->"c5a12aa7-1e43-4c75-b75b-4100c02604e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot6", " ", "=", " ", 
  RowBox[{"ListPlot", "[", "rungePts", "]"}]}]], "Input",
 CellChangeTimes->{{3.434721952030799*^9, 3.4347219522651467`*^9}, {
  3.4347224711741114`*^9, 3.4347224899844446`*^9}, {3.435323861753539*^9, 
  3.435323869456664*^9}, {3.435324432331664*^9, 
  3.435324437253539*^9}},ExpressionUUID->"60d9f806-6d0d-4554-be0e-\
241c1252f3e7"],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{0., 0.5}, {0.1, 0.526658003818244}, {0.2, 0.5583739310754928}, {
    0.30000000000000004`, 0.5980617416954938}, {0.4, 0.6491676977837305}, {
    0.5, 0.7159192784283326}, {0.6, 0.8037440440952285}, {0.7, 
    0.9199996377502666}, {0.7999999999999999, 1.0753038289112133`}, {
    0.8999999999999999, 1.2861072888217873`}, {0.9999999999999999, 
    1.5800880093111669`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.435323870550414*^9, 3.435324438081664*^9, 
  3.513525535935*^9},ExpressionUUID->"772a835e-6f2b-4f41-83c5-2d5b019fe855"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot6"}], "]"}]], "Input",
 CellChangeTimes->{{3.435323873566039*^9, 3.435323880409789*^9}, {
  3.435324441284789*^9, 
  3.435324441425414*^9}},ExpressionUUID->"b4c9a336-4424-4997-917e-\
d6d2fab3721f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVx3s0VAkAx/HxyDPPajtDRItSxNFEUn6VSoVsYm0S1vSUtpJOWZGRwVaW
7agleeRVEiOP2jbSyrZlK3lPxbgzxhhjzE153JuMbf/4nu/5WIYf9zugymAw
fL72/3cckLY9GQ5wT86jvpKAuofJiX4mC7rbfboKvnpVftaNGuZm2DQl125U
IeD1qqc6l+mPsmLT7AuqBAL3TzVcYe5HgGXXtOYcAn0OKR5pzGgs0G1xmKdD
oGCBb/JFZhIMtFUyV80nwNGqWfoLMxPmpZXhecsI/LDnJu/DWDG2RMnpBwEE
dGc5wZ7mPMSy57rNJhCw3qWQPr1UC+eUrk2Vdwmcee2KrPGH+DgaVHyrj8DC
WiOBikojCqeVDpp6QtwXebxsXdcETsNRHnuTEE0RuaZ75M2I5hiytGOEmLBZ
b1Bx7B9wNcI71lQKoUqXG5patyA+lj2cLBPCeTbs/u7Kl+CdXRnJsRbhZRLr
9bPlrVC7n/NUO1yExRkjdJniDbwrWF4zpSKMTPULuhzbIVtrZFsgE6FY9qhF
/9cOVChfH3/lMgB9s1ukWNyJwtDvdf5KGcDlI3UHC6y6wXFTW/dd9wAmN5SL
D5/vQeO7YBc7RzGinZprv3nKh4Xo3wvVqWL0VzZfarN8h5L1cU4aCjGmIzpz
bH9+j8uH7qj6Bw5ixUZN5cFHvYi4bRLJbByEZ6HloXsLBWD8uNJGw1mCM2ah
S4TB/QjaMHgvulwCO3mAbo8PgZkXMv6Y1RDmGXzQav5MIH6VRZBP1RDUG3N4
394QIsulM0DoKsVR1qO32l4iXLHpnnnQI0X59vCCx5MimIm4jsbnhjExYmIo
uTaA5rIXel7mMtTt9lTL3CyGakmU01W+DOe3cfNrJWKcyq7a2pMxAsu+Hfwi
7iDYd79safWVY61LUibTSQLf92NJoStGEWzeSqt0SJDGDu6+pq7AREua6ARn
CA2MCq14pQJZ6iHRflZShEgSpoMmScwT1BWqNksR+YU1QcV+wJw4jr/ryWFM
SxuOnDQcA6MshCcylqGFkxDbVzSGqOu8NOMmGUprUwLm7vyIhhWpWkY/jYAx
cfp6GuMTjHZE2SXqy9FY2q5jVf0JvfZvOmLq5XhubO/VfX4cVXmwEoeMwuBw
MeHrM4F9PGcjM+UoaNrzcYLVJBK4Nzm9dxQgHBJ5fPMpVEjNcvS9SYTO/834
HZNCai43TLCTBNFtk8s2p7Dfb9S6cheJiyrnshVLKCyqr6/yCSTxMHlkWMuO
wsX0vc8uh5O4WlYyvdOdwmHn7DGdGBIxGowoSzaFJUnzt2mWkjjuP7pWXEFB
ueacXs9tEvi4zj23msLb0YH20nISNdZbngc+oJARWLNv6z0SiQOup9qeUJhd
7neKW09CUSBx6emg0NuWnqfWQSKdv3mh/WcKfyRPsTu6SKj7C/hKJYVMt1Db
Ij6JrHxvu3Y1Gl4lK2s3CUi4qMVfitOj8efZVy84wySeJ9piyILGNfvV6bvk
JMble4v+tqZxUnTD35IkcSzZNL9kOY1l3pH9T8ZJmOgtDYtg0VBX6SzOmCJR
xpHY+LrSIOrcIsI+k/jCMkld7U6jPqLIwXGGhMAwLsnMg8bvi3UnZmdJRJ5u
WaS5jcZ/eWJyfw==
      "]]}}, 
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{0., 0.5}, {0.1, 0.526658003818244}, {0.2, 
     0.5583739310754928}, {0.30000000000000004`, 0.5980617416954938}, {0.4, 
     0.6491676977837305}, {0.5, 0.7159192784283326}, {0.6, 
     0.8037440440952285}, {0.7, 0.9199996377502666}, {0.7999999999999999, 
     1.0753038289112133`}, {0.8999999999999999, 1.2861072888217873`}, {
     0.9999999999999999, 1.5800880093111669`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.6000000000000001},
  ImageSize->{623., Automatic},
  PlotRange->{{0, 1}, {0.5000000055342333, 1.5800849079745047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.435323881175414*^9, 3.435324442331664*^9, 
  3.5135255398506002`*^9},ExpressionUUID->"258b6c81-0956-47e5-8851-\
6103540345fd"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Numerical Solutions from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Subsection",
 CellChangeTimes->{{3.4355049637707653`*^9, 3.4355049677292285`*^9}, {
  3.435508037403534*^9, 
  3.4355080431621847`*^9}},ExpressionUUID->"fa4c5259-ee6e-4536-b75b-\
628fae799943"],

Cell[TextData[{
 "Now that we have seen a number of numerical methods for solving first order \
differential equations, it is interesting to note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " also has built-in methods for solving differential equations numerically."
}], "Text",
 CellChangeTimes->{{3.435507728955729*^9, 
  3.435507788613554*^9}},ExpressionUUID->"3c75bfb7-25d5-4ab8-ad8c-\
c269931af2aa"],

Cell[TextData[{
 "Numerical methods have to be applied in situations where it is impossible \
to solve the differential equation exactly. Here is a simple example. The \
following demonstrates that there are relatively simple looking first order \
differential equations that are impossible for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve exactly."
}], "Text",
 CellChangeTimes->{{3.435507795808782*^9, 
  3.4355078617233276`*^9}},ExpressionUUID->"9b789535-7b3e-4a54-bc82-\
422d44799dee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"y", "[", "t", "]"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"-", "2"}], ")"}]}], " ", "+", " ", 
       RowBox[{"t", "^", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", "[", "0.0", "]"}], "\[Equal]", "0.5"}]}], "}"}], ",", 
   RowBox[{"y", "[", "t", "]"}], ",", "t"}], "]"}]], "Input",
 CellChangeTimes->{{3.435504973822768*^9, 
  3.4355050300516443`*^9}},ExpressionUUID->"1c98b454-b6e7-4fe5-a79e-\
e6dac0930f5c"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       SuperscriptBox["t", "2"], "+", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"y", "[", "t", "]"}], "2"]]}]}], ",", 
     RowBox[{
      RowBox[{"y", "[", "0.`", "]"}], "\[Equal]", "0.5`"}]}], "}"}], ",", 
   RowBox[{"y", "[", "t", "]"}], ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{
  3.4355050357711554`*^9},ExpressionUUID->"3f20e01e-42d8-452b-8fa4-\
cf121810743d"]
}, Open  ]],

Cell[TextData[{
 "When DSolve can not solve an equation, you can at least solve it \
numerically by using NDSolve, the built-in numerical differential equation \
solver in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.435507869168824*^9, 3.43550790997828*^9}, 
   3.5135255765418*^9},ExpressionUUID->"27a7d6d1-1c24-49ba-8bdf-76518a5122e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", " ", "=", " ", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "[", "t", "]"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}]}], " ", "+", " ", 
        RowBox[{"t", "^", "2"}]}]}], ",", 
      RowBox[{
       RowBox[{"y", "[", "0.0", "]"}], "\[Equal]", "0.5"}]}], "}"}], ",", "y",
     ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0.0", ",", "2.0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.435505059849208*^9, {3.4355051034078856`*^9, 3.435505113802747*^9}, {
   3.4355051572055798`*^9, 3.4355051686913557`*^9}, {3.435505233943658*^9, 
   3.4355052355332766`*^9}},ExpressionUUID->"495d81df-cdf5-4cff-a06a-\
2af35f9e5083"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "2.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4355050702752385`*^9, 3.4355051705770807`*^9, 
  3.435505236265748*^9},ExpressionUUID->"c5bb272b-7472-403b-9bbe-\
ef1b93f38122"]
}, Open  ]],

Cell["\<\
We can use this result to get an estimate for what y[2.0] is.\
\>", "Text",
 CellChangeTimes->{{3.4355079257764983`*^9, 
  3.4355079402920885`*^9}},ExpressionUUID->"38918d15-1b58-443e-ba05-\
5524df06984c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Evaluate", "[", 
  RowBox[{
   RowBox[{"y", "[", "2.0", "]"}], "/.", 
   RowBox[{"soln", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4355051920681057`*^9, 3.4355051960421534`*^9}, {
  3.4355052390242043`*^9, 
  3.435505252505351*^9}},ExpressionUUID->"5cea0ba9-2512-4fd6-b9bb-\
92986bb0705c"],

Cell[BoxData["4.236832616929114`"], "Output",
 CellChangeTimes->{3.435505198021385*^9, 
  3.4355052533625484`*^9},ExpressionUUID->"952b5ab6-d788-4d89-9115-\
5946bbd642f4"]
}, Open  ]],

Cell["\<\
By way of comparison, here is the same equation solved by the Runge-Kutta \
method we developed above.\
\>", "Text",
 CellChangeTimes->{{3.435507950365408*^9, 
  3.4355079704964046`*^9}},ExpressionUUID->"8c674be8-7ed3-4715-84ed-\
f56cf47547c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.01"}]], "Input",
 CellChangeTimes->{{3.435505452684229*^9, 
  3.4355054582793875`*^9}},ExpressionUUID->"d31564c5-f8df-4fc0-bc97-\
034f3da771bb"],

Cell[BoxData["0.01`"], "Output",
 CellChangeTimes->{
  3.435505460321075*^9},ExpressionUUID->"34218adb-6559-466f-9c04-\
063aaa75c135"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"y", "^", 
    RowBox[{"(", 
     RowBox[{"-", "2"}], ")"}]}], "+", 
   RowBox[{"t", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4355052799356556`*^9, 
  3.4355052985134525`*^9}},ExpressionUUID->"13e7af6e-64c7-4cb9-9491-\
cdf7606ec2f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rungePts", " ", "=", " ", 
   RowBox[{"NestList", "[", 
    RowBox[{"runge", ",", 
     RowBox[{"{", 
      RowBox[{"0.", ",", "0.5"}], "}"}], ",", "200"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.434721854167074*^9, 3.434721865103314*^9}, {
   3.4347224470831375`*^9, 3.4347224840632515`*^9}, 3.4347226569339595`*^9, {
   3.435323748425414*^9, 3.435323760316039*^9}, {3.435324328612914*^9, 
   3.435324334769164*^9}, {3.4355054637966194`*^9, 
   3.435505467646213*^9}},ExpressionUUID->"be06ca7e-9ff7-4f1b-9649-\
019b0d7c0394"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rungePts", "[", 
  RowBox[{"[", 
   RowBox[{"-", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.435505473256957*^9, 
  3.4355054784313097`*^9}},ExpressionUUID->"a05ccf5b-5e3e-4325-b9ad-\
520fefe08e35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.0000000000000013`", ",", "4.236832522909276`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.435505479382019*^9},ExpressionUUID->"ecf72072-8838-41a9-b7c3-\
0021d4c27877"]
}, Open  ]],

Cell["\<\
Out to 6 digits the produces the same result as NDSolve. (This is actually \
not that surprising, since NDSolve is actually using a variant of the \
Runge-Kutta method to do its work.)\
\>", "Text",
 CellChangeTimes->{{3.435507984808652*^9, 
  3.4355080302559395`*^9}},ExpressionUUID->"bcc3dcc0-8407-4f01-9fdf-\
77054cb52308"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Runge-Kutta-Fehlberg Method", "Subsection",
 CellChangeTimes->{{3.4359392239174023`*^9, 
  3.4359392362600036`*^9}},ExpressionUUID->"6688477a-bc40-4818-b1ff-\
cc8abed3e525"],

Cell["\<\
This section of our notes will take you through the process of using the \
Runge-Kutta-Fehlberg variable step size method to solve a first order DE.\
\>", "Text",
 CellChangeTimes->{{3.4359392401288137`*^9, 3.4359392849725556`*^9}, {
  3.5129180734716*^9, 
  3.5129180831124*^9}},ExpressionUUID->"f7adf7da-89a7-46eb-b896-998ab2ced901"],

Cell[CellGroupData[{

Cell["The exact solution", "Subsubsection",
 CellChangeTimes->{{3.4358709504208655`*^9, 
  3.4358709549098654`*^9}},ExpressionUUID->"90a91187-4dc5-4559-b52d-\
3ca5f7e14805"],

Cell["\<\
To make it easier to judge whether or not our methods are working correctly, \
we choose a differential equation that can be solved exactly. The problem we \
solve comes from exercise 3a at the end of section 5.5.

Here is the equation solved exactly with DSolve.\
\>", "Text",
 CellChangeTimes->{{3.4359392975970945`*^9, 
  3.4359393886316133`*^9}},ExpressionUUID->"d4eecf5f-51ca-4d40-a824-\
7cfe2c4f08e8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", " ", "=", " ", "1.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", " ", "=", " ", "3.0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4358626361758657`*^9, 3.4358626380488653`*^9}, {
  3.4358673402948656`*^9, 
  3.4358673612308655`*^9}},ExpressionUUID->"2ec6c6b8-c986-42ff-86f9-\
3d5cae03a44a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soln", " ", "=", " ", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}], " ", "\[Equal]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "/", "t"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"y", "[", "t", "]"}], "/", "t"}], ")"}], "^", "2"}]}]}], 
      ",", 
      RowBox[{
       RowBox[{"y", "[", "a", "]"}], " ", "\[Equal]", " ", "1."}]}], "}"}], 
    ",", "y", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4347199081537085`*^9, 3.434719990660884*^9}, {
  3.4347200789951324`*^9, 3.4347201049454336`*^9}, {3.43472028947223*^9, 
  3.434720290050292*^9}, {3.43507350946875*^9, 3.435073517734375*^9}, {
  3.4353221657499065`*^9, 3.4353221659999094`*^9}, {3.4353223442678165`*^9, 
  3.4353223448615737`*^9}, {3.435862561875866*^9, 3.4358625914498653`*^9}, {
  3.4358626624588656`*^9, 3.4358626875608654`*^9}, {3.435862863698866*^9, 
  3.4358628873938656`*^9}, {3.4358673652478657`*^9, 
  3.4358673664248657`*^9}},ExpressionUUID->"93846ac5-3bdb-4a16-b223-\
4c565407c12a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      FractionBox["t", 
       RowBox[{"1.`", "\[InvisibleSpace]", "+", 
        RowBox[{"Log", "[", "t", "]"}]}]]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4347199623825297`*^9, 3.434719991504547*^9}, {
   3.434720080682449*^9, 3.4347201062421675`*^9}, 3.434720291003313*^9, 
   3.434720398850371*^9, 3.4347229182163563`*^9, 3.4347232943448963`*^9, 
   3.435073359484375*^9, {3.435073512453125*^9, 3.43507351865625*^9}, 
   3.43532216996871*^9, 3.4353223456115837`*^9, 3.4353293518650303`*^9, 
   3.43550287434375*^9, 3.435860984238866*^9, 3.4358625935708656`*^9, 
   3.4358626926168656`*^9, 3.435862892257866*^9, 
   3.4358673683278656`*^9},ExpressionUUID->"5779f49f-d8c3-4585-af64-\
5e309f2e2206"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Y", "[", "t_", "]"}], " ", "=", 
  RowBox[{"Evaluate", "[", " ", 
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "/.", 
    RowBox[{"soln", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435859419172866*^9, 
  3.4358594363908653`*^9}},ExpressionUUID->"5e645da3-7951-4122-bc2d-\
f50d0767bc9b"],

Cell[BoxData[
 FractionBox["t", 
  RowBox[{"1.`", "\[InvisibleSpace]", "+", 
   RowBox[{"Log", "[", "t", "]"}]}]]], "Output",
 CellChangeTimes->{3.435860987066866*^9, 3.435862697193866*^9, 
  3.4358628966048656`*^9},ExpressionUUID->"adf865be-459d-4c07-b54f-\
3f43a686a705"]
}, Open  ]],

Cell["Here is a plot of the exact solution.", "Text",
 CellChangeTimes->{{3.43593939840545*^9, 
  3.4359394044044557`*^9}},ExpressionUUID->"eaeac017-7b8e-44e3-b0c8-\
7591dbbe6f51"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot1", " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Y", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "a", ",", "b"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4358627038248653`*^9, 3.435862704495866*^9}, {
  3.4358629002558656`*^9, 3.4358629031598654`*^9}, {3.4358630256098657`*^9, 
  3.4358630257758656`*^9}, {3.4358673733618655`*^9, 
  3.4358673762548656`*^9}},ExpressionUUID->"7aeb0435-162c-4107-a9f5-\
ad06e74c9510"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0ws0lVkUB3Cuy837FeUq3IqQMvIKN/sj3SiVPFJMidJMiYzyaIqi9DAe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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 1.},
  PlotRange->{{1, 3}, {1.0000000000000009`, 1.4295160639399622`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4358623377688656`*^9, 3.4358627064148655`*^9, 
  3.4358629041188655`*^9, 
  3.4358630267398653`*^9},ExpressionUUID->"bf967fa5-bce5-4928-8a46-\
31d9964912a6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Runge-Kutta method with fixed step", "Subsubsection",
 CellChangeTimes->{{3.435870961127866*^9, 
  3.4358709674618654`*^9}},ExpressionUUID->"845c9605-b03a-412d-ab0c-\
2681c3180787"],

Cell[TextData[{
 "For comparison purposes, we first solve the initial value problem with the \
Runge-Kutta method with step size ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", " ", "=", " ", "0.2"}], TraditionalForm]],ExpressionUUID->
  "62727dc6-91c4-487e-9b0a-e7c05357ef4c"],
 "."
}], "Text",
 CellChangeTimes->{{3.435939412032434*^9, 3.4359394456613245`*^9}, {
  3.435940202298092*^9, 
  3.435940203095089*^9}},ExpressionUUID->"cba40b70-0892-4fd1-8fce-\
68a451e86cb1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"runge", "[", 
   RowBox[{"{", 
    RowBox[{"t_", ",", "y_"}], "}"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k1", ",", "k2", ",", "k3", ",", "k4"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"k1", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{"t", ",", "y"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k2", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", 
         RowBox[{"h", "/", "2"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k1", "*", 
          RowBox[{"h", "/", "2"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k3", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", 
         RowBox[{"h", "/", "2"}]}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k2", "*", 
          RowBox[{"h", "/", "2"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"k4", " ", "=", " ", 
      RowBox[{"f", "[", 
       RowBox[{
        RowBox[{"t", "+", "h"}], ",", 
        RowBox[{"y", "+", 
         RowBox[{"k3", "*", "h"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "+", "h"}], ",", 
       RowBox[{"y", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"k1", "+", 
           RowBox[{"2", "*", "k2"}], "+", 
           RowBox[{"2", "*", "k3"}], "+", "k4"}], ")"}], "*", 
         RowBox[{"h", "/", "6"}]}]}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435324150284789*^9, 3.435324295800414*^9}, {
  3.435324415706664*^9, 3.435324419441039*^9}, {3.4353380673437815`*^9, 
  3.4353381418362603`*^9}},ExpressionUUID->"5f21af6f-79d8-4df9-b788-\
d4ade1cda95f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"t_", ",", "y_"}], "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"y", "/", "t"}], " ", "-", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"y", "/", "t"}], ")"}], "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4358627176648655`*^9, 3.4358627271048656`*^9}, {
  3.4358629132168655`*^9, 
  3.4358629208878655`*^9}},ExpressionUUID->"3ff69426-5291-451a-a503-\
73abc50d5d9c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", " ", "=", " ", "0.2"}]], "Input",
 CellChangeTimes->{{3.4347225901760263`*^9, 3.4347225926444917`*^9}, {
  3.435323743222289*^9, 3.435323743331664*^9}, {3.4358629558878655`*^9, 
  3.435862956014866*^9}},ExpressionUUID->"3d9d95c0-9d6f-42d3-85cb-\
b8a415b28f29"],

Cell[BoxData["0.2`"], "Output",
 CellChangeTimes->{3.4347226536374645`*^9, 3.4347232817213507`*^9, 
  3.435323744612914*^9, 3.435324324066039*^9, 3.4353381561346908`*^9, 
  3.4355054153883667`*^9, 3.4358623964568653`*^9, 3.4358627315058656`*^9, 
  3.4358629573818655`*^9},ExpressionUUID->"e382703c-e89d-49c3-b4f0-\
ca889173a7b3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rungePts", " ", "=", " ", 
  RowBox[{"NestList", "[", 
   RowBox[{"runge", ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "1."}], "}"}], ",", 
    RowBox[{"Round", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "-", "a"}], ")"}], "/", "h"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.434721854167074*^9, 3.434721865103314*^9}, {
   3.4347224470831375`*^9, 3.4347224840632515`*^9}, 3.4347226569339595`*^9, {
   3.435323748425414*^9, 3.435323760316039*^9}, {3.435324328612914*^9, 
   3.435324334769164*^9}, {3.435862738745866*^9, 3.4358627485198655`*^9}, {
   3.4358629275528655`*^9, 3.4358629615418653`*^9}, {3.4358630327888656`*^9, 
   3.435863033087866*^9}, {3.4358673895698657`*^9, 
   3.4358674241828656`*^9}},ExpressionUUID->"6e34cec1-fe46-4b7a-bf90-\
73faccc959bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2`", ",", "1.0149468167045208`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4`", ",", "1.047527593023122`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5999999999999999`", ",", "1.0884262712672048`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.7999999999999998`", ",", "1.1336471884274983`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9999999999999998`", ",", "1.1812259096859539`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1999999999999997`", ",", "1.2301041364213465`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.4`", ",", "1.279673849527534`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.6`", ",", "1.3295692135780879`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.8000000000000003`", ",", "1.3795627466650087`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.0000000000000004`", ",", "1.4295098164708337`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.43472186596259*^9, {3.434721947234476*^9, 3.4347219689351015`*^9}, 
   3.434722033708888*^9, 3.4347222023769555`*^9, {3.434722466252804*^9, 
   3.4347224847662954`*^9}, 3.4347226581525693`*^9, 3.4347230994142303`*^9, 
   3.434723284314802*^9, {3.435323763362914*^9, 3.435323780519164*^9}, 
   3.435324365941039*^9, {3.435324398487914*^9, 3.435324423472289*^9}, 
   3.435338158478696*^9, 3.4358623995888653`*^9, 3.4358627495588655`*^9, {
   3.435862940752866*^9, 3.4358629645988655`*^9}, 3.4358630342278657`*^9, {
   3.435867402160866*^9, 
   3.4358674255168657`*^9}},ExpressionUUID->"8474a16f-73e9-4f6a-99b0-\
a219ab45caee"]
}, Open  ]],

Cell[TextData[{
 "Since we have the exact solution we can compute the actual error at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "3"}], TraditionalForm]],ExpressionUUID->
  "53bbdeab-97f6-4723-9604-d56fd76168ff"],
 ":"
}], "Text",
 CellChangeTimes->{{3.4359394560930157`*^9, 
  3.4359394768937454`*^9}},ExpressionUUID->"37e60375-b2ba-4522-a5b9-\
286ccf05724a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rungeError", " ", "=", " ", 
  RowBox[{
   RowBox[{"Y", "[", "b", "]"}], "-", 
   RowBox[{"rungePts", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4358623674018655`*^9, 3.4358623866238656`*^9}, {
   3.435862757153866*^9, 3.435862757257866*^9}, {3.4358629488178654`*^9, 
   3.4358629489528656`*^9}, {3.4358630418258657`*^9, 3.4358630419758654`*^9}, 
   3.435867430672866*^9},ExpressionUUID->"6212da6a-7f80-44e8-abe9-\
c94377a051cb"],

Cell[BoxData["6.25765067918671`*^-6"], "Output",
 CellChangeTimes->{{3.435862388035866*^9, 3.435862401929866*^9}, 
   3.4358627586408653`*^9, {3.4358629431668653`*^9, 3.435862967132866*^9}, {
   3.4358630372728653`*^9, 3.435863042580866*^9}, 
   3.4358674323328657`*^9},ExpressionUUID->"fdbd931d-e831-400b-8a1b-\
e87ef4ff6d90"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Runge-Kutta-Fehlberg", "Subsubsection",
 CellChangeTimes->{{3.4358709792898655`*^9, 
  3.435870985804866*^9}},ExpressionUUID->"9c18815b-ba25-48fd-8b8c-\
e5bcb3b7f151"],

Cell[TextData[{
 "Here now is the code to do one step in the Runge-Kutta-Fehlberg method. \
This function takes as its input a list composed of a value for ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "c1cb0829-980d-4efc-9425-c838d167def8"],
 ", a suggested step size ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "9723b393-db59-4b57-8ff1-ad72b847c9c6"],
 ", and a value for ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "dd186345-8bbc-42b0-920c-ea6b95b6d500"],
 ". It returns a new ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "c7e944a7-7e0d-4436-9c26-66d03962aa70"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "497ae12e-f346-4e1a-87c3-ea92c9eb58c2"],
 " along with a new suggested step size to use for the next iteration. The \
function does its work by first computing an error estimate, ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "7ed21238-2d0a-4dc9-9e32-4525c5166263"],
 ". Once the error ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "781b41fe-ac48-4170-a5ee-14bcd161cfb5"],
 " is known, we can use it to compute the new step size, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", " ", "h"}], TraditionalForm]],ExpressionUUID->
  "7431a6df-5b9c-4e97-bfed-7615fe9191c9"],
 ". If ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "dc70666d-6a3c-40ec-97c7-0dbcd6891d21"],
 " is smaller than a preset tolerance, TOL, we go ahead and return the result \
of the estimate. If the error exceeds TOL, we redo the estimate with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", " ", "h"}], TraditionalForm]],ExpressionUUID->
  "53e642c5-67f1-47ef-9471-d050acb51058"],
 " in place of ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]],ExpressionUUID->
  "35919c2f-4b4c-42ad-9ebc-e4b7639db5d6"],
 " and return the result of that instead."
}], "Text",
 CellChangeTimes->{{3.435939488249565*^9, 3.435939754426607*^9}, {
  3.4359402521255784`*^9, 
  3.4359402533128047`*^9}},ExpressionUUID->"fec685c3-a7c4-47ed-8fb3-\
7ec231633cb5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rkf", "[", 
    RowBox[{"{", 
     RowBox[{"t_", ",", "h_", ",", "y_"}], "}"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "k1", ",", "k2", ",", "k3", ",", "k4", ",", "k5", ",", "k6", ",", 
       "est1", ",", "est2", ",", "r", ",", "q", ",", "newH"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"k1", " ", "=", " ", 
       RowBox[{"h", "*", 
        RowBox[{"f", "[", 
         RowBox[{"t", ",", "y"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"k2", " ", "=", " ", 
       RowBox[{"h", "*", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"t", "+", 
           RowBox[{"h", "/", "4"}]}], ",", 
          RowBox[{"y", "+", 
           RowBox[{"k1", "/", "4"}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"k3", "=", " ", 
       RowBox[{"h", "*", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"t", "+", 
           RowBox[{"3", "*", 
            RowBox[{"h", "/", "8"}]}]}], ",", 
          RowBox[{"y", "+", 
           RowBox[{"3", "*", 
            RowBox[{"k1", "/", "32"}]}], "+", 
           RowBox[{"9", "*", 
            RowBox[{"k2", "/", "32"}]}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"k4", "=", 
       RowBox[{"h", "*", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"t", "+", 
           RowBox[{"12", "*", 
            RowBox[{"h", "/", "13"}]}]}], ",", 
          RowBox[{"y", "+", 
           RowBox[{"1932", "*", 
            RowBox[{"k1", "/", "2197"}]}], "-", 
           RowBox[{"7200", "*", 
            RowBox[{"k2", "/", "2197"}]}], "+", 
           RowBox[{"7296", "*", 
            RowBox[{"k3", "/", "2197"}]}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"k5", " ", "=", " ", 
       RowBox[{"h", "*", " ", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"t", " ", "+", " ", "h"}], ",", 
          RowBox[{"y", " ", "+", " ", 
           RowBox[{"439", "*", 
            RowBox[{"k1", "/", "216"}]}], "-", 
           RowBox[{"8", "*", "k2"}], "+", 
           RowBox[{"3680", "*", 
            RowBox[{"k3", "/", "513"}]}], "-", 
           RowBox[{"845", "*", 
            RowBox[{"k4", "/", "4104"}]}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"k6", " ", "=", " ", 
       RowBox[{"h", "*", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"t", " ", "+", " ", 
           RowBox[{"h", "/", "2"}]}], ",", 
          RowBox[{"y", "-", 
           RowBox[{"8", "*", 
            RowBox[{"k1", "/", "27"}]}], "+", 
           RowBox[{"2", "*", "k2"}], "-", 
           RowBox[{"3544", "*", 
            RowBox[{"k3", "/", "2565"}]}], "+", 
           RowBox[{"1859", "*", 
            RowBox[{"k4", "/", "4104"}]}], "-", 
           RowBox[{"11", "*", 
            RowBox[{"k5", "/", "40"}]}]}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"r", "=", " ", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"k1", "/", "360"}], "-", 
          RowBox[{"128", "*", 
           RowBox[{"k3", "/", "4275"}]}], "-", 
          RowBox[{"2197", "*", 
           RowBox[{"k4", "/", "75240"}]}], "+", 
          RowBox[{"k5", "/", "50"}], "+", 
          RowBox[{"2", "*", 
           RowBox[{"k6", "/", "55"}]}]}], "]"}], "/", "h"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"q", " ", "=", " ", 
       RowBox[{"0.84", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"TOL", "/", "r"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "4"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"newH", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"q", " ", "\[LessEqual]", " ", "0.1"}], ",", 
         RowBox[{"0.1", "*", "h"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"q", "\[GreaterEqual]", "4"}], ",", 
           RowBox[{"4", "*", "h"}], ",", 
           RowBox[{"q", "*", "h"}]}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"r", " ", ">=", " ", "TOL"}], ",", 
        RowBox[{"rkf", "[", 
         RowBox[{"{", 
          RowBox[{"t", ",", "newH", ",", "y"}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"t", "+", "h"}], ",", "newH", ",", 
          RowBox[{"y", "+", 
           RowBox[{"25", "*", 
            RowBox[{"k1", "/", "216"}]}], "+", 
           RowBox[{"1408", "*", 
            RowBox[{"k3", "/", "2565"}]}], "+", 
           RowBox[{"2197", "*", 
            RowBox[{"k4", "/", "4104"}]}], "-", 
           RowBox[{"k5", "/", "5"}]}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4358594439538655`*^9, 3.4358594946578655`*^9}, {
   3.4358595481768656`*^9, 3.435860031139866*^9}, {3.4358600719018655`*^9, 
   3.4358600725168657`*^9}, {3.4358601349908657`*^9, 3.4358602318218656`*^9}, 
   3.4358602701028657`*^9, {3.435860301757866*^9, 3.4358605556198654`*^9}, {
   3.4358606568218656`*^9, 3.435860657396866*^9}, {3.4358607312038655`*^9, 
   3.4358607651248655`*^9}, {3.4358611375328655`*^9, 
   3.4358611389598656`*^9}, {3.4358613676318655`*^9, 
   3.4358614948028655`*^9}, {3.4358615639328656`*^9, 3.435861564922866*^9}, {
   3.4358617107118654`*^9, 3.4358617564448657`*^9}, {3.4358618022448654`*^9, 
   3.4358618157288656`*^9}, {3.4358618805658655`*^9, 3.435861898580866*^9}, {
   3.4358619531188655`*^9, 3.4358621089398656`*^9}, {3.4358710287078657`*^9, 
   3.4358710469548655`*^9}},ExpressionUUID->"6777105a-371c-46d2-897d-\
d1413762686e"],

Cell["\<\
We are now ready to apply this method. We have to provide a tolerance.\
\>", "Text",
 CellChangeTimes->{{3.4359397684706087`*^9, 
  3.435939783562436*^9}},ExpressionUUID->"bfc882f4-75d0-4ffe-8e8b-\
9c835221fbe1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TOL", " ", "=", " ", 
  RowBox[{"10", "^", 
   RowBox[{"(", 
    RowBox[{"-", "8"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.435860864870866*^9, 3.435860873934866*^9}, {
  3.4358610090728655`*^9, 3.4358610104078655`*^9}, {3.4358615380888653`*^9, 
  3.4358615385038657`*^9}, {3.4358621731688657`*^9, 
  3.435862174559866*^9}},ExpressionUUID->"a8fc3242-7342-4b26-9b75-\
fac684c71bf8"],

Cell[BoxData[
 FractionBox["1", "100000000"]], "Output",
 CellChangeTimes->{3.435860876344866*^9, 3.4358610112368655`*^9, 
  3.4358615396648655`*^9, 3.4358621755428658`*^9, 
  3.4358627730898657`*^9},ExpressionUUID->"2f6ba871-1e90-408d-a593-\
e98d51c6487d"]
}, Open  ]],

Cell[TextData[{
 "A further complication is that we can not use NestList to iterate this \
method. The problem is that the step size will be changing constantly, so we \
can't predict in advance how many steps it will take to go from ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "1a239046-7795-4478-9dac-9c4c261ca718"],
 " to ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "29a3568f-8a92-45a4-9c57-91c1a74ae896"],
 ". The solution is to use a variant of NestList, NestWhileList. \
NestWhileList takes as its third parameter a function. On each iteration it \
will apply that function to the result of the most recent iteration. If the \
function returns true, NestWhileList will continue for another iteration. If \
it returns false, the iteration will stop. Since we want our iteration to \
continue until the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "43a59d9b-4689-4fe9-aaab-996483ea6eb9"],
 " coordinate of the list returned by rkf passes ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "b"}], TraditionalForm]],ExpressionUUID->
  "52cc70d9-2878-47ce-9d4b-8bb471e71719"],
 ", we set up our test function like so:"
}], "Text",
 CellChangeTimes->{{3.4359397893802185`*^9, 3.4359399867410126`*^9}, {
  3.5129179501656*^9, 
  3.5129179863108*^9}},ExpressionUUID->"3582f468-8105-400a-856d-1e75f5e05c0f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"continueTest", "[", 
   RowBox[{"{", 
    RowBox[{"t_", ",", "h_", ",", "y_"}], "}"}], "]"}], " ", "=", " ", 
  RowBox[{"(", 
   RowBox[{"t", " ", "<", " ", "b"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.4358612009798656`*^9, 3.4358612474248657`*^9}, 
   3.4358615288728657`*^9, {3.4358622045058656`*^9, 3.4358622095128655`*^9}, {
   3.4358627689608655`*^9, 3.4358627690558653`*^9}, {3.4358629739128656`*^9, 
   3.435862974040866*^9}, {3.4358630486808653`*^9, 3.4358630488158655`*^9}, 
   3.4358674412328653`*^9},ExpressionUUID->"917cfd89-6c3e-4bc4-abdc-\
5c4df5eeb9a3"],

Cell[BoxData[
 RowBox[{"t", "<", "3.`"}]], "Output",
 CellChangeTimes->{{3.4358612295098658`*^9, 3.435861249059866*^9}, 
   3.4358615304458656`*^9, 3.4358622110758657`*^9, 3.4358627698888655`*^9, 
   3.4358629748728657`*^9, 3.4358630497098656`*^9, 
   3.435867443264866*^9},ExpressionUUID->"c5562461-c807-416a-9e3f-\
2fcc904f131b"]
}, Open  ]],

Cell["We are now ready to run the iteration.", "Text",
 CellChangeTimes->{{3.4359399974322743`*^9, 
  3.4359400039970846`*^9}},ExpressionUUID->"d4cde144-2def-4a3b-9b03-\
3fc520771db6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rkfList", " ", "=", " ", 
  RowBox[{"NestWhileList", "[", 
   RowBox[{"rkf", ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0.2", ",", "1."}], "}"}], ",", "continueTest"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4358608284788656`*^9, 3.4358609125048656`*^9}, {
   3.4358609429448657`*^9, 3.4358609433768654`*^9}, {3.4358610157618656`*^9, 
   3.435861017488866*^9}, {3.4358612345848656`*^9, 3.4358612362798653`*^9}, {
   3.4358613029178658`*^9, 3.4358613171598654`*^9}, {3.4358622154708652`*^9, 
   3.4358622169448657`*^9}, {3.4358627785458655`*^9, 
   3.4358627881688657`*^9}, {3.4358629804728656`*^9, 3.4358629833018656`*^9}, 
   3.4358674525468655`*^9},ExpressionUUID->"bfaf63ce-c5fc-4fe7-92f1-\
aa81d98eece1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "0.2`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.036078593964561`", ",", "0.033287578673196525`", ",", 
     "1.0006138342238589`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.0693661726377575`", ",", "0.03608970345851786`", ",", 
     "1.0021555010025756`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.1054558760962754`", ",", "0.038836232620588766`", ",", 
     "1.0047244101603556`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.144292108716864`", ",", "0.0418997248548104`", ",", 
     "1.0083768283672718`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.1861918335716743`", ",", "0.04529930155693054`", ",", 
     "1.0131913939333188`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.2314911351286049`", ",", "0.04908193381722819`", ",", 
     "1.0192558354448555`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.280573068945833`", ",", "0.05330051107172977`", ",", 
     "1.0266697484860332`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.3338735800175627`", ",", "0.058016550324148694`", ",", 
     "1.0355460460643313`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.3918901303417115`", ",", "0.06330168259947035`", ",", 
     "1.0460127918576871`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.4551918129411818`", ",", "0.0692395826934981`", ",", 
     "1.0582153274547281`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.52443139563468`", ",", "0.07592834651058175`", ",", 
     "1.072318766835246`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.6003597421452618`", ",", "0.08348347050172988`", ",", 
     "1.0885109403260373`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.6838432126469915`", ",", "0.09204164133695962`", ",", 
     "1.107005901024198`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.7758848539839511`", ",", "0.10176564194362381`", ",", 
     "1.1280481496954036`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.877650495927575`", ",", "0.1128508214293052`", ",", 
     "1.151917798258742`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.9905013173568802`", ",", "0.1255337987725028`", ",", 
     "1.1789369862960544`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.116035116129383`", ",", "0.14010441880482244`", ",", 
     "1.2094780062065`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.2561395349342055`", ",", "0.15692254018956775`", ",", 
     "1.2439738064101817`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.413062075123773`", ",", "0.17644218344585447`", ",", 
     "1.282931871430455`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.5895042585696273`", ",", "0.19924722952767632`", ",", 
     "1.3269530019204578`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.7887514880973034`", ",", "0.22610593964251888`", ",", 
     "1.3767573836725617`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "3.0148574277398223`", ",", "0.25805762832441254`", ",", 
     "1.4332218367058442`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.435860923047866*^9, 3.435860944193866*^9}, {
   3.4358609946698656`*^9, 3.4358610202558656`*^9}, {3.4358612379168653`*^9, 
   3.4358612517638655`*^9}, 3.4358613197468653`*^9, {3.4358615130118656`*^9, 
   3.4358615421268654`*^9}, 3.4358615836348658`*^9, {3.4358621555268655`*^9, 
   3.4358621782028656`*^9}, 3.435862218186866*^9, 3.4358627902148657`*^9, 
   3.435862989415866*^9, 
   3.4358630525368657`*^9},ExpressionUUID->"7df35a1a-9af7-4900-89f4-\
2a8b4fa72ef9"]
}, Open  ]],

Cell["\<\
Here is the actual error at the last point computed. As you can see, the rkf \
method has met the desired error tolerance.\
\>", "Text",
 CellChangeTimes->{{3.4359400137817774`*^9, 
  3.4359400421980267`*^9}},ExpressionUUID->"d891ee81-cefc-49f3-bdc6-\
1da63d1aa9af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rkfError", " ", "=", " ", 
  RowBox[{
   RowBox[{"Y", "[", 
    RowBox[{"rkfList", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], "]"}], "-", 
   RowBox[{"rkfList", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "3"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.435860956099866*^9, 3.4358609745038657`*^9}, {
  3.435861598264866*^9, 3.4358616022798653`*^9}, {3.4358632631548653`*^9, 
  3.4358632775348654`*^9}},ExpressionUUID->"58eb3cc2-a419-445d-9195-\
6981890e4f7a"],

Cell[BoxData[
 RowBox[{"-", "4.407185949517611`*^-9"}]], "Output",
 CellChangeTimes->{{3.4358609772698655`*^9, 3.4358610257398653`*^9}, 
   3.4358612595678654`*^9, 3.435861604309866*^9, {3.4358621635658655`*^9, 
   3.4358621822728653`*^9}, 3.435862795337866*^9, 3.4358629925378656`*^9, 
   3.4358630562298656`*^9},ExpressionUUID->"99a2afa7-ff9e-4f28-8fe1-\
de609abf4d6a"]
}, Open  ]],

Cell["\<\
Finally, we convert the data generated by the iteration above into a sequence \
of points and plot them alongside the exact solution.\
\>", "Text",
 CellChangeTimes->{{3.4359400527486143`*^9, 
  3.435940082165215*^9}},ExpressionUUID->"16a76d75-5696-465f-ad09-\
7618569adfd9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rkfPts", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rkfList", "[", 
       RowBox[{"[", 
        RowBox[{"k", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"rkfList", "[", 
       RowBox[{"[", 
        RowBox[{"k", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", 
      RowBox[{"Length", "[", "rkfList", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4358622659658656`*^9, 
  3.4358623161858654`*^9}},ExpressionUUID->"c1379a8b-fd63-4033-a8ac-\
1ec2e80986a6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.036078593964561`", ",", "1.0006138342238589`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0693661726377575`", ",", "1.0021555010025756`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1054558760962754`", ",", "1.0047244101603556`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.144292108716864`", ",", "1.0083768283672718`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1861918335716743`", ",", "1.0131913939333188`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2314911351286049`", ",", "1.0192558354448555`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.280573068945833`", ",", "1.0266697484860332`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3338735800175627`", ",", "1.0355460460643313`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3918901303417115`", ",", "1.0460127918576871`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4551918129411818`", ",", "1.0582153274547281`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.52443139563468`", ",", "1.072318766835246`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6003597421452618`", ",", "1.0885109403260373`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6838432126469915`", ",", "1.107005901024198`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.7758848539839511`", ",", "1.1280481496954036`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.877650495927575`", ",", "1.151917798258742`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9905013173568802`", ",", "1.1789369862960544`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.116035116129383`", ",", "1.2094780062065`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.2561395349342055`", ",", "1.2439738064101817`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.413062075123773`", ",", "1.282931871430455`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5895042585696273`", ",", "1.3269530019204578`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.7887514880973034`", ",", "1.3767573836725617`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.0148574277398223`", ",", "1.4332218367058442`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.435862317601866*^9, 3.435862799672866*^9, 
  3.435862998297866*^9, 
  3.4358630688978653`*^9},ExpressionUUID->"1b207200-9c65-4953-a641-\
d635652c3b4d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plot2", " ", "=", " ", 
  RowBox[{"ListPlot", "[", "rkfPts", "]"}]}]], "Input",
 CellChangeTimes->{{3.435862420672866*^9, 
  3.4358624305758657`*^9}},ExpressionUUID->"e8782579-7b3a-4545-8f81-\
6e043ae273c6"],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAAAAAAAAA8D8AAAAAAADwP4Cd0iXH
k/A/jqrepoMC8D+C2C60HxzxPzwA5TTUCPA/jxIwgPKv8T8bGzLnWRPwPywo
AD4FT/I/MBu+vU8i8D/Wj79JpPryPyCE2C0INvA/dg9rDDC08z+P4vc0307w
P9ortC86ffQ/FKQYQj1t8D8tyLLSi1f1PxmTFbuYkfA/0xXXlS5F9j9sn8Po
d7zwP0fU3zV3SPc/LbT4MXPu8D8G8tMsEmT4P2QcJ7k3KPE/EJUl0RKb+T/a
naByimrxPwKRnpQF8fo/DgzW0Uu28T82KpU8Bmr8P8UUdDd8DPI/3jsVP9sK
/j/ZOXNbQW7yP18Vy+gX2f8/TvuCB+3c8j/DtKfRo+0AQBQ2HpwFWvM/Xgpu
4pIMAkBAzPkTUefzP/r+Pn3zTQNAWqPskeOG9D8zRjsCTrcEQP88KRIzO/U/
3mSw8FxPBkAgZxbAMgf2Pzb2MZJtHghA0ghJBXru9j+oMqkz
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.4358624332378654`*^9, 3.4358628023998656`*^9, 
  3.4358630006618657`*^9, 
  3.4358630712938657`*^9},ExpressionUUID->"c0a8ab43-908a-4abc-9d13-\
363daff68287"]
}, Open  ]],

Cell["\<\
This shows quite clearly that the method was using a relatively small step \
size in regions where the solution was changing quickly and relaxing to a \
larger step size when the solution became more linear.\
\>", "Text",
 CellChangeTimes->{{3.435940089792899*^9, 
  3.435940141835681*^9}},ExpressionUUID->"8e5de774-6424-44a8-b81c-\
d91f5073ddd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"plot1", ",", "plot2"}], "]"}]], "Input",
 CellChangeTimes->{{3.435862435068866*^9, 
  3.4358624413838654`*^9}},ExpressionUUID->"15191bc9-2370-4667-82e9-\
8633e841613b"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0ws0lVkUB3Cuy837FeUq3IqQMvIKN/sj3SiVPFJMidJMiYzyaIqi9DAe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      "]]}}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAAAAAAAAA8D8AAAAAAADwP4Cd0iXH
k/A/jqrepoMC8D+C2C60HxzxPzwA5TTUCPA/jxIwgPKv8T8bGzLnWRPwPywo
AD4FT/I/MBu+vU8i8D/Wj79JpPryPyCE2C0INvA/dg9rDDC08z+P4vc0307w
P9ortC86ffQ/FKQYQj1t8D8tyLLSi1f1PxmTFbuYkfA/0xXXlS5F9j9sn8Po
d7zwP0fU3zV3SPc/LbT4MXPu8D8G8tMsEmT4P2QcJ7k3KPE/EJUl0RKb+T/a
naByimrxPwKRnpQF8fo/DgzW0Uu28T82KpU8Bmr8P8UUdDd8DPI/3jsVP9sK
/j/ZOXNbQW7yP18Vy+gX2f8/TvuCB+3c8j/DtKfRo+0AQBQ2HpwFWvM/Xgpu
4pIMAkBAzPkTUefzP/r+Pn3zTQNAWqPskeOG9D8zRjsCTrcEQP88KRIzO/U/
3mSw8FxPBkAgZxbAMgf2Pzb2MZJtHghA0ghJBXru9j+oMqkz
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{1., 1.},
  ImageSize->{679., Automatic},
  PlotRange->{{1, 3}, {1.0000000000000009`, 1.4295160639399622`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4358624426188655`*^9, 3.4358628061158657`*^9, 
  3.435863004014866*^9, 
  3.4358630741058655`*^9},ExpressionUUID->"45481221-f72c-4049-b3b8-\
41a261fa997f"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
WindowSize->{880, 789},
WindowMargins->{{5, Automatic}, {Automatic, 37}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"13.1 for Mac OS X ARM (64-bit) (June 16, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"2fd17ef0-f47a-4e58-ae6f-30d123803193"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 294, 3, 54, "Subsection",ExpressionUUID->"d0f57ee0-199e-49ee-b7ac-1b7c83e66d16"],
Cell[CellGroupData[{
Cell[886, 29, 195, 3, 45, "Subsubsection",ExpressionUUID->"9643bf2c-1052-49c7-8521-1b3148e2ca61"],
Cell[1084, 34, 684, 13, 104, "Text",ExpressionUUID->"0b18ff41-04e8-4e7c-81cd-92350811d71e"],
Cell[CellGroupData[{
Cell[1793, 51, 956, 22, 30, "Input",ExpressionUUID->"95ce3852-4b3d-4b01-a1a5-a04ac17ec65a"],
Cell[2752, 75, 2630, 69, 134, "Output",ExpressionUUID->"bd579ae3-35b2-44eb-8c73-76973f83e1a5"]
}, Open  ]],
Cell[5397, 147, 366, 7, 58, "Text",ExpressionUUID->"83eca7f2-73a3-4224-beec-34c81e99a7be"],
Cell[5766, 156, 704, 13, 30, "Input",ExpressionUUID->"1cb924f2-f133-40b2-b6e3-8fd9c5c26a8c"],
Cell[6473, 171, 323, 7, 58, "Text",ExpressionUUID->"7d4b5d83-dfb4-469a-a6d2-06f1d97d6d12"],
Cell[CellGroupData[{
Cell[6821, 182, 558, 11, 30, "Input",ExpressionUUID->"c60dfde3-2603-4062-a037-9c5ddf947b1a"],
Cell[7382, 195, 2492, 47, 251, "Output",ExpressionUUID->"b73d4193-0a5f-41f5-9a09-47d960f9f7ee"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9923, 248, 169, 3, 45, "Subsubsection",ExpressionUUID->"fd645d20-d23c-411c-ad8f-a7dba4bd0074"],
Cell[10095, 253, 727, 14, 127, "Text",ExpressionUUID->"e53cd3f7-d057-4496-b67d-308577dbef39"],
Cell[10825, 269, 353, 9, 30, "Input",ExpressionUUID->"a6b4960f-d125-4a67-b099-4dd0b46524a3"],
Cell[11181, 280, 192, 3, 35, "Text",ExpressionUUID->"1ee6c9a2-d6b3-4a50-8fba-68e70f639a35"],
Cell[11376, 285, 719, 18, 30, "Input",ExpressionUUID->"8c2ea1e1-7544-4864-a61f-db08e3de6c8c"],
Cell[CellGroupData[{
Cell[12120, 307, 218, 5, 30, "Input",ExpressionUUID->"be8fe1d0-53d6-4506-a81e-06e984187434"],
Cell[12341, 314, 39102, 720, 430, "Output",ExpressionUUID->"31e5a355-dfb4-4c95-9141-e671ce18fb8a"]
}, Open  ]],
Cell[51458, 1037, 752, 12, 127, "Text",ExpressionUUID->"2d36c615-ab55-449d-a0c9-c44d40f3a68d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52247, 1054, 169, 3, 45, "Subsubsection",ExpressionUUID->"c52591d6-c93c-42f6-b92c-ac9e31fb23af"],
Cell[52419, 1059, 255, 6, 35, "Text",ExpressionUUID->"7385051f-3349-4203-a772-242417515084"],
Cell[52677, 1067, 677, 17, 30, "Input",ExpressionUUID->"84e4f48d-b641-43f9-bfba-1e07b54ad4f9"],
Cell[53357, 1086, 373, 9, 30, "Input",ExpressionUUID->"c135e3ef-5b35-4552-8b41-76f5b8f22522"],
Cell[CellGroupData[{
Cell[53755, 1099, 463, 8, 30, "Input",ExpressionUUID->"dae8a8bd-bc16-411f-9374-556e707c0227"],
Cell[54221, 1109, 417, 6, 34, "Output",ExpressionUUID->"7e5b38c3-7c16-4938-9803-97c4e59048e8"]
}, Open  ]],
Cell[54653, 1118, 257, 6, 35, "Text",ExpressionUUID->"b22880d6-dc9f-4043-b167-09b9d5964598"],
Cell[54913, 1126, 764, 15, 30, "Input",ExpressionUUID->"e0be180f-1f51-4b58-8767-3dcf8fc12dcc"],
Cell[55680, 1143, 409, 7, 58, "Text",ExpressionUUID->"16ef7ba7-ddd7-413b-8e4e-4bccd01542cc"],
Cell[CellGroupData[{
Cell[56114, 1154, 293, 8, 30, "Input",ExpressionUUID->"2cb93842-635f-4e64-a300-89ac173ca198"],
Cell[56410, 1164, 239, 3, 34, "Output",ExpressionUUID->"48ba0c2f-f3bd-40eb-9920-54ff83220cdf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56686, 1172, 314, 5, 30, "Input",ExpressionUUID->"65f75f9b-a223-4156-9a5f-688ce3dbc2ce"],
Cell[57003, 1179, 342, 5, 34, "Output",ExpressionUUID->"43f2c41d-8c76-469b-877f-7c6344b00be0"]
}, Open  ]],
Cell[57360, 1187, 287, 6, 58, "Text",ExpressionUUID->"71ce6a3b-befc-4425-8c5b-befe1bdccd7b"],
Cell[CellGroupData[{
Cell[57672, 1197, 198, 4, 30, "Input",ExpressionUUID->"b98d4af8-4d9a-4360-a5ee-f9064bc4ccbc"],
Cell[57873, 1203, 245, 3, 34, "Output",ExpressionUUID->"83e9d7bd-9531-4440-92c9-282e4a13f080"]
}, Open  ]],
Cell[58133, 1209, 263, 6, 35, "Text",ExpressionUUID->"3a66c874-7487-4bd3-a65f-f38571d875c4"],
Cell[CellGroupData[{
Cell[58421, 1219, 358, 7, 30, "Input",ExpressionUUID->"e09033ca-382d-4d3f-b42d-5dea90d7df2d"],
Cell[58782, 1228, 926, 18, 234, "Output",ExpressionUUID->"72b80e71-6f7e-4fe4-9fcc-a1542529dcaa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59745, 1251, 292, 6, 30, "Input",ExpressionUUID->"864be9ff-a461-41eb-b117-5957fb647fed"],
Cell[60040, 1259, 2845, 53, 417, "Output",ExpressionUUID->"5c1b687f-6839-4c1f-9bf2-4664d28d51ea"]
}, Open  ]],
Cell[62900, 1315, 399, 8, 58, "Text",ExpressionUUID->"aca838ba-2cf5-43d7-9000-a93a1aca28c8"],
Cell[CellGroupData[{
Cell[63324, 1327, 242, 5, 30, "Input",ExpressionUUID->"8035f4de-cf50-47b0-b3bc-8983063957f1"],
Cell[63569, 1334, 177, 2, 34, "Output",ExpressionUUID->"b55ff21d-4d84-4a6f-ae57-9b267c722605"]
}, Open  ]],
Cell[63761, 1339, 840, 16, 30, "Input",ExpressionUUID->"db2fb540-240c-4056-bfff-590467f444f1"],
Cell[64604, 1357, 385, 7, 58, "Text",ExpressionUUID->"3bd533a2-9b5c-4709-9739-5b4556ffe70a"],
Cell[CellGroupData[{
Cell[65014, 1368, 293, 8, 30, "Input",ExpressionUUID->"57aa2c32-3b05-40ff-811e-75d7d788e878"],
Cell[65310, 1378, 268, 4, 34, "Output",ExpressionUUID->"9ac15f8e-a2b2-4e8b-9dab-866bbf823e02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65615, 1387, 198, 4, 30, "Input",ExpressionUUID->"a351fc21-fe01-4769-af7b-a5a5199bcaed"],
Cell[65816, 1393, 272, 4, 34, "Output",ExpressionUUID->"f826f2f6-a357-47f6-9dae-19bf08d3802c"]
}, Open  ]],
Cell[66103, 1400, 206, 3, 35, "Text",ExpressionUUID->"5bc2b747-eafb-404c-84c0-44c30862595a"],
Cell[CellGroupData[{
Cell[66334, 1407, 360, 7, 30, "Input",ExpressionUUID->"f710992d-e06c-4b8d-9a4a-49ba01a28ef8"],
Cell[66697, 1416, 1326, 25, 234, "Output",ExpressionUUID->"54a5f9c3-181d-4147-b847-d7bcf9335b57"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68060, 1446, 292, 6, 30, "Input",ExpressionUUID->"ecfaa946-e0a2-4214-a9bf-caf40aa76bbd"],
Cell[68355, 1454, 3250, 61, 440, "Output",ExpressionUUID->"7bc66938-0c41-4539-aa1d-7f00d5ef36bd"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71654, 1521, 180, 3, 45, "Subsubsection",ExpressionUUID->"0cc43104-3990-4842-97a9-523a39abdc59"],
Cell[71837, 1526, 1537, 46, 142, "Text",ExpressionUUID->"55605f96-be7b-47c4-91d0-395e44faeaff"],
Cell[73377, 1574, 1572, 49, 88, "Text",ExpressionUUID->"676e44e0-349d-49eb-9e28-db25b158a49f"],
Cell[74952, 1625, 1371, 38, 104, "Text",ExpressionUUID->"aa48408b-adb9-4177-aa2a-7582bd3d8a55"],
Cell[76326, 1665, 1057, 28, 81, "Text",ExpressionUUID->"a4ae3dcb-8797-4e4f-bbc8-01de8337b93e"],
Cell[77386, 1695, 286, 6, 30, "Input",ExpressionUUID->"0e40de20-e7db-4850-b5f6-47baf0ad4e33"],
Cell[CellGroupData[{
Cell[77697, 1705, 422, 11, 30, "Input",ExpressionUUID->"1732cfb8-81a5-4ce6-9119-3f3488b094a5"],
Cell[78122, 1718, 1165, 41, 50, "Output",ExpressionUUID->"7bf49e7b-2dda-40c5-84ce-37341a77dbdc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79324, 1764, 964, 25, 30, "Input",ExpressionUUID->"7b2a74f8-8366-4d76-b374-b7a301d920d3"],
Cell[80291, 1791, 14315, 457, 340, "Output",ExpressionUUID->"6e7bb730-e9d8-41d0-b963-c7990a9abedf"]
}, Open  ]],
Cell[94621, 2251, 777, 21, 81, "Text",ExpressionUUID->"25889a16-70f4-4271-924d-0841df901594"],
Cell[95401, 2274, 263, 6, 35, "Text",ExpressionUUID->"156ccddf-7527-4ba1-ab33-738b40145b65"],
Cell[95667, 2282, 2193, 55, 94, "Input",ExpressionUUID->"52289563-32f3-401a-8d6a-9dedcd6922e5"],
Cell[97863, 2339, 239, 6, 35, "Text",ExpressionUUID->"622f6287-8dbe-4c41-8a52-16170f4f2947"],
Cell[CellGroupData[{
Cell[98127, 2349, 201, 5, 30, "Input",ExpressionUUID->"acdda1d1-dca5-4c17-986a-73ace1da7a59"],
Cell[98331, 2356, 1012, 33, 49, "Output",ExpressionUUID->"193ece58-eddb-4638-92d3-edffdb2a14fe"]
}, Open  ]],
Cell[99358, 2392, 361, 7, 58, "Text",ExpressionUUID->"d1e255bb-4993-4587-b865-1d913a107043"],
Cell[CellGroupData[{
Cell[99744, 2403, 1030, 23, 30, "Input",ExpressionUUID->"bac17b3d-43ff-45fb-b647-77f8dc9ff074"],
Cell[100777, 2428, 12769, 394, 294, "Output",ExpressionUUID->"f3143cfe-b4ff-4a50-b04e-529ad613671a"]
}, Open  ]],
Cell[113561, 2825, 536, 15, 35, "Text",ExpressionUUID->"400c3e52-4aeb-4c4b-9dc7-c2dddb2f3d79"],
Cell[114100, 2842, 414, 9, 30, "Input",ExpressionUUID->"8cac342c-f427-45ce-8832-529a4addde44"],
Cell[CellGroupData[{
Cell[114539, 2855, 234, 4, 30, "Input",ExpressionUUID->"8dd7d663-129c-41c8-8670-7897af04a97a"],
Cell[114776, 2861, 321, 5, 34, "Output",ExpressionUUID->"a787268b-3c6e-4d7e-a88a-bfc57887f6ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115134, 2871, 164, 4, 30, "Input",ExpressionUUID->"beb62567-a813-420e-8674-58f2bc97b3d9"],
Cell[115301, 2877, 2493, 73, 85, "Output",ExpressionUUID->"d69f5753-be70-4643-a22a-255dffd4335e"]
}, Open  ]],
Cell[117809, 2953, 265, 6, 35, "Text",ExpressionUUID->"25ec182a-0fc6-406c-9c76-e92f31175997"],
Cell[CellGroupData[{
Cell[118099, 2963, 402, 9, 30, "Input",ExpressionUUID->"951f7e0b-8a3c-4d02-abfd-4be0d902a5df"],
Cell[118504, 2974, 1127, 28, 56, "Output",ExpressionUUID->"8c16bab9-a8bf-41a3-864d-6428cffdae30"]
}, Open  ]],
Cell[119646, 3005, 257, 6, 35, "Text",ExpressionUUID->"61d1e865-d9c6-43aa-ab01-42c40b5aa3e9"],
Cell[CellGroupData[{
Cell[119928, 3015, 287, 6, 30, "Input",ExpressionUUID->"87962d8a-c0b4-47a7-8cf8-e5440a8d3a21"],
Cell[120218, 3023, 816, 17, 237, "Output",ExpressionUUID->"2e26a0bb-a22c-434e-a874-90d76fd93772"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121071, 3045, 214, 5, 30, "Input",ExpressionUUID->"cd767237-ae77-46e2-b277-92bc69f91e15"],
Cell[121288, 3052, 2716, 51, 389, "Output",ExpressionUUID->"a666b704-bbe9-4d96-b41a-35df181f2476"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124065, 3110, 179, 3, 54, "Subsection",ExpressionUUID->"c2a87ceb-72a8-42ff-aeba-3d4a954c8fce"],
Cell[124247, 3115, 368, 7, 47, "Text",ExpressionUUID->"24119a21-532b-45a3-849d-84cfaeb5690c"],
Cell[124618, 3124, 336, 7, 47, "Text",ExpressionUUID->"63c4a41a-cae4-470d-8267-e2909afd7263"],
Cell[CellGroupData[{
Cell[124979, 3135, 170, 3, 27, "Subsubsection",ExpressionUUID->"f6903f23-b9b1-4714-808f-86c9c5fe38db"],
Cell[125152, 3140, 887, 20, 65, "Text",ExpressionUUID->"39968e6d-238f-4a18-bdc8-279419cd2d01"],
Cell[126042, 3162, 619, 17, 47, "Text",ExpressionUUID->"fb6a70d4-ae14-4a9d-bfc4-35ab0caab331"],
Cell[126664, 3181, 2456, 71, 170, "Text",ExpressionUUID->"c008f9e7-b1eb-425c-822c-5c00476b1c37"],
Cell[129123, 3254, 949, 24, 50, "Text",ExpressionUUID->"62945e57-c244-4dad-bdf0-cbbfa8c50a2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130109, 3283, 244, 3, 27, "Subsubsection",ExpressionUUID->"7477762e-e19c-42f2-9095-12f3f9efbf16"],
Cell[130356, 3288, 528, 11, 65, "Text",ExpressionUUID->"73a5bdf3-aa1c-4c01-a537-2a0b4e79987b"],
Cell[130887, 3301, 495, 14, 29, "Text",ExpressionUUID->"79cc4707-0c93-4e2e-ba1e-15b4c99e578a"],
Cell[131385, 3317, 2193, 55, 92, "Input",ExpressionUUID->"56f87ffb-2f14-454a-936c-72ada9e2b662"],
Cell[133581, 3374, 604, 14, 31, "Input",ExpressionUUID->"f2fb33ab-fd90-4c82-9b72-b5d35794e6ae"],
Cell[134188, 3390, 277, 6, 29, "Text",ExpressionUUID->"f7f539dd-25ab-4196-8818-eb0a9158a91d"],
Cell[CellGroupData[{
Cell[134490, 3400, 183, 4, 31, "Input",ExpressionUUID->"6cdd8682-594f-4a92-aae2-d39035cc4d25"],
Cell[134676, 3406, 6930, 219, 148, "Output",ExpressionUUID->"bf4c5913-177c-40ca-b024-db29a0f6a634"]
}, Open  ]],
Cell[141621, 3628, 444, 8, 47, "Text",ExpressionUUID->"463c9587-af52-4bd6-8bb4-8c620decbcef"],
Cell[142068, 3638, 2219, 62, 83, "Text",ExpressionUUID->"012bfd30-7462-4c85-80e0-7c40507f6cdd"],
Cell[144290, 3702, 924, 23, 65, "Text",ExpressionUUID->"0e5ba330-3f93-4cfb-961f-fed071fa005c"],
Cell[145217, 3727, 867, 18, 65, "Text",ExpressionUUID->"72f592fa-8304-4b23-aef5-88466dd614e5"],
Cell[146087, 3747, 907, 28, 29, "Text",ExpressionUUID->"06f75dad-db17-4229-bdc1-edb0a3bf5461"],
Cell[CellGroupData[{
Cell[147019, 3779, 432, 12, 31, "Input",ExpressionUUID->"caaa6588-acdc-4b99-8cc3-a6b969e14854"],
Cell[147454, 3793, 3004, 108, 119, "Output",ExpressionUUID->"45e9041c-775f-43e0-ab46-78881b0039d3"]
}, Open  ]],
Cell[150473, 3904, 1471, 40, 67, "Text",ExpressionUUID->"a63520bd-31f0-4dda-a386-8393eff4afce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151981, 3949, 166, 3, 27, "Subsubsection",ExpressionUUID->"f7d76ac2-b078-4ead-a657-288120fd5f79"],
Cell[152150, 3954, 326, 7, 47, "Text",ExpressionUUID->"f27f1bfd-eea3-45bd-bf38-f9ff71114017"],
Cell[CellGroupData[{
Cell[152501, 3965, 183, 4, 31, "Input",ExpressionUUID->"b25ca3a4-3358-40c7-a622-a58c39eb9a98"],
Cell[152687, 3971, 865, 30, 47, "Output",ExpressionUUID->"5a6032b7-1046-4d4e-8074-206adfbaa964"]
}, Open  ]],
Cell[153567, 4004, 262, 8, 29, "Text",ExpressionUUID->"b305519f-4f56-41e8-9309-1d841f29063c"],
Cell[153832, 4014, 293, 7, 31, "Input",ExpressionUUID->"c8e23b2c-1a71-4fb1-9245-31df57600df4"],
Cell[154128, 4023, 575, 16, 31, "Input",ExpressionUUID->"04c4ad7c-bbc4-4ec4-a819-79408cfda594"],
Cell[CellGroupData[{
Cell[154728, 4043, 389, 11, 31, "Input",ExpressionUUID->"0b64e2e8-04e2-4fab-b5f6-a299e50e4f3b"],
Cell[155120, 4056, 665, 21, 30, "Output",ExpressionUUID->"19e80ad3-49a3-40e5-8366-2f6b5047d777"]
}, Open  ]],
Cell[155800, 4080, 923, 22, 47, "Text",ExpressionUUID->"3b0a53ff-02ce-4618-9bbd-54b223887086"],
Cell[156726, 4104, 378, 11, 29, "Text",ExpressionUUID->"e24f2a1e-c2bb-4862-ab2d-b0a3bdb59015"],
Cell[CellGroupData[{
Cell[157129, 4119, 534, 14, 31, "Input",ExpressionUUID->"b6e93afd-c421-432b-842d-b3e24a23ed51"],
Cell[157666, 4135, 1197, 42, 33, "Output",ExpressionUUID->"96981a2a-1a94-4c02-a71f-77e99096cd49"]
}, Open  ]],
Cell[158878, 4180, 1002, 31, 29, "Text",ExpressionUUID->"1db3be61-3f06-4e6a-bd08-a3205ec842dd"],
Cell[CellGroupData[{
Cell[159905, 4215, 341, 7, 31, "Input",ExpressionUUID->"202744c2-fb0b-4687-b2d8-d3ab1fe56345"],
Cell[160249, 4224, 253, 6, 30, "Output",ExpressionUUID->"701457ba-def1-4110-9c23-7d8436258f52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[160539, 4235, 608, 18, 31, "Input",ExpressionUUID->"43005adc-296a-4fc9-9f4c-852b209eabe0"],
Cell[161150, 4255, 1256, 42, 33, "Output",ExpressionUUID->"6ee5b5ab-6753-4115-9e88-6cdcc48796b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162443, 4302, 327, 9, 31, "Input",ExpressionUUID->"3b9e4bea-b0d9-4adc-ad53-d063e62885fb"],
Cell[162773, 4313, 1510, 50, 33, "Output",ExpressionUUID->"39817cf5-06c4-4253-8d28-0a5be497d8ec"]
}, Open  ]],
Cell[164298, 4366, 465, 12, 31, "Text",ExpressionUUID->"a082ee2b-68d7-4f32-a60f-a9494496f062"],
Cell[CellGroupData[{
Cell[164788, 4382, 419, 9, 31, "Input",ExpressionUUID->"7a408aa0-f38d-40b1-b881-62930a6a7c3c"],
Cell[165210, 4393, 2224, 77, 83, "Output",ExpressionUUID->"3894b622-884e-4152-97f8-8811fe7ee254"]
}, Open  ]],
Cell[167449, 4473, 298, 6, 29, "Text",ExpressionUUID->"e1bd810d-cd83-4562-80c8-7678a261be5b"],
Cell[167750, 4481, 522, 11, 47, "Text",ExpressionUUID->"eca5d6b5-cfa4-43e3-a42e-98222bce2bdc"],
Cell[CellGroupData[{
Cell[168297, 4496, 514, 12, 31, "Input",ExpressionUUID->"33f945c6-9888-4e03-b8f6-4170b2bc496a"],
Cell[168814, 4510, 471, 14, 47, "Output",ExpressionUUID->"820a7845-de2d-4a60-b26f-78f4fbcc718d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169322, 4529, 509, 12, 31, "Input",ExpressionUUID->"ec87c31d-5f27-427a-b73d-2458e4226e2d"],
Cell[169834, 4543, 286, 8, 47, "Output",ExpressionUUID->"6da3a6ba-80e0-4a7c-99b5-49810417e70f"]
}, Open  ]],
Cell[170135, 4554, 225, 5, 29, "Text",ExpressionUUID->"0719336d-977a-4ad4-8483-8f8514a8367a"],
Cell[CellGroupData[{
Cell[170385, 4563, 805, 17, 31, "Input",ExpressionUUID->"f09f5ed3-fe44-447c-b906-95f3481f37fd"],
Cell[171193, 4582, 367, 11, 47, "Output",ExpressionUUID->"be85ad9c-fea2-4ea4-959e-6e36ce721890"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171597, 4598, 766, 15, 31, "Input",ExpressionUUID->"95610e60-0346-4fc5-8419-8f28a837c222"],
Cell[172366, 4615, 318, 10, 47, "Output",ExpressionUUID->"5dae322e-0458-4288-8ead-1617f1e5a943"]
}, Open  ]],
Cell[172699, 4628, 224, 5, 29, "Text",ExpressionUUID->"791b8f37-6f86-4878-9200-bf51894ed4b6"],
Cell[CellGroupData[{
Cell[172948, 4637, 555, 14, 31, "Input",ExpressionUUID->"9f031e80-8a75-49ec-862b-7295087a3558"],
Cell[173506, 4653, 715, 22, 47, "Output",ExpressionUUID->"2a5b95a6-766b-4665-ab1e-04f65833e1b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174258, 4680, 576, 14, 31, "Input",ExpressionUUID->"e53f2a9f-a93a-4410-b11e-9717fdeb2e4a"],
Cell[174837, 4696, 628, 12, 21, "Message",ExpressionUUID->"4e61f886-93e4-4197-aa81-a52dcfa67968"],
Cell[175468, 4710, 724, 22, 49, "Output",ExpressionUUID->"6aa38d3f-2923-46fc-83f2-316f28ffe6c8"]
}, Open  ]],
Cell[176207, 4735, 467, 8, 47, "Text",ExpressionUUID->"1e6523f5-6592-43d7-88c4-3f26b7b5332e"],
Cell[176677, 4745, 480, 11, 29, "Text",ExpressionUUID->"d8c42544-236d-46b8-834d-c8ee4611cfd4"],
Cell[177160, 4758, 180, 3, 29, "Text",ExpressionUUID->"c96070b9-7fc8-4d00-8fea-a5d6d08472b4"],
Cell[CellGroupData[{
Cell[177365, 4765, 262, 6, 31, "Input",ExpressionUUID->"3a4b384a-a0eb-4f19-bc7e-f0cece658112"],
Cell[177630, 4773, 152, 3, 30, "Output",ExpressionUUID->"31244792-dfb2-49fc-b6db-f7ab3b651d28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177819, 4781, 512, 15, 31, "Input",ExpressionUUID->"2df13a48-c288-4048-80f3-a15c51473311"],
Cell[178334, 4798, 396, 12, 47, "Output",ExpressionUUID->"93cac504-22c2-4534-9104-fe4ae6e7c74f"]
}, Open  ]],
Cell[178745, 4813, 184, 3, 29, "Text",ExpressionUUID->"5ce556b3-47c2-49d9-aa6d-9822f3ebbb70"],
Cell[CellGroupData[{
Cell[178954, 4820, 236, 6, 31, "Input",ExpressionUUID->"d8d60e39-5bfb-4a6a-a661-6cfe35afef48"],
Cell[179193, 4828, 152, 4, 47, "Output",ExpressionUUID->"31464a62-cdd0-479c-baa8-6aa939326b66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179382, 4837, 439, 13, 31, "Input",ExpressionUUID->"c03962be-f818-47b8-87bd-dbc0d3c3d12c"],
Cell[179824, 4852, 499, 17, 47, "Output",ExpressionUUID->"8ff4637f-3279-4cff-b5bb-f3ab3369db7b"]
}, Open  ]],
Cell[180338, 4872, 292, 6, 29, "Text",ExpressionUUID->"8904d6b2-8d4f-41a0-91e7-957e73be2abd"],
Cell[CellGroupData[{
Cell[180655, 4882, 183, 4, 31, "Input",ExpressionUUID->"17011391-248f-4129-96f8-e99bd888e47b"],
Cell[180841, 4888, 867, 30, 47, "Output",ExpressionUUID->"375eeac9-09cf-4b93-8b93-e43476cc33db"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[181757, 4924, 179, 3, 27, "Subsubsection",ExpressionUUID->"e2d17fcd-9694-45bc-91de-7b2bbf451815"],
Cell[181939, 4929, 553, 9, 65, "Text",ExpressionUUID->"b2b9e951-57ba-46b8-a6b0-a2db4da3c9ab"],
Cell[182495, 4940, 190, 2, 29, "Text",ExpressionUUID->"2eb4f897-526c-4d94-9fc8-c720ffcb20ee"],
Cell[182688, 4944, 293, 7, 31, "Input",ExpressionUUID->"168935a4-95a3-4636-b846-1d9565a90874"],
Cell[182984, 4953, 575, 16, 31, "Input",ExpressionUUID->"4bda2408-61a1-43b2-a578-31186b0e405c"],
Cell[183562, 4971, 665, 18, 31, "Input",ExpressionUUID->"c88ea32c-c98d-4262-8b6a-cee9dc8692d3"],
Cell[184230, 4991, 824, 23, 31, "Input",ExpressionUUID->"710e8917-25b2-4a18-a2d8-a0353db9e9e3"],
Cell[CellGroupData[{
Cell[185079, 5018, 646, 18, 31, "Input",ExpressionUUID->"b325b529-5931-4cdb-89d5-29b29feadf85"],
Cell[185728, 5038, 3470, 103, 88, "Output",ExpressionUUID->"baf83207-40e8-4657-ab53-6773f552671c"]
}, Open  ]],
Cell[189213, 5144, 196, 3, 29, "Text",ExpressionUUID->"0ae40e10-0100-442e-ad9a-8d90fdab9f8e"],
Cell[CellGroupData[{
Cell[189434, 5151, 183, 4, 31, "Input",ExpressionUUID->"de3ccf7a-9c7f-4332-9ea4-4410f348e74f"],
Cell[189620, 5157, 6925, 218, 148, "Output",ExpressionUUID->"431da15b-2bb9-47ed-babf-801708124070"]
}, Open  ]],
Cell[196560, 5378, 509, 13, 47, "Text",ExpressionUUID->"ffd7f579-7c8e-4027-afa9-775762bd7253"],
Cell[CellGroupData[{
Cell[197094, 5395, 481, 13, 31, "Input",ExpressionUUID->"23edb18f-d946-482c-9bcb-ca14b42f5967"],
Cell[197578, 5410, 3040, 107, 119, "Output",ExpressionUUID->"c9b8959d-bb55-4540-baed-0597d6ac0917"]
}, Open  ]],
Cell[200633, 5520, 190, 2, 29, "Text",ExpressionUUID->"28c7c7cc-b85b-4128-a10c-761c6f631315"],
Cell[CellGroupData[{
Cell[200848, 5526, 341, 7, 31, "Input",ExpressionUUID->"9ffbf96e-e3ff-46da-8488-6fdae6105c4a"],
Cell[201192, 5535, 271, 5, 30, "Output",ExpressionUUID->"3ed504aa-78d6-4054-8df7-eaeec9207090"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201500, 5545, 608, 18, 31, "Input",ExpressionUUID->"9b305fe9-b98a-4da1-b2b4-a5a6cb186217"],
Cell[202111, 5565, 3311, 112, 119, "Output",ExpressionUUID->"b8f6a0cf-0b10-4f42-bb5a-36e656454130"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205459, 5682, 678, 20, 31, "Input",ExpressionUUID->"bd4aa363-1f16-4644-8cc7-f74f054f3b5e"],
Cell[206140, 5704, 11155, 340, 336, "Output",ExpressionUUID->"7c0a9b0e-6739-47b5-9b72-2f519cfe9fe6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217332, 6049, 796, 22, 31, "Input",ExpressionUUID->"f1ce153b-3b31-4b49-99f0-7403e8e69b3e"],
Cell[218131, 6073, 37671, 1023, 987, "Output",ExpressionUUID->"483342f2-6970-431a-8f0d-2c2a31d63e60"]
}, Open  ]],
Cell[255817, 7099, 547, 14, 31, "Input",ExpressionUUID->"1e5965d1-7654-4d19-8830-c6efef27b250"],
Cell[256367, 7115, 433, 9, 29, "Text",ExpressionUUID->"f11db8a3-dc3c-428d-abfa-efc072d67545"],
Cell[256803, 7126, 251, 5, 29, "Text",ExpressionUUID->"167484d6-2a9f-4f26-9df1-b1599c5919a3"],
Cell[257057, 7133, 358, 9, 31, "Input",ExpressionUUID->"5c38a07f-7ac9-4f7d-a0e0-a26e70364cbe"],
Cell[257418, 7144, 444, 9, 29, "Text",ExpressionUUID->"2d520e2b-fe52-4da0-902a-485fd9ae8b10"],
Cell[CellGroupData[{
Cell[257887, 7157, 411, 11, 31, "Input",ExpressionUUID->"54e3bad3-aa6d-4869-9811-3152ce93d601"],
Cell[258301, 7170, 348, 10, 30, "Output",ExpressionUUID->"c67851b9-0fc9-4ded-83bd-90e8ae959a75"]
}, Open  ]],
Cell[258664, 7183, 501, 9, 47, "Text",ExpressionUUID->"4b2bb1a3-2898-4a34-bdd1-6c51e8119198"],
Cell[259168, 7194, 515, 13, 31, "Input",ExpressionUUID->"b82f5df5-ef49-4881-abab-5dcdab1e4be8"],
Cell[259686, 7209, 490, 9, 47, "Text",ExpressionUUID->"ac7f8396-9957-4c72-ba83-e7b7c954574e"],
Cell[CellGroupData[{
Cell[260201, 7222, 218, 5, 31, "Input",ExpressionUUID->"fe6d09ac-0469-4bb9-8cf5-ebf5ebbaa09c"],
Cell[260422, 7229, 1446, 44, 67, "Output",ExpressionUUID->"2f978818-5322-4dc6-bb46-a30804a30b03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[261905, 7278, 240, 6, 31, "Input",ExpressionUUID->"59af3154-49f8-4ec7-a5a2-405099b6dc02"],
Cell[262148, 7286, 1601, 54, 47, "Output",ExpressionUUID->"33621fd2-d802-4e00-bcb7-3bccdff1cb7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263786, 7345, 244, 6, 31, "Input",ExpressionUUID->"f6788b03-6a1e-49fc-b287-6cc409dc691c"],
Cell[264033, 7353, 14956, 520, 415, "Output",ExpressionUUID->"03557b15-98bf-4ea4-b2cd-f6f979f57c35"]
}, Open  ]],
Cell[279004, 7876, 246, 4, 29, "Text",ExpressionUUID->"1d00c98c-7b7f-4cbd-b510-68b14d16ec6c"],
Cell[CellGroupData[{
Cell[279275, 7884, 2699, 76, 77, "Input",ExpressionUUID->"2c834e11-1a0f-4b68-82e6-e3297cf53178"],
Cell[281977, 7962, 8561, 259, 301, "Output",ExpressionUUID->"276aaeb6-d319-4a62-9a3e-3d1eff5476db"]
}, Open  ]],
Cell[290553, 8224, 219, 5, 29, "Text",ExpressionUUID->"396b8b78-01d7-4da6-b490-3fee459aba7b"],
Cell[290775, 8231, 510, 13, 31, "Input",ExpressionUUID->"f9867f0c-b5be-4867-9d3c-ebefaa9753a0"],
Cell[CellGroupData[{
Cell[291310, 8248, 267, 6, 31, "Input",ExpressionUUID->"8bd097ea-320e-4144-a2e4-cea5c5f47547"],
Cell[291580, 8256, 573, 15, 47, "Output",ExpressionUUID->"c6d2760d-65bf-45cc-8196-20861bbe3704"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292190, 8276, 291, 7, 31, "Input",ExpressionUUID->"ea21a423-f552-49c1-8831-f53753f9df76"],
Cell[292484, 8285, 1595, 53, 47, "Output",ExpressionUUID->"7150f213-ee1c-479c-b060-1c24bf0b9758"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294116, 8343, 295, 7, 31, "Input",ExpressionUUID->"5eae4f9d-fbc1-4d40-9170-6f63cf495f98"],
Cell[294414, 8352, 6624, 229, 160, "Output",ExpressionUUID->"e5396ad5-9c1b-4868-8ccc-d10ca6c43f94"]
}, Open  ]],
Cell[301053, 8584, 2618, 73, 92, "Input",ExpressionUUID->"223c7637-2275-4e6d-8b3a-8b72a4d30893"],
Cell[303674, 8659, 192, 3, 29, "Text",ExpressionUUID->"549313f7-1a11-41f4-bf94-c729b35c7399"],
Cell[CellGroupData[{
Cell[303891, 8666, 363, 6, 31, "Input",ExpressionUUID->"0c336771-f5ce-4c86-919f-73bc695cedb6"],
Cell[304257, 8674, 12680, 382, 490, "Output",ExpressionUUID->"489f9293-57ae-4d24-9a24-f4b0f8be24e4"]
}, Open  ]],
Cell[316952, 9059, 389, 9, 47, "Text",ExpressionUUID->"e0a6d936-39a1-42b9-8157-5d8e760bef00"],
Cell[317344, 9070, 547, 9, 47, "Text",ExpressionUUID->"f5b0128a-df5b-49d5-b4ba-636bacc0b743"],
Cell[317894, 9081, 731, 20, 72, "Input",ExpressionUUID->"ecebc330-5e25-4bf7-ab33-362a0e5dd1c1"],
Cell[318628, 9103, 246, 6, 29, "Text",ExpressionUUID->"aaac2c09-cfc8-41bc-b51a-7abe88c11528"],
Cell[CellGroupData[{
Cell[318899, 9113, 211, 4, 31, "Input",ExpressionUUID->"916244fc-53c6-4747-abe9-51e1ee589b3a"],
Cell[319113, 9119, 5575, 172, 227, "Output",ExpressionUUID->"7d2e07a3-cd36-48fd-a7eb-96aff4b8a922"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324725, 9296, 926, 21, 31, "Input",ExpressionUUID->"e2b214f7-eaee-465a-9d52-f0a5417ceb0e"],
Cell[325654, 9319, 1042, 30, 47, "Output",ExpressionUUID->"5fabc254-f581-40cf-bb79-e475430c2fe2"]
}, Open  ]],
Cell[326711, 9352, 291, 5, 29, "Text",ExpressionUUID->"f08fd850-f6c0-48b2-96c8-3c4086caaefe"],
Cell[CellGroupData[{
Cell[327027, 9361, 721, 20, 31, "Input",ExpressionUUID->"72c8b287-8d24-4ba5-bf76-142055354854"],
Cell[327751, 9383, 1880, 60, 83, "Output",ExpressionUUID->"ce071025-a8f4-490a-a1c4-93157278e617"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[329680, 9449, 224, 3, 27, "Subsubsection",ExpressionUUID->"ffc1ec06-a984-45c0-bfdc-9b3baa63d696"],
Cell[329907, 9454, 349, 6, 29, "Text",ExpressionUUID->"d2be71d0-86bc-4816-8742-e039ea9f5d32"],
Cell[330259, 9462, 1764, 49, 132, "Input",ExpressionUUID->"1caadc7d-31e3-40f4-b069-4be320b391ba"],
Cell[332026, 9513, 224, 5, 29, "Text",ExpressionUUID->"cfe37764-825d-4e00-bdd5-309016c36999"],
Cell[332253, 9520, 330, 9, 31, "Input",ExpressionUUID->"32bc80d8-f215-491d-9c3f-af0d858e4cd7"],
Cell[CellGroupData[{
Cell[332608, 9533, 240, 5, 31, "Input",ExpressionUUID->"c55b5fe8-410d-4766-a99c-79d0dcf84817"],
Cell[332851, 9540, 274, 4, 30, "Output",ExpressionUUID->"c89bc6d9-b307-4646-9f14-e09d32a1047e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333162, 9549, 544, 11, 31, "Input",ExpressionUUID->"8dacf5e1-d55f-437c-81b1-603ec829bc59"],
Cell[333709, 9562, 1477, 34, 50, "Output",ExpressionUUID->"b6fcbe73-a8f2-47e4-8f7e-502c5e1e7db9"]
}, Open  ]],
Cell[335201, 9599, 497, 11, 47, "Text",ExpressionUUID->"db0a3611-af5a-46e6-a077-c088cbd8c91f"],
Cell[CellGroupData[{
Cell[335723, 9614, 283, 8, 31, "Input",ExpressionUUID->"412d6077-8e06-4228-8caf-3a82453457c0"],
Cell[336009, 9624, 250, 5, 30, "Output",ExpressionUUID->"55fec059-55be-4f84-8770-b41cd75a64be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336296, 9634, 113, 1, 31, "Input",ExpressionUUID->"e6255f9f-17fd-49cb-aafe-d6c3c75e8f2f"],
Cell[336412, 9637, 261, 5, 30, "Output",ExpressionUUID->"c5a12aa7-1e43-4c75-b75b-4100c02604e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336710, 9647, 381, 7, 31, "Input",ExpressionUUID->"60d9f806-6d0d-4554-be0e-241c1252f3e7"],
Cell[337094, 9656, 717, 14, 235, "Output",ExpressionUUID->"772a835e-6f2b-4f41-83c5-2d5b019fe855"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337848, 9675, 263, 6, 31, "Input",ExpressionUUID->"b4c9a336-4424-4997-917e-d6d2fab3721f"],
Cell[338114, 9683, 2646, 50, 403, "Output",ExpressionUUID->"258b6c81-0956-47e5-8851-6103540345fd"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[340821, 9740, 292, 8, 38, "Subsection",ExpressionUUID->"fa4c5259-ee6e-4536-b75b-628fae799943"],
Cell[341116, 9750, 418, 9, 47, "Text",ExpressionUUID->"3c75bfb7-25d5-4ab8-ad8c-c269931af2aa"],
Cell[341537, 9761, 508, 11, 47, "Text",ExpressionUUID->"9b789535-7b3e-4a54-bc82-422d44799dee"],
Cell[CellGroupData[{
Cell[342070, 9776, 666, 20, 31, "Input",ExpressionUUID->"1c98b454-b6e7-4fe5-a79e-e6dac0930f5c"],
Cell[342739, 9798, 626, 19, 49, "Output",ExpressionUUID->"3f20e01e-42d8-452b-8fa4-cf121810743d"]
}, Open  ]],
Cell[343380, 9820, 384, 9, 47, "Text",ExpressionUUID->"27a7d6d1-1c24-49ba-8bdf-76518a5122e9"],
Cell[CellGroupData[{
Cell[343789, 9833, 887, 25, 31, "Input",ExpressionUUID->"495d81df-cdf5-4cff-a06a-2af35f9e5083"],
Cell[344679, 9860, 478, 14, 30, "Output",ExpressionUUID->"c5bb272b-7472-403b-9bbe-ef1b93f38122"]
}, Open  ]],
Cell[345172, 9877, 215, 5, 29, "Text",ExpressionUUID->"38918d15-1b58-443e-ba05-5524df06984c"],
Cell[CellGroupData[{
Cell[345412, 9886, 354, 9, 31, "Input",ExpressionUUID->"5cea0ba9-2512-4fd6-b9bb-92986bb0705c"],
Cell[345769, 9897, 171, 3, 30, "Output",ExpressionUUID->"952b5ab6-d788-4d89-9115-5946bbd642f4"]
}, Open  ]],
Cell[345955, 9903, 254, 6, 29, "Text",ExpressionUUID->"8c674be8-7ed3-4715-84ed-f56cf47547c5"],
Cell[CellGroupData[{
Cell[346234, 9913, 190, 4, 31, "Input",ExpressionUUID->"d31564c5-f8df-4fc0-bc97-034f3da771bb"],
Cell[346427, 9919, 134, 3, 30, "Output",ExpressionUUID->"34218adb-6559-466f-9c04-063aaa75c135"]
}, Open  ]],
Cell[346576, 9925, 361, 11, 31, "Input",ExpressionUUID->"13e7af6e-64c7-4cb9-9491-cdf7606ec2f3"],
Cell[346940, 9938, 573, 13, 31, "Input",ExpressionUUID->"be06ca7e-9ff7-4f1b-9649-019b0d7c0394"],
Cell[CellGroupData[{
Cell[347538, 9955, 231, 6, 31, "Input",ExpressionUUID->"a05ccf5b-5e3e-4325-b9ad-520fefe08e35"],
Cell[347772, 9963, 210, 5, 30, "Output",ExpressionUUID->"ecf72072-8838-41a9-b7c3-0021d4c27877"]
}, Open  ]],
Cell[347997, 9971, 336, 7, 47, "Text",ExpressionUUID->"bcc3dcc0-8407-4f01-9fdf-77054cb52308"]
}, Closed]],
Cell[CellGroupData[{
Cell[348370, 9983, 183, 3, 38, "Subsection",ExpressionUUID->"6688477a-bc40-4818-b1ff-cc8abed3e525"],
Cell[348556, 9988, 345, 6, 29, "Text",ExpressionUUID->"f7adf7da-89a7-46eb-b896-998ab2ced901"],
Cell[CellGroupData[{
Cell[348926, 9998, 173, 3, 27, "Subsubsection",ExpressionUUID->"90a91187-4dc5-4559-b52d-3ca5f7e14805"],
Cell[349102, 10003, 417, 9, 83, "Text",ExpressionUUID->"d4eecf5f-51ca-4d40-a824-7cfe2c4f08e8"],
Cell[349522, 10014, 344, 8, 52, "Input",ExpressionUUID->"2ec6c6b8-c986-42ff-86f9-3d5cae03a44a"],
Cell[CellGroupData[{
Cell[349891, 10026, 1172, 28, 31, "Input",ExpressionUUID->"93846ac5-3bdb-4a16-b223-4c565407c12a"],
Cell[351066, 10056, 871, 18, 48, "Output",ExpressionUUID->"5779f49f-d8c3-4585-af64-5e309f2e2206"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351974, 10079, 365, 10, 31, "Input",ExpressionUUID->"5e645da3-7951-4122-bc2d-f50d0767bc9b"],
Cell[352342, 10091, 273, 6, 48, "Output",ExpressionUUID->"adf865be-459d-4c07-b54f-3f43a686a705"]
}, Open  ]],
Cell[352630, 10100, 180, 3, 29, "Text",ExpressionUUID->"eaeac017-7b8e-44e3-b0c8-7591dbbe6f51"],
Cell[CellGroupData[{
Cell[352835, 10107, 493, 11, 31, "Input",ExpressionUUID->"7aeb0435-162c-4107-a9f5-ad06e74c9510"],
Cell[353331, 10120, 3241, 60, 243, "Output",ExpressionUUID->"bf967fa5-bce5-4928-8a46-31d9964912a6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[356621, 10186, 187, 3, 27, "Subsubsection",ExpressionUUID->"845c9605-b03a-412d-ab0c-2681c3180787"],
Cell[356811, 10191, 469, 12, 29, "Text",ExpressionUUID->"cba40b70-0892-4fd1-8fce-68a451e86cb1"],
Cell[357283, 10205, 1764, 49, 132, "Input",ExpressionUUID->"5f21af6f-79d8-4df9-b788-d4ade1cda95f"],
Cell[359050, 10256, 424, 12, 31, "Input",ExpressionUUID->"3ff69426-5291-451a-a503-73abc50d5d9c"],
Cell[CellGroupData[{
Cell[359499, 10272, 288, 5, 31, "Input",ExpressionUUID->"3d9d95c0-9d6f-42d3-85cb-b8a415b28f29"],
Cell[359790, 10279, 329, 5, 30, "Output",ExpressionUUID->"e382703c-e89d-49c3-b4f0-ca889173a7b3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360156, 10289, 815, 17, 31, "Input",ExpressionUUID->"6e34cec1-fe46-4b7a-bf90-73faccc959bc"],
Cell[360974, 10308, 1656, 36, 50, "Output",ExpressionUUID->"8474a16f-73e9-4f6a-99b0-a219ab45caee"]
}, Open  ]],
Cell[362645, 10347, 377, 10, 29, "Text",ExpressionUUID->"37e60375-b2ba-4522-a5b9-286ccf05724a"],
Cell[CellGroupData[{
Cell[363047, 10361, 536, 12, 31, "Input",ExpressionUUID->"6212da6a-7f80-44e8-abe9-c94377a051cb"],
Cell[363586, 10375, 327, 5, 30, "Output",ExpressionUUID->"fdbd931d-e831-400b-8a1b-e87ef4ff6d90"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[363962, 10386, 173, 3, 27, "Subsubsection",ExpressionUUID->"9c18815b-ba25-48fd-8b8c-e5bcb3b7f151"],
Cell[364138, 10391, 2117, 55, 83, "Text",ExpressionUUID->"fec685c3-a7c4-47ed-8fb3-7ec231633cb5"],
Cell[366258, 10448, 5729, 148, 252, "Input",ExpressionUUID->"6777105a-371c-46d2-897d-d1413762686e"],
Cell[371990, 10598, 222, 5, 29, "Text",ExpressionUUID->"bfc882f4-75d0-4ffe-8e8b-9c835221fbe1"],
Cell[CellGroupData[{
Cell[372237, 10607, 409, 9, 31, "Input",ExpressionUUID->"a8fc3242-7342-4b26-9b75-fac684c71bf8"],
Cell[372649, 10618, 257, 5, 47, "Output",ExpressionUUID->"2f6ba871-1e90-408d-a593-e98d51c6487d"]
}, Open  ]],
Cell[372921, 10626, 1390, 29, 101, "Text",ExpressionUUID->"3582f468-8105-400a-856d-1e75f5e05c0f"],
Cell[CellGroupData[{
Cell[374336, 10659, 606, 12, 31, "Input",ExpressionUUID->"917cfd89-6c3e-4bc4-abdc-5c4df5eeb9a3"],
Cell[374945, 10673, 331, 6, 30, "Output",ExpressionUUID->"c5562461-c807-416a-9e3f-2fcc904f131b"]
}, Open  ]],
Cell[375291, 10682, 184, 3, 29, "Text",ExpressionUUID->"d4cde144-2def-4a3b-9b03-3fc520771db6"],
Cell[CellGroupData[{
Cell[375500, 10689, 743, 14, 31, "Input",ExpressionUUID->"bfaf63ce-c5fc-4fe7-92f1-aa81d98eece1"],
Cell[376246, 10705, 3570, 100, 164, "Output",ExpressionUUID->"7df35a1a-9af7-4900-89f4-2a8b4fa72ef9"]
}, Open  ]],
Cell[379831, 10808, 276, 6, 29, "Text",ExpressionUUID->"d891ee81-cefc-49f3-bdc6-1da63d1aa9af"],
Cell[CellGroupData[{
Cell[380132, 10818, 567, 15, 31, "Input",ExpressionUUID->"58eb3cc2-a419-445d-9195-6981890e4f7a"],
Cell[380702, 10835, 371, 6, 30, "Output",ExpressionUUID->"99a2afa7-ff9e-4f28-8fe1-de609abf4d6a"]
}, Open  ]],
Cell[381088, 10844, 285, 6, 29, "Text",ExpressionUUID->"16a76d75-5696-465f-ad09-7618569adfd9"],
Cell[CellGroupData[{
Cell[381398, 10854, 595, 17, 31, "Input",ExpressionUUID->"c1379a8b-fd63-4033-a8ac-1ec2e80986a6"],
Cell[381996, 10873, 2367, 53, 107, "Output",ExpressionUUID->"1b207200-9c65-4953-a641-d635652c3b4d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384400, 10931, 231, 5, 31, "Input",ExpressionUUID->"e8782579-7b3a-4545-8f81-6e043ae273c6"],
Cell[384634, 10938, 943, 20, 241, "Output",ExpressionUUID->"c0a8ab43-908a-4abc-9d13-363daff68287"]
}, Open  ]],
Cell[385592, 10961, 357, 7, 47, "Text",ExpressionUUID->"8e5de774-6424-44a8-b81c-d91f5073ddd2"],
Cell[CellGroupData[{
Cell[385974, 10972, 216, 5, 31, "Input",ExpressionUUID->"15191bc9-2370-4667-82e9-8633e841613b"],
Cell[386193, 10979, 3877, 72, 440, "Output",ExpressionUUID->"45481221-f72c-4049-b3b8-41a261fa997f"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

